import React from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';

import IconButton from '@material-ui/core/IconButton';

/* Icons */
import AddOutlinedIcon from '@mui/icons-material/AddOutlined';
import { ThemeTypes } from './Theme/theme.types';

interface AddButtonTypes {
  width?: string | number;
  height?: string | number;
  onClick?: () => void;
  iconWidth?: number | string;
  [key: string]: any;
}

export const AddButton = ({ width, height, onClick, iconWidth, ...props }: AddButtonTypes) => {
  const styles = makeStyles({
    root: {
      border: `1px  solid ${theme.borderGreyPrimary}`,
      width: (props: ThemeTypes) => props.width || 356,
      height: (props: ThemeTypes) => props.height || 65,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      borderRadius: 4,
      '&:hover': {
        border: `1px solid ${theme.bluePrimary}`
      },
      '&>button': {
        width: (props: ThemeTypes) => props.iconWidth || 35,
        height: (props: ThemeTypes) => props.iconWidth || 35,
        '&>span>svg': {
          width: (props: ThemeTypes) => props.iconWidth || 35,
          height: (props: ThemeTypes) => props.iconWidth || 35,
          borderRadius: '50%',
          backgroundColor: theme.secondaryLightGray,
          color: theme.opacityGrayDefault,
          '&:hover': {
            cursor: 'pointer'
          }
        }
      }
    }
  });
  const classes = styles({ width, height, iconWidth });
  return (
    <div className={classes.root} {...props}>
      <IconButton onClick={onClick}>
        <AddOutlinedIcon />
      </IconButton>
    </div>
  )
}