import React, { useState, useRef } from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';

import { FormatName, FileSize, DescriptionSize } from '../src/helpers/fileTypes';
import { temporalId } from './helpers/temporalId';
import { ThemeTypes } from './Theme/theme.types';


import { DefaultModal } from './DefaultModal';
import { RenderFile } from './RenderFile';
import CloudOffIcon from '@mui/icons-material/CloudOff';



type RecentFilesListType = {
  id: string;
  name: string;
  url: string;
  type: string;
  size?: string;
  created?: Date | string;
}

interface AttachFilesTypes {
  [key: string]: any;
  lng?: string;
  recentFilesList?: RecentFilesListType[];
  addFile?: RecentFilesListType;
  setAddFile?: (v: RecentFilesListType) => void;
  file?: any;
  setFile?: any;
  limitSizeInMB: number;
  setAlertSize?: (v: boolean) => void;
  setFileName?: (v?: string) => void;
  setFileType?: (v?: string) => void;
  setFileSize?: (v?: string) => void;
  setFilePath?: (v?: string) => void;
}

export const AttachFilesChat = ({
  lng,
  addFile,
  setAddFile,
  recentFilesList,
  file,
  setFile,
  limitSizeInMB,
  setAlertSize,
  setFileName,
  setFileSize,
  setFilePath,
  setFileType,
  ...props }: AttachFilesTypes) => {
  const styles = makeStyles({
    root: {
      position: 'absolute',
      right: 70,
      border: `2px solid ${theme.borderGreyPrimary}`,
      width: 'max-content',
      height: 'max-content',
      marginTop: (props: ThemeTypes) => props.marginTop,
      backgroundColor: theme.whitePrimary,
      zIndex: 120,
      borderRadius: 5
    },
    content: {
      '&>p': {
        margin: '0px 0px 0px 0px',
        padding: 15,
        '&:nth-child(1)': {
          borderBottom: `2px solid ${theme.borderGreyPrimary}`,
          color: theme.opacityGrayDefault
        },
        "&:hover": {
          '&:nth-child(1)': {
            backgroundColor: theme.whitePrimary,
            cursor: 'default',
            color: theme.opacityGrayDefault

          },
          backgroundColor: theme.hoverBlue,
          cursor: 'pointer',
          color: theme.bluePrimary
        }
      }
    },
    containerNoRecentFiles: {
      height: 200,
      width: 200,
      padding: 20,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center'
    },
    containerRecentFiles: {
      maxHeight: 250,
      minHeight: 250,
      overflowY: "auto",
      overflowX: 'hidden',
      '&::-webkit-scrollbar': {
        width: "5px",
        backgroundColor: theme.grayPrimary,
      },
      '&::-webkit-scrollbar-thumb': {
        backgroundColor: theme.opacityGrayDefault,
        borderRadius: "20px",
      },
      "&::-webkit-scrollbar-track": {
        marginBottom: "1px",
      },
    },
    itemFile: {
      borderBottom: `1px solid ${theme.grayPrimary}`,
      display: 'flex',
      flexFlow: 'wrap',
      alignItems: 'center',
      padding: 15,
      '&:hover': {
        cursor: 'pointer',
        backgroundColor: theme.hoverBlue,
        '&>div>p': {
          color: theme.bluePrimary
        }
      },
      "&>:nth-child(1)": {
        width: 50,
        height: 50,
        border: `1px solid ${theme.grayPrimary}`,
        borderRadius: 4,
        "&>div>img": {
          width: 50,
          height: 50,
          borderRadius: 4,
        }
      }
    },
    fileInfo: {
      width: 'max-content',
      padding: 5,
      marginLeft: 5,
      textAlign: 'left'
    },
    fileName: {
      fontSize: 14,
      color: theme.defaultSubtitle,
    },
    fileSize: {
      fontSize: 12,
      color: theme.defaultSubtitle,
      width: 'max-content'
    },
    contentModal: {
      width: 'fit-content',
      height: 'fit-content',
      maxWidth: 530,
      maxHeight: 760,
      overflow: 'auto',
      "&>div>div":{        
        maxHeight: `520px !important`,
        maxWidth: 450,
        overflow: 'auto',
        '&::-webkit-scrollbar': {
          width: "5px",
          height: "5px",
          backgroundColor: theme.grayPrimary,
        },
        '&::-webkit-scrollbar-thumb': {
          backgroundColor: theme.opacityGrayDefault,
          borderRadius: "20px",
        },
        "&::-webkit-scrollbar-track": {
          marginBottom: "1px",
        },
      }
    },
    containerVideo: {},
    noRecentFiles: {
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      color: theme.opacityGrayDefault,
      width: '100%',
      height: '100%',
      fontSize: 18,
      '&>div>div': {
        display: 'flex',
        justifyContent: 'center',
        '&>svg': {
          width: 60,
          height: 60,
        },
      }
    }
  });
  const [openRecentFiles, setOpenRecentFiles] = useState(false);
  const selectedFileInitialValues = { id: '', name: '', url: '', type: '', size: '', created: undefined }
  const [selectedFile, setSelectedFile] = useState<RecentFilesListType>(selectedFileInitialValues)

  const classes = styles({ marginTop: openRecentFiles ? -255 : -170 });
  const [openModal, setOpenModal] = useState(false);

  const inputFile: any = useRef();
  const accept = 
   `image/*,
    application/pdf, 
    application/vnd.openxmlformats-officedocument.wordprocessingml.document,
    application/vnd.openxmlformats-officedocument.spreadsheetml.sheet,
    application/zip,
    application/x-zip-compressed,
    video/mp4,
    audio/mpeg,
    audio/ogg,
    audio/wav
    `
  


  const labels = {
    title: lng === 'en' ? 'Attach' : 'Adjuntar',
    labelOne: lng === 'en' ? 'Recent files' : 'Archivos recientes',
    labelTwo: lng === 'en' ? 'Upload from your computer' : 'Subir desde mi computador'
  }

  const handleRecentFiles = () => {
    setOpenRecentFiles(!openRecentFiles)
  }
 
  const handlePreview = (file: RecentFilesListType) => {
    setOpenModal(!openModal)
    setSelectedFile(file)
  }
  const handleAddFile = (file: RecentFilesListType) => {
    // Here set recent file data
    setAddFile && setAddFile(file)
    setFileName && setFileName(file.name)
    setFileType && setFileType(file.type)
    setFileSize && setFileSize(file.size)
    setFilePath && setFilePath(file.url)
    setOpenRecentFiles(false)
  }

  const handleCloseModal = () => {
    setOpenModal(false)
    setSelectedFile(selectedFileInitialValues)
  }
 
  /* Add new file */

  const handleUploadNewFile = () => {
    if (inputFile) inputFile?.current.click();
  };

  const onLoad = async (data: any) => {
		return new Promise((resolve, _reject) => {
			const fileReader = new window.FileReader()
			fileReader.readAsDataURL(data)
			fileReader.onload = (fileLoad) => {
				const { result }: any = fileLoad.target
				resolve(result)
			}
		})
	}
  const fileChange = async (e: any) => {
    const preSaveFile = async () => {
			const aux: any = []
			const aux2: any = []
      const limitInMB = limitSizeInMB;
      const limitInBytes: number = limitInMB *  1000000;
      await Promise.all(
        Array.from(e.target.files).map(async (ind) => {
          const url = await onLoad(ind)
          aux.push(ind)
          aux2.push({ url: url })
          return null
        })
        )
        
        if(aux[0]?.size <=limitInBytes){
        setAlertSize && setAlertSize(false)
        setFile && setFile({
          base: aux2[0].url,
          url: aux2[0].url,
          name: aux[0].name,
          type: aux[0].type,
          size: aux[0].size,
          lastModified: aux[0].lastModified,
          lastModifiedDate: { ...aux[0].lastModifiedDate },
          webkitRelativePath: aux[0].webkitRelativePath,
          dataFile: {
            base: aux2[0].url,
            url: aux2[0].url,
            name: aux[0].name,
            type: aux[0].type,
            size: aux[0].size,
            lastModified: aux[0].lastModified,
            lastModifiedDate: { ...aux[0].lastModifiedDate },
            webkitRelativePath: aux[0].webkitRelativePath,
          },
          file: {
            base: aux2[0].url,
            url: aux2[0].url,
            name: aux[0].name,
            type: aux[0].type,
            size: aux[0].size,
            lastModified: aux[0].lastModified,
            lastModifiedDate: { ...aux[0].lastModifiedDate },
            webkitRelativePath: aux[0].webkitRelativePath,
          },
          attachData: { ...aux },
        })
        setAddFile && setAddFile({
          id: temporalId(), 
          name: aux[0].name, 
          url: aux2[0].url, 
          type: aux[0].type, 
          size: aux[0].size, 
          created: new Date().toISOString()
        })
      } else {
        setAlertSize && setAlertSize(true)
      }
		}

		if (e.target.files && e.target.files[0]) {
			await preSaveFile()
		}
  };
  /* End add new file */

  const ContentModal = () => {
    return (
      <div>
        <RenderFile
          selectedFile={selectedFile}
          renderType="preview"
          lng={lng}
          handlePreview={handlePreview}
          file={selectedFile}
        />
      </div>
    )
  }

  return (
    <div className={classes.root} {...props}>
      {openModal && (
        <DefaultModal
          open={openModal}
          setOpen={setOpenModal}
          handleClose={() => handleCloseModal()}
          content={ContentModal()}
          width={'fit-content'}
          height={'fit-content'}
          classContent={classes.contentModal}
        />
      )}
      {openRecentFiles && (
        <div className={recentFilesList && recentFilesList.length > 0 ? classes.containerRecentFiles : classes.containerNoRecentFiles}>
          {recentFilesList && recentFilesList.length > 0 ? (
            recentFilesList.map((f: RecentFilesListType) => (
              <div key={f.id} className={classes.itemFile}>
                <RenderFile
                  selectedFile={selectedFile}
                  renderType="icon"
                  lng={lng}
                  handlePreview={handlePreview}
                  file={f}
                />
                <div className={classes.fileInfo} onClick={() => handleAddFile(f)}>
                  <p className={classes.fileName}>{FormatName(f.name)}</p>
                  <p className={classes.fileSize}>{DescriptionSize(FileSize(f.size), lng || "")}</p>
                </div>
              </div>
            ))
          ) : (
            <div className={classes.noRecentFiles}>
              <div>
                <div><CloudOffIcon /></div>
                <p>
                  {lng === 'en' ? 'No recent files' : 'No hay archivos recientes'}
                </p>
              </div>
            </div>
          )}
        </div>
      )}
      {!openRecentFiles && (
        <React.Fragment>
          <div className={classes.content}>
            <p>{labels.title}</p>
            <p onClick={() => handleRecentFiles()}>{labels.labelOne}</p>
            <p onClick={handleUploadNewFile}>{labels.labelTwo}</p>
          </div>
          <input
            ref={inputFile}
            style={{ display: 'none' }}
            accept={accept}
            type="file"
            onChange={fileChange}            
          />
        </React.Fragment>
      )}
    </div>
  )
}