import React from 'react';
import { makeStyles } from "@material-ui/core";
import Avatar from '@material-ui/core/Avatar';
import EditIcon from '@mui/icons-material/Edit';
import { theme } from './Theme/theme';
import { ThemeTypes } from './Theme/theme.types';

interface AvatarTypes {
  small?: boolean;
  medium?: boolean;
  big?: boolean;
  online?: boolean;
  status?: boolean;
  image?: string;
  name: string;
  editable?: boolean;
  onClick?: () => void;
  editableWidth?: number|string;
  [key: string]: any;
  onClickAvatar?: ()=> void;
}

export const AvatarModule = ({
  small,
  medium,
  big,
  online,
  status,
  image,
  name,
  editable,
  onClick,
  editableWidth,
  onClickAvatar,
  ...props
}: AvatarTypes) => {
  const styles = makeStyles({
    root: {
      width: 'max-content',
      position: 'relative',
      '&>div':{
        height: (props:ThemeTypes ) => props.width || 40,
        width: (props:ThemeTypes ) => props.width || 40,
        fontSize: (props:ThemeTypes ) => props.fontSize || 14,
        '&:hover':{
          border: (props:ThemeTypes) => props.editable &&`1px solid ${theme.bluePrimary}`,
          cursor: (props:ThemeTypes) => props.editable && 'pointer'
        }
      },
      '&>.frontwall':{
        height: (props:ThemeTypes ) => props.width || 40,
        width: (props:ThemeTypes ) => props.width || 40,
        borderRadius: '50%',
        display: 'none',
        '&>svg':{
          border: `1px solid ${theme.defaultSubtitle}`,
          borderRadius: '50%',
          width: editableWidth || 20,
          height: editableWidth || 20,
          padding: 5,
          color: theme.defaultSubtitle,
          backgroundColor: theme.whitePrimary
        }
      },
      "&:hover":{
        '&>.frontwall':{
          display: (props:ThemeTypes) => props.editable && 'flex',
          justifyContent:(props:ThemeTypes) => props.editable && 'center',
          alignItems: (props:ThemeTypes) => props.editable && 'center',
          position: (props:ThemeTypes) => props.editable && 'absolute',
          margin: (props:ThemeTypes) => props.editable && 0,
          padding: (props:ThemeTypes) => props.editable && 0,
          zIndex: (props:ThemeTypes) => props.editable && 98,
          backgroundColor:(props:ThemeTypes) => props.editable &&  theme.whiteOpacity,
          border: (props:ThemeTypes) => props.editable &&`1px solid ${theme.bluePrimary}`,
          cursor: (props:ThemeTypes) => props.editable && 'pointer',
        }
      }
    },
    dot:{
      width: (props:ThemeTypes ) => props.dot,
      height: (props:ThemeTypes ) =>  props.dot,
      margin: 0,
      padding: 0,
      borderRadius: '50%',
      backgroundColor: online ? theme.greenPrimary : theme.borderGreyPrimary,
      border: `1px solid ${online ? theme.greenPrimary : theme.opacityGrayDefault }`,
      marginInlineStart: 'auto',
      marginTop: (props:ThemeTypes ) =>  props.marginTop,
      position: 'relative',
      zIndex: 99
    }
  });
  const widthAndHeightAssigned = () => {
    if(small){
      return {
        width: 40,
        fontSize: 20,
        dot: 12,
        marginTop: -15
      }
    }
    if(medium){
      return {
        width: 60,
        fontSize: 40,
        dot: 12,
        marginTop: -16
      }
    }
    if(big){
      return {
        width: 120,
        fontSize: 70,
        dot: 30,
        marginTop: -35
      }
    }
    else  return {
      width: 40,
      fontSize: 20,
      dot: 12,
      marginTop: -15
    }
  };
  const classes = styles({ 
    width: widthAndHeightAssigned().width, 
    fontSize: widthAndHeightAssigned().fontSize, 
    dot: widthAndHeightAssigned().dot,
    marginTop: widthAndHeightAssigned().marginTop,
    editable: editable || false
  });

  return (
    <div className={classes.root} {...props}>
      <section className='frontwall'><EditIcon onClick={onClick}/></section>
      <Avatar
        src={image}
        onClick={onClickAvatar}
        >
        {name.slice(0,1)}
      </Avatar>
      {status && (
        <section className={classes.dot}/>
      )}
    </div>
  )
}