import React from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';
import { ThemeTypes } from "./Theme/theme.types";
import Button from '@material-ui/core/Button';

interface ButtonProps {
  active?: boolean;
  label: string;
  enabled?: boolean;
  minWidth?: string;
  onClick?: () => void;
  [key: string]: any;
}


export const ButtonForm = ({
  active,
  label,
  enabled,
  minWidth,
  ...props
}: ButtonProps) => {

  const defaultProps = {
    minWidth: 135,
    padding: 10
  }

  const styles = makeStyles({
    /* Button primary */
    rootPrimary: {
      backgroundColor: (props: ThemeTypes) => !props.enabled ? theme.grayPrimary : theme.bluePrimary,
      color: (props: ThemeTypes) => !props.enabled ? theme.blackPrimary : theme.whitePrimary,
      fontWeight: 400,
      fontSize: 16,
      minWidth: (props: ThemeTypes) => props.minWidth || defaultProps.minWidth,
      padding: defaultProps.padding,
      border: `1px solid ${theme.borderGreyPrimary}`,
      '&:hover': {
        backgroundColor: theme.bluePrimary,
        color: theme.whitePrimary
      }
    },
    /* Button Secondary */
    rootSecondary: {
      backgroundColor: theme.whitePrimary,
      color: theme.blackPrimary,
      fontWeight: 400,
      minWidth: (props: ThemeTypes) => props.minWidth || defaultProps.minWidth,
      fontSize: 16,
      padding: defaultProps.padding,
      border: `1px solid ${theme.borderGreyPrimary}`,
      '&:hover': {
        backgroundColor: theme.bluePrimary,
        color: theme.whitePrimary
      }
    }
  });


  const classes = styles({ active, enabled, minWidth });
  return (
    <Button
      className={active ? classes.rootPrimary : classes.rootSecondary}
      {...props}
    >
      {label}
    </Button>
  );
};
