import { makeStyles } from '@material-ui/core';
import React from 'react';
import { DefaultCard } from './DefaultCard';
import PositionFooter from './Types/positionFooter';
import ActionTypes from './Types/actionsTypes';
import { theme } from './Theme/theme';



type Value = string | number | readonly string[] | undefined;

interface DataValue {
  id: string | number
  render: React.ReactNode | undefined
  text?: string
  value: Value
};

export const CardPicker: React.FC<{
  iconColorActions?: string
  actions?: ActionTypes
  onClickDelete?: () => void
  onClickEdit?: () => void
  [key: string]: any
  divider?: boolean
  position?: PositionFooter
  dividerColor?: string
  width?: string | number
  height?: string | number
  value?: DataValue
  data?: DataValue[]
  activeInputFile?: boolean
  onChangeInputFile?: React.ChangeEventHandler<HTMLInputElement> | undefined
  onChange?: (value: DataValue) => void
}> = ({
  value,
  data,
  onChange,
  width,
  height,
  position,
  divider,
  dividerColor,
  actions,
  iconColorActions,
  onClickDelete,
  onClickEdit,
  activeInputFile,
  onChangeInputFile,
  ...props
}) => {
    const styles = makeStyles({
      root: {
        display: 'flex',
        flexWrap: 'wrap',
        alignItems: 'center',
        padding: 0,
        margin: 0,
        listStyle: 'none'
      },
      containerIcons: {
        position: 'absolute',
        marginTop: 10,
        zIndex: 90,
        '&>button': {
          border: `1px solid ${theme.borderGreyPrimary}`,
          width: 40,
          height: 40,
          margin: 5
        }
      },
    });
    const classes = styles();

    return (
      <div className={classes.root} {...props}>
        {Array.isArray(data) && data.map((cardPicker: DataValue, pos: number) => (
          <div key={cardPicker?.id} style={{ paddingLeft: pos !== 0 ? 30 : 0 }}>
            <DefaultCard
              activeInputFile={activeInputFile}
              onChangeInputFile={onChangeInputFile}
              actions={actions}
              onClickEdit={onClickEdit}
              onClickDelete={onClickDelete}
              iconColorActions={iconColorActions}
              width={width}
              height={height}
              footerCard={{ title: cardPicker?.text, position, divider, dividerColor }}
              selected={cardPicker?.value === value}
              onClick={() => typeof onChange === 'function' && onChange(cardPicker)}
            >
              {cardPicker?.render}
            </DefaultCard>
          </div>
        ))}
      </div>
    );
  };

