import React, { useEffect, useState } from 'react';
import { Dropdown } from './Dropdown';

interface DataValue {
  id?: string | number
  title?: string
  reference?: string | number
};
//type Nuevo = Omit<DataValue, 'reference' | 'title'> & { price: number }
interface ObjectValue {
  category?: DataValue
  speciality?: DataValue
  abilities?: DataValue[]
};

export const CategoryDropdown: React.FC<{
  width?: number
  hideSearch?: boolean
  labelCategory?: string
  labelSpeciality?: string
  labelAbility?: string
  max?: number
  values?: ObjectValue
  maxText?: string
  emptyText?: string
  prerequisiteSpeciality?: boolean
  prerequisiteSpecialityText?: string
  prerequisiteAbility?: boolean
  prerequisiteAbilityText?: string
  categories?: DataValue[]
  specialities?: DataValue[]
  abilities?: DataValue[]
  onChange?: (value?: ObjectValue) => void
}> = ({
  width,
  hideSearch,
  labelCategory,
  labelSpeciality,
  labelAbility,
  max,
  values,
  maxText,
  emptyText,
  prerequisiteSpeciality,
  prerequisiteSpecialityText,
  prerequisiteAbility,
  prerequisiteAbilityText,
  categories,
  specialities,
  abilities,
  onChange,
}) => {
    const [category, setCategory] = useState<DataValue>({ id: '', reference: '', title: '' });
    const [speciality, setSpeciality] = useState<DataValue>({ id: '', reference: '', title: '' });
    const [abilitiesData, setAbilitiesData] = useState<DataValue[]>([]);
    const [categorySelected, setCategorySelected] = useState<string | number | undefined>('');
    const [specialitySelected, setSpecilitySelected] = useState<string | number | undefined>('');
    const [abilitiesSelected, setAbilitiesSelected] = useState<DataValue[]>([]);

    useEffect(() => {
      if (values?.category?.id) {
        setCategorySelected(values?.category.id);
      }

      if (values?.speciality?.id) {
        setSpecilitySelected(values.speciality.id);
      }

      if (values && Array.isArray(values?.abilities) && values?.abilities?.length > 0) {
        setAbilitiesData(values?.abilities);
      }
    }, [values]);

    useEffect(() => {
      if (categorySelected) {
        const dataCategories = categories || [];
        const index = dataCategories.findIndex(e => e.id === categorySelected);
        if (index !== -1) {
          setCategory(dataCategories[index]);
        }
      }
    }, [categorySelected]);

    useEffect(() => {
      if (specialitySelected) {
        const dataSpecialities = specialities || [];
        const index = dataSpecialities.findIndex(e => e.id === specialitySelected);
        if (index !== -1) {
          setSpeciality(dataSpecialities[index]);
        }
      }
    }, [specialitySelected]);


    useEffect(() => {
      if (abilitiesSelected.length > 0) {
        let _abilities: DataValue[] = abilitiesSelected;
        _abilities.forEach(ability => {
          const index = _abilities.findIndex(v => v.id === ability.id);
          if (index === -1) _abilities = _abilities.concat(abilities?.filter(v => v.id === ability?.id) || []);
        });
        setAbilitiesData(_abilities);
      } else {
        setAbilitiesData(values && Array.isArray(values?.abilities) && values?.abilities || []);
      }
    }, [abilitiesSelected]);

    const handleCategory = (e: any) => {
      setCategorySelected(!Array.isArray(e) ? e.value : '');
      if (onChange) onChange({
        category: { id: e.value, reference: e.key, title: e.text },
        speciality: { id: '', reference: '', title: '' },
        abilities: []
      });
      setSpeciality({ id: '', reference: '', title: '' });
      setSpecilitySelected('');
      setAbilitiesSelected([]);
      setAbilitiesData([]);
    };

    const handleSpecialities = (e: any) => {
      setSpecilitySelected(!Array.isArray(e) ? e.value : '');
      if (onChange) onChange({
        category,
        speciality: { id: e.value, reference: e.key, title: e.text },
        abilities: []
      });
      setAbilitiesData([]);
      setAbilitiesSelected([]);
    };

    const handleAbilities = (e: { value?: string | number, key?: string | number, text?: string }[]) => {
      if (Array.isArray(e) && e.length > 0) {
        const selected: DataValue[] = [];
        abilities?.forEach(v => {
          const equal = e.some(k => k.value === v.id);
          if (equal) selected.push(v);
        });
        setAbilitiesSelected(selected);
        if (onChange) onChange({
          category,
          speciality,
          abilities: selected
        });
      } else {
        setAbilitiesSelected([]);
        if (onChange) onChange({
          category,
          speciality,
          abilities: []
        });
      }
    };

    return (
      <div>
        <div style={{ marginTop: 20 }}>
          <Dropdown
            width={width}
            label={labelCategory}
            emptyText={emptyText}
            hideSearch={hideSearch}
            value={categorySelected}
            onChange={handleCategory}
            data={categories?.map(e => ({ text: e.title, key: e.id, value: e.id }))} />
        </div>
        <div style={{ marginTop: 20 }}>
          <Dropdown
            width={width}
            emptyText={emptyText}
            prerequisite={prerequisiteSpeciality}
            prerequisiteText={prerequisiteSpecialityText}
            label={labelSpeciality}
            hideSearch={hideSearch}
            value={specialitySelected}
            onChange={handleSpecialities}
            data={specialities?.map(e => ({ text: e.title, key: e.id, value: e.id }))} />
        </div>
        <div style={{ marginTop: 20 }}>
          <Dropdown
            width={width}
            prerequisite={prerequisiteAbility}
            prerequisiteText={prerequisiteAbilityText}
            hideSearch={hideSearch}
            multiple
            max={max}
            emptyText={emptyText}
            maxText={maxText}
            label={labelAbility}
            values={abilitiesData.map(e => ({ text: e.title, value: e.id, key: e.id }))}
            onChangeValues={(data: { value?: string | number, key?: string | number, text?: string }[]) => handleAbilities(data)}
            data={abilities?.map(e => ({ text: e.title, key: e.id, value: e.id }))} />
        </div>
      </div>
    );
  };