import React, { useState, useEffect } from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';

import { Error } from './Error';
import TextField from '@material-ui/core/TextField';
import IconButton from '@material-ui/core/IconButton';
import InputAdornment from '@material-ui/core/InputAdornment';
import KeyboardArrowUpIcon from '@mui/icons-material/KeyboardArrowUp';
import KeyboardArrowDownIcon from '@mui/icons-material/KeyboardArrowDown';
import SearchIcon from '@mui/icons-material/Search'


import { CategoriesConstants } from './Types/categoryTypes';


interface CategoryTypes {
  id?: string
  disabled?: boolean
  type?: string
  handleChange?: any
  value?: string
  valuesAbilities?: any
  MaterialIcon?: any
  label?: string
  name?: any
  onMouseEnter?: any
  onMouseLeave?: any
  listCategories?: any
  listSpecialities?: any
  listTags?: any
  dataSection?: string
  selectedCategory?: { title: string; id: string; reference: string }
  setSelectedCategory: (value: { title: string; id: string; reference: string }) => void | any
  selectedSpeciality?: { title: string; id: string; reference: string }
  setSelectedSpeciality: (value: { title: string; id: string; reference: string }) => void | any
  selectedAbility?: any
  setSelectedAbility: (value: any) => void | any
  relationSpecialityCategory?: any
  relationAbilitySpeciality?: any
  maxTags: number
  error?: boolean
  listLabels: { [key: string]: string };
  [key: string]: any;
}

export const CategorySelectors = ({
  id,
  handleChange,
  value,
  disabled,
  MaterialIcon,
  label,
  name,
  onMouseEnter,
  onMouseLeave,
  type,
  listCategories,
  listSpecialities,
  listTags,
  dataSection,
  selectedCategory,
  setSelectedCategory,
  selectedSpeciality,
  setSelectedSpeciality,
  selectedAbility,
  setSelectedAbility,
  relationSpecialityCategory,
  relationAbilitySpeciality,
  maxTags,
  error,
  listLabels,
  ...props
}: CategoryTypes) => {
  const styles = makeStyles({
    backWall: {
      position: 'fixed',
      width: '100%',
      height: '100%',
      zIndex: 998,
      left: 0,
      top: 0,
      right: 0,
    },
    root: {
      display: 'flex',
      flexDirection: 'column',
      alignSelf: 'center',
      width: '100%',
      borderRadius: 6,
      position: 'relative',
      zIndex: (props: any) => props.zIndex,
      '& > .MuiPaper-elevation3': {
        boxShadow: 'none',
        backgroundColor: 'white',
      },
    },
    field: {
      borderBottom: (props: any) => props.borderBottom,
      width: '100%',
      outline: 'none',
      borderRadius: 4,
      '& > .MuiInputBase-root': {
        marginTop: '1px',
        fontWeight: 300,
        fontSize: 16,
        borderRadius: '4px',
        '& > .MuiInputBase-input': {
          paddingLeft: '20px',
          paddingRight: '20px',
          paddingTop: '24px',
          paddingBottom: '15px',
          color: theme.blackPrimary,
          padding: '0px',
          borderRadius: '4px',
          backgroundColor: "transparent !important",
          zIndex: 100,
          '&:focus': {
            border: 'none',
          },
        },
      },
      '& > .MuiInput-root': {
        backgroundColor: theme.whitePrimary,
      },
      '& > .MuiInput-underline:before': {
        borderBottom: 'none',
        content: 'none',
      },
      '& > .MuiInput-underline:after': {
        backgroundColor: 'white',
        borderBottom: 'none',
      },
      '& > .MuiInput-underline:hover': {
        backgroundColor: theme.whitePrimary,
      },
      '& > .MuiInputLabel-animated': {
        color: 'grey',
        zIndex: 99,
        marginTop: 0,
        paddingTop: 8,
        paddingLeft: 15,
        fontSize: 16,
        transition:
          'color 200ms cubic-bezier(0.0, 0, 0.2, 1) 0ms,transform 200ms cubic-bezier(0.0, 0, 0.2, 1) 0ms',
      },
      '& > .MuiInputLabel-root:before': {
        color: theme.bluePrimary,
      },
    },
    fieldSearch: {
      border: `1px solid ${theme.bluePrimary}`,
      width: '100%',
      outline: 'none',
      borderRadius: 4,
      postion: 'relative',
      '& > .MuiInputBase-root': {
        marginTop: 1,
        borderRadius: 4,
        '& > .MuiInputBase-input': {
          paddingLeft: 20,
          paddingRight: 20,
          paddingTop: 24,
          paddingBottom: 15,
          color: '#000c24',
          padding: 0,
          borderRadius: 4,
          backgroundColor: 'transparent',
          zIndex: (props: any) => props.zIndex,
          '&:focus': {
            border: 'none',
          },
        },
      },
      '& > .MuiInput-root': {
        backgroundColor: theme.whitePrimary,
      },
      '& > .MuiInput-underline:before': {
        borderBottom: 'none',
        content: 'none',
      },
      '& > .MuiInput-underline:after': {
        backgroundColor: theme.whitePrimary,
        borderBottom: 'none',
      },
      '& > .MuiInput-underline:hover': {
        backgroundColor: theme.whitePrimary,
      },
      '& > .MuiInputLabel-animated': {
        color: 'grey',
        zIndex: 99,
        marginTop: 0,
        paddingTop: 8,
        paddingLeft: 15,
        fontSize: 16,
        transition:
          'color 200ms cubic-bezier(0.0, 0, 0.2, 1) 0ms,transform 200ms cubic-bezier(0.0, 0, 0.2, 1) 0ms',
      },
      '& > .MuiInputLabel-root:before': {
        color: 'blue',
      },
    },
    arrow: {
      color: theme.defaultSubtitle,
      width: '35px !important',
      height: '35px !important',
      borderRadius: '50%',
      cursor: 'pointer',
      border: `1px solid ${theme.borderGreyPrimary}`
    },
    selector: {
      border: `1px solid ${theme.borderGreyPrimary}`,
      minHeight: 190,
      backgroundColor: theme.whitePrimary,
    },
    inputSearch: {
      padding: 25,
    },
    containerResults: {
      maxHeight: 150,
      height: 'min-content',
      overflowX: 'auto',
      marginTop: 15,
    },
    results: {
      fontSize: 15,
      '&>p': {
        padding: '6px 6px 6px 4px',
        margin: 0,
        '&:hover': {
          backgroundColor: theme.hoverBlue,
          cursor: 'pointer',
        },
      },
    },
    noResults: {
      textAlign: 'center',
      marginTop: 15,
    },
    errorMaxTags: {
      display: 'flex',
      justifyContent: 'center',
      '&>div': {
        width: 300,
        textAlign: 'center',
      },
    },
    containerTags: {
      border: `1px solid ${theme.borderGreyPrimary}`,
      marginTop: 10,
      padding: 15,
    },
    subContainerTags: {
      display: 'flex',
      flexFlow: 'wrap',
    },
    tag: {
      backgroundColor: theme.grayPrimary,
      borderRadius: 4,
      margin: 10,
      width: 'max-content',
      padding: 8,
      display: 'flex',
    },
    tagTitle: {
      fontSize: 14,
    },
    crossTag: {
      marginLeft: 20,
      '&:hover': {
        fontWeight: 700,
        cursor: 'pointer',
      },
    },
    tagsContainer: {
      display: 'flex',
      flexWrap: 'wrap',
      borderLeft: theme.borderGreyPrimary,
      borderRight: theme.borderGreyPrimary,
    },
    searchIcon: {
      border: `1px solid ${theme.borderGreyPrimary}`,
      width: 30,
      height: 30,
      padding: 5,
      borderRadius: '50%'
    }
  });
  const [upArrow, setUpArrow] = useState(false)
  const [listDataCategories, setListDataCategories] = useState([])
  const [listDataSpecialities, setListDataSpecialities] = useState([])
  const [listDataTags, setListDataTags] = useState([])
  const [alertMaxTag, setAlertMaxTag] = useState(false)
  const classes = styles({
    border: upArrow ? `1px solid ${theme.borderGreyPrimary}` : `1px solid ${theme.bluePrimary}`,
    borderBottom: upArrow ? `1px solid ${theme.bluePrimary}` : `1px solid ${theme.borderGreyPrimary}`,
    zIndex: upArrow ? 999 : 10,
  });

  const handleChangeIcon = () => {
    setUpArrow(!upArrow)
  }

  useEffect(() => {
    listCategories && listCategories !== 'PENDING' && setListDataCategories(listCategories || [])
  }, [listCategories])

  useEffect(() => {
    listSpecialities &&
      listSpecialities !== 'PENDING' &&
      relationSpecialityCategory &&
      relationSpecialityCategory.reference !== '' &&
      setListDataSpecialities(listSpecialities || [])
  }, [listSpecialities, relationSpecialityCategory])

  useEffect(() => {
    if (
      listTags &&
      listTags !== 'PENDING' &&
      relationAbilitySpeciality &&
      relationAbilitySpeciality.reference !== ''
    ) {
      setListDataTags(listTags)
    } else {
      setListDataTags([])
      setAlertMaxTag(false)
      setUpArrow(false)
    }
  }, [listTags, relationAbilitySpeciality])

  /* regulacion de cooerencia de valores segun relacionamiento de categorias 
    Ej: si el usuario cambia de categoria ya teneiendo una especialidad seleccionada
    y la categoria no tiene relacion con la especialidad => los valores de la especialidad 
    se deben eliminar ya que no existe relacion con la categoria.
    Lo mismo aplica para Habilidades en relacion con Especialidades.
  */
  useEffect(() => {
    if (
      relationSpecialityCategory &&
      relationSpecialityCategory.reference &&
      selectedSpeciality &&
      selectedSpeciality.reference
    ) {
      if (selectedSpeciality?.reference !== relationSpecialityCategory?.reference) {
        setSelectedSpeciality({ title: '', id: '', reference: '' })
      }
    }
  }, [relationSpecialityCategory, selectedSpeciality])

  useEffect(() => {
    if (
      dataSection === CategoriesConstants.ABILITY &&
      relationAbilitySpeciality &&
      relationAbilitySpeciality.reference === ''
    )
      setSelectedAbility([])
  }, [relationAbilitySpeciality])

  useEffect(() => {
    if (dataSection === CategoriesConstants.ABILITY) {
      if (selectedAbility && selectedAbility.length < maxTags) {
        setAlertMaxTag(false)
      }
    }
  }, [selectedAbility])

  /* limpieza de input Search segun event key y seccion del input */
  const handleOnPressKey = (event: any, dataSection: any) => {
    if (event === 'Backspace' || event === 'Delete') {
      switch (dataSection) {
        case CategoriesConstants.CATEGORY:
          setSelectedCategory && setSelectedCategory({ title: '', id: '', reference: '' })
          break
        case CategoriesConstants.SPECIALITY:
          setSelectedSpeciality && setSelectedSpeciality({ title: '', id: '', reference: '' })
          break
        default:
      }
    }
  }
  /* seleccion de valores */
  const handleClick = (dataSection: any, data: any) => {
    switch (dataSection) {
      case CategoriesConstants.CATEGORY:
        setSelectedCategory && setSelectedCategory({ title: data.title, id: data.id, reference: data.id })
        setUpArrow(!upArrow)
        break
      case CategoriesConstants.SPECIALITY:
        setSelectedSpeciality && setSelectedSpeciality({ title: data.title, id: data.id, reference: data.abilityParentId })
        setUpArrow(!upArrow)
        break
      case CategoriesConstants.ABILITY:
        if (selectedAbility && selectedAbility.length < maxTags) {
          setSelectedAbility && setSelectedAbility([
            ...selectedAbility.filter((tags: any) => tags.id !== data.id),
            { title: data.title, id: data.id, reference: data.specialityParentId },
          ])
          setAlertMaxTag(false)
        } else {
          setAlertMaxTag(true)
        }
        break
      default:
    }
  }
  /* Retorno de valores seleccionados */
  const returnResults = (listDataCategories: any, dataSection: any) => {
    if (listDataCategories && listDataCategories.length > 0) {
      switch (dataSection) {
        case CategoriesConstants.CATEGORY:
          return (
            listDataCategories &&
            listDataCategories.map((data: any) => (
              <div className={classes.results}>
                <p onClick={() => handleClick(dataSection, data)}>{data.title}</p>
              </div>
            ))
          )
        case CategoriesConstants.SPECIALITY:
          return (
            listDataSpecialities &&
            listDataSpecialities.map((data: any) => (
              <div className={classes.results}>
                <p onClick={() => handleClick(dataSection, data)}>{data.title}</p>
              </div>
            ))
          )
        case CategoriesConstants.ABILITY:
          return !alertMaxTag ? (
            listDataTags &&
            listDataTags.map((data: any) => (
              <div className={classes.results}>
                <p onClick={() => handleClick(dataSection, data)}>{data.title}</p>
              </div>
            ))
          ) : (
            <div className={classes.results} style={{ overflow: 'hidden' }}>
              <div className={classes.errorMaxTags}>
                <Error title={listLabels.maxTag} />
              </div>
            </div>
          )
        default:
      }
    }
  }
  /* Retorno de resultados filtrados */
  const handleFilterResults = (event: any, dataSection: any) => {
    switch (dataSection) {
      case CategoriesConstants.CATEGORY:
        if (event && listCategories && listCategories.length > 0) {
          setListDataCategories(
            listCategories.filter((category: any) =>
              category.title.toLowerCase().includes(event.toLowerCase())
            )
          )
        } else {
          setListDataCategories(listCategories || [])
        }
        break
      case CategoriesConstants.SPECIALITY:
        if (event.length > 0 && listSpecialities && listSpecialities.length > 0) {
          setListDataSpecialities(
            listSpecialities.filter((speciality: any) =>
              speciality.title.toLowerCase().includes(event.toLowerCase())
            )
          )
        } else {
          setListDataSpecialities(listSpecialities || [])
        }
        break
      case CategoriesConstants.ABILITY:
        if (!alertMaxTag) {
          if (event && listTags && listTags.length > 0) {
            setListDataTags(
              listTags.filter((tag: any) => tag.title.toLowerCase().includes(event.toLowerCase()))
            )
          } else {
            setListDataTags(listTags || [])
          }
        }
        break
      default:
    }
  }

  /* Retorno de valores para inputs Search */
  const handleValues = (dataSection: any) => {
    switch (dataSection) {
      case CategoriesConstants.CATEGORY:
        return selectedCategory && selectedCategory.title !== '' ? selectedCategory.title : null
      case CategoriesConstants.SPECIALITY:
        return selectedSpeciality && selectedSpeciality.title !== ''
          ? selectedSpeciality.title
          : null
      case CategoriesConstants.ABILITY:
        break
      default:
        return ""
    }
  }

  const removeTag = (selectedAbility: any, tag: any) => {
    if (selectedAbility && selectedAbility.length > 0 && tag) {
      setSelectedAbility && setSelectedAbility(selectedAbility.filter((tags: any) => tags.id !== tag.id))
    }
  }

  const ListTagsSelected = (selectedAbility: any) => {
    if (selectedAbility && selectedAbility.length > 0) {
      return (
        <div
          style={{ borderBottom: upArrow ? `1px solid ${theme.bluePrimary}` : `1px solid ${theme.borderGreyPrimary}` }}
          className={classes.tagsContainer}
        >
          {selectedAbility.map((tag: any) => (
            <div className={classes.tag}>
              <p className={classes.tagTitle}>{tag.title}</p>
              <p className={classes.crossTag} onClick={() => removeTag(selectedAbility, tag)}>
                x
              </p>
            </div>
          ))}
        </div>
      )
    }
  }


  return (
    <>
      {upArrow && <div className={classes.backWall} onClick={() => handleChangeIcon()} />}
      <div
        className={classes.root}
        style={{ border: upArrow ? `1px solid ${theme.bluePrimary}` : `1px solid ${theme.borderGreyPrimary}` }}
        onClick={() => handleChangeIcon()}
        {...props}
      >
        {dataSection !== CategoriesConstants.ABILITY && (
          <TextField
            className={classes.field}
            id={id}
            type={type}
            value={value}
            onChange={handleChange}
            label={label}
            onMouseEnter={onMouseEnter}
            onMouseLeave={onMouseLeave}
            fullWidth
            autoComplete="off"
            disabled
            name={name || null}
            InputProps={{
              endAdornment: (
                <InputAdornment position="start">
                  <div style={{ paddingRight: '12px' }} onClick={() => handleChangeIcon()}>
                    {MaterialIcon || !upArrow ? (
                      <IconButton style={{ width: 30, height: 30 }}>
                        <KeyboardArrowDownIcon className={classes.arrow} />
                      </IconButton>
                    ) : (
                      <IconButton style={{ width: 30, height: 30 }}>
                        <KeyboardArrowUpIcon
                          className={classes.arrow}
                          style={{ border: `1px solid ${theme.bluePrimary}` }}
                        />
                      </IconButton>
                    )}
                  </div>
                </InputAdornment>
              ),
            }}
          />
        )}

        {dataSection === CategoriesConstants.ABILITY && (
          <TextField
            className={classes.field}
            id={id}
            type={type}
            value={value}
            onChange={handleChange}
            label={label}
            onMouseEnter={onMouseEnter}
            onMouseLeave={onMouseLeave}
            fullWidth
            autoComplete="off"
            disabled
            style={{
              borderBottom:
                dataSection === CategoriesConstants.ABILITY &&
                  selectedAbility &&
                  selectedAbility.length > 0
                  ? `1px solid ${theme.whitePrimary}`
                  : upArrow
                    ? `1px solid ${theme.bluePrimary}`
                    : `1px solid ${theme.borderGreyPrimary}`,
              borderBottomLeftRadius:
                dataSection === CategoriesConstants.ABILITY &&
                  selectedAbility &&
                  selectedAbility.length > 0
                  ? 0
                  : 2,
              borderBottomRightRadius:
                dataSection === CategoriesConstants.ABILITY &&
                  selectedAbility &&
                  selectedAbility.length > 0
                  ? 0
                  : 2,
            }}
            name={name || null}
            InputProps={{
              endAdornment: (
                <InputAdornment position="start">
                  <div style={{ paddingRight: '12px' }} onClick={() => handleChangeIcon()}>
                    {MaterialIcon || !upArrow ? (
                      <IconButton style={{ width: 20, height: 20 }}>
                        <KeyboardArrowDownIcon className={classes.arrow} />
                      </IconButton>
                    ) : (
                      <IconButton style={{ width: 20, height: 20 }}>
                        <KeyboardArrowUpIcon
                          className={classes.arrow}
                          style={{ border: `1px solid ${theme.bluePrimary}` }}
                        />
                      </IconButton>
                    )}
                  </div>
                </InputAdornment>
              ),
            }}
          />
        )}

        {dataSection === CategoriesConstants.ABILITY &&
          selectedAbility &&
          selectedAbility.length > 0 && <>{ListTagsSelected(selectedAbility)}</>}

        {upArrow && (
          <div>
            <div className={classes.inputSearch}>
              <TextField
                className={classes.fieldSearch}
                id={id}
                type={type}
                value={
                  dataSection !== CategoriesConstants.ABILITY ? handleValues(dataSection) : null
                }
                onChange={(event) => handleFilterResults(event.target.value, dataSection)}
                onKeyDown={(event) =>
                  dataSection !== CategoriesConstants.ABILITY &&
                  handleOnPressKey(event.key, dataSection)
                }
                label={listLabels.search}
                onMouseEnter={onMouseEnter}
                onMouseLeave={onMouseLeave}
                fullWidth
                autoComplete="off"
                disabled={disabled}
                autoFocus
                name={name || null}
                InputProps={{
                  endAdornment: (
                    <InputAdornment position="start">
                      <div style={{ paddingRight: '12px' }}>
                        <IconButton style={{ width: 30, height: 30 }}>
                          <SearchIcon className={classes.searchIcon} />
                        </IconButton>
                      </div>
                    </InputAdornment>
                  ),
                }}
              />
              {dataSection === CategoriesConstants.CATEGORY &&
                upArrow &&
                listDataCategories &&
                listDataCategories.length > 0 && (
                  <div className={classes.containerResults}>
                    {returnResults(listDataCategories, dataSection)}
                  </div>
                )}
              {dataSection === CategoriesConstants.CATEGORY &&
                (!listDataCategories || listDataCategories.length === 0) && (
                  <p className={classes.noResults}>{listLabels.noResults}</p>
                )}
              {dataSection === CategoriesConstants.SPECIALITY &&
                upArrow &&
                listDataSpecialities &&
                listDataSpecialities.length > 0 && (
                  <div className={classes.containerResults}>
                    {returnResults(listDataSpecialities, dataSection)}
                  </div>
                )}
              {dataSection === CategoriesConstants.SPECIALITY &&
                (!listDataSpecialities || listDataSpecialities.length === 0) &&
                (relationSpecialityCategory && relationSpecialityCategory.reference !== '' ? (
                  <p className={classes.noResults}>{listLabels.noResults}</p>
                ) : (
                  <p className={classes.noResults}>{listLabels.noCategory}</p>
                ))}
              {dataSection === CategoriesConstants.ABILITY &&
                upArrow &&
                listDataTags &&
                listDataTags.length > 0 && (
                  <div className={classes.containerResults}>
                    {returnResults(listDataTags, dataSection)}
                  </div>
                )}
              {dataSection === CategoriesConstants.ABILITY &&
                (!listDataTags || listDataTags.length === 0) &&
                (relationAbilitySpeciality && relationAbilitySpeciality.reference !== '' ? (
                  <p className={classes.noResults}>{listLabels.noResults}</p>
                ) : (
                  <p className={classes.noResults}>{listLabels.noSpeciality}</p>
                ))}
            </div>
          </div>
        )}
      </div>

      {error && dataSection === CategoriesConstants.CATEGORY && (
        <Error title={listLabels.errorCategory} />
      )}
      {error && dataSection === CategoriesConstants.SPECIALITY && (
        <Error title={listLabels.errorSpeciality} />
      )}
      {error && dataSection === CategoriesConstants.ABILITY && <Error title={listLabels.errorTag} />}
    </>
  )
}