import React, { useState } from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';

import { ChatMessagesListTypes } from './Types/chatMessages';
import { FormatNameAWS, HourChat } from './helpers/fileTypes';

/* Components */
import { AvatarModule } from './Avatar';
import { RenderFile } from './RenderFile';
import { DefaultModal } from './DefaultModal';

import ErrorIcon from '@mui/icons-material/Error';

type FileType = {
  id: string;
  name: string;
  type: string;
  size: string;
  url: string;
}

interface ChatRoomTypes {
  [key: string]: any;
  listMessages?: ChatMessagesListTypes[];
  ReturnNotification?: (v?: ChatMessagesListTypes) => React.ReactNode;
  ReturnHistoricalMessage?: (v?: ChatMessagesListTypes) => React.ReactNode;
  userRoom?: string | null;
  userById_UserId?: string | null;
  loggedUser_Id?: string | null;
  lng?: string;
  onClickAvatar?: () => void;
  onClickSeeMore?: () => void;
  seeMoreLimit?: number;
  activeHistory?: (message?: any) => void;
  readHistory?: (message?: any) => void;

}

export const ChatRoom = ({
  listMessages,
  ReturnHistoricalMessage,
  ReturnNotification,
  userById_UserId,
  loggedUser_Id,
  userRoom,
  lng,
  onClickAvatar,
  onClickSeeMore,
  seeMoreLimit,
  activeHistory,
  readHistory,
  ...props }: ChatRoomTypes) => {
  const styles = makeStyles({
    root: {
      width: "100%",
      overflow: "scroll",
      overflowX: "hidden",
      height: "100%",
      behavior: 'smooth',
      block: 'end',
      display: "flex",
      justifyContent: "flex-start",
      flexFlow: "column-reverse",
      inline: 'nearest',
      '&::-webkit-scrollbar': {
        width: "5px",
        backgroundColor: "#F2F4F6",
      },
      '&::-webkit-scrollbar-thumb': {
        backgroundColor: "#93A0AD",
        borderRadius: "238px",
      },
      "&::-webkit-scrollbar-track": {
        marginBottom: "70px",

      },
    },
    contentModal: {
      width: 'fit-content',
      height: 'fit-content',
      maxWidth: 530,
      maxHeight: 760,
      overflow: 'auto',
      "&>div>div": {
        maxHeight: `520px !important`,
        maxWidth: 450,
        overflow: 'auto',
        '&::-webkit-scrollbar': {
          width: "5px",
          height: "5px",
          backgroundColor: theme.grayPrimary,
        },
        '&::-webkit-scrollbar-thumb': {
          backgroundColor: theme.opacityGrayDefault,
          borderRadius: "20px",
        },
        "&::-webkit-scrollbar-track": {
          marginBottom: "1px",
        },
      }
    },
    rowLeft: {
      display: 'flex',
      margin: '20px 20px 20px 20px',
      flexFlow: 'wrap'
    },
    rowRight: {
      display: 'flex',
      margin: '20px 20px 20px 20px',
      flexFlow: 'wrap',
      justifyContent: 'flex-end'
    },
    containerMsgLeft: {
      backgroundColor: '#f2f4f6',
      width: 287,
      padding: 10,
      borderRadius: '0px 24px 24px 24px',
      marginLeft: 12,
      display: 'block !important',
      position: 'relative',
    },
    containerError: {
      width: 40,
      height: 40,
      borderRadius: '50%',
      "&>svg": {
        color: theme.backgroundRed,
        background: theme.redPrimary,
        borderRadius: '50%',
        width: 40,
        height: 40
      }
    },
    containerMsgRight: {
      backgroundColor: '#e5e9ff',
      width: 287,
      padding: 10,
      borderRadius: '24px 0px 24px 24px',
      marginRight: 10,
      display: 'block !important',
      position: 'relative',
    },
    textMessage: {
      color: '#424a59',
      marginBottom: 10,
      marginLeft: 12,
    },
    textMessageCensored: {
      color: '#424a59',
      marginBottom: 10,
      marginLeft: 12,
      textDecorationLine: "line-through"
    },
    hour: {
      color: '#93a0ad',
      marginLeft: 10,
      marginTop: 8,
      margin: 'inherit',
    },
    containerFile: {
      maxHeight: 50,
      maxWidth: 50,
      margin: 'auto',
      "&>div>div": {
        maxWidth: 50,
        maxHeight: 50,
        "&>img": {
          maxHeight: 50,
          maxWidth: 50,
        }
      }
    },
    textFile: {
      color: '#424a59',
      fontSize: 14,
      margin: 'auto',
      textAlign: 'center',
      marginTop: 5,
    },
    textAlertCensoredLeft: {
      color: theme.redPrimary,
      display: 'flex',
      justifyContent: 'flex-start',
      flexFlow: 'wrap',
      marginLeft: 80,
      "&>p": {
        maxWidth: 287
      }
    },
    textAlertCensoredRight: {
      color: theme.redPrimary,
      display: 'flex',
      justifyContent: 'flex-end',
      flexFlow: 'wrap',
      marginRight: 80,
      "&>p": {
        maxWidth: 287
      }
    },
    seeMoreContainer: {
      borderBottom: `1px solid ${theme.grayPrimary}`,
      marginBottom: 15,
      padding: 20,
      '&>p': {
        color: theme.opacityGrayDefault,
        textAlign: 'center',
        '&:hover': {
          color: theme.bluePrimary,
          cursor: 'pointer',
          fontWeight: 700
        }
      }
    }
  });

  const classes = styles();
  const [openModal, setOpenModal] = useState(false);
  const initialStateFile = { id: '', name: '', type: '', size: '', url: '' }
  const [selectedFile, setSelectedFile] = useState(initialStateFile)


  const handleOpenFile = (file: FileType) => {
    setSelectedFile(file)
    setOpenModal(!openModal)
  }

  const handlePreview = () => {
    selectedFile.type !== 'application/zip' && setOpenModal(!openModal)
  }

  const ContentModal = () => {
    return (
      <div>
        <RenderFile
          selectedFile={selectedFile}
          renderType="preview"
          lng={lng}
          handlePreview={handlePreview}
          file={selectedFile}
        />
      </div>
    )
  }

  const CreateObjectFile = (file: ChatMessagesListTypes) => {
    const newObjectFile: FileType = {
      id: file['id'] || "",
      url: file['file'] || "",
      type: file['fileType'] || "",
      size: file['fileSize'] || "",
      name: file['fileName'] || ""
    }
    return newObjectFile
  }

  const CensoredMessage = (censoredLow?: boolean, censoredHight?: boolean, lng?: string) => {
    if (censoredHight) {
      const esText = "Este comentario ha sido clasificado como ofensivo o ir en contra de nuestros términos de uso.";
      const enText = "This comment has been classified as offensive or against our terms of use."
      const text = lng === 'en' ? enText : esText
      return text
    }
    if (censoredLow && !censoredHight) {
      const esText = "Este comentario puede ser ofensivo o ir en contra de nuestros términos de uso."
      const enText = "This comment may be offensive or go against our terms of use."
      const text = lng === 'en' ? enText : esText
      return text
    }
    return ""
  }

  const viewMoreLimit = seeMoreLimit || 49;

  return (
    <React.Fragment>
      <div className={classes.root} {...props}>
        {listMessages && listMessages.length > 0 && listMessages.map((message, index) => (
          <div key={message.id || index}>
            {openModal && (
              <DefaultModal
                open={openModal}
                setOpen={setOpenModal}
                handleClose={() => setOpenModal(false)}
                content={ContentModal()}
                width={'fit-content'}
                height={'fit-content'}
                classContent={classes.contentModal}
              />
            )}
            {message.userEmisor === userById_UserId && message.userEmisor === userRoom ?
              (
                <div>
                  {ReturnNotification && ReturnNotification(message)}
                  {/* Left Messages */}
                  {message.type !== 'HISTORICAL' ? (
                    <React.Fragment>
                      <div className={classes.rowLeft}>
                        {(message.censoredLow || message.censoredHight) ? (
                          <div className={classes.containerError}>
                            <ErrorIcon />
                          </div>
                        ) : (
                          <AvatarModule
                            small
                            name={message.emisorName || ""}
                            image={message.avatar || ""}
                            onClickAvatar={onClickAvatar}
                          />
                        )}
                        <div className={classes.containerMsgLeft} style={{ filter: message.censoredHight ? 'blur(4px)' : "" }}>
                          <p className={
                            message.censoredLow ?
                              classes.textMessageCensored
                              : classes.textMessage
                          }>{message.message}</p>
                          {message.file && (
                            <div className={classes.containerFile}>
                              <RenderFile
                                selectedFile={CreateObjectFile(message)}
                                renderType="icon"
                                lng={lng}
                                handlePreview={() => handleOpenFile(CreateObjectFile(message))}
                                file={CreateObjectFile(message)}
                              />
                            </div>
                          )}
                          {message.file && (
                            <p className={classes.textFile}>{FormatNameAWS(CreateObjectFile(message).name)}</p>
                          )}
                        </div>
                        <p className={classes.hour}>{HourChat(message.hour || "")}</p>
                      </div>
                      {(message.censoredLow || message.censoredHight) && (
                        <div className={classes.textAlertCensoredLeft}>
                          <p>{CensoredMessage(message.censoredLow, message.censoredHight, lng)}</p>
                        </div>
                      )}
                      <>
                        {activeHistory ? activeHistory(message) : null}
                        {readHistory ? readHistory(message) : null}
                      </>
                    </React.Fragment>
                  ) : (
                    <React.Fragment>
                      {ReturnHistoricalMessage && ReturnHistoricalMessage(message)}
                    </React.Fragment>
                  )}
                </div>
              )
              :
              (
                <React.Fragment>
                  {message.userEmisor === loggedUser_Id ?
                    (
                      <div>
                        {ReturnNotification && ReturnNotification(message)}
                        {/* Right Messages */}
                        {message.type !== "HISTORICAL" &&
                          (
                            <React.Fragment>
                              <>
                                {activeHistory ? activeHistory(message) : null}
                                {readHistory ? readHistory(message) : null}
                              </>
                              <div className={classes.rowRight}>
                                <p className={classes.hour}>{HourChat(message.hour || "")}</p>
                                <div className={classes.containerMsgRight} style={{ filter: message.censoredHight ? 'blur(4px)' : "" }}>
                                  <p className={
                                    message.censoredLow ?
                                      classes.textMessageCensored
                                      : classes.textMessage
                                  }>{message.message}</p>
                                  {message.file && (
                                    <div className={classes.containerFile}>
                                      <RenderFile
                                        selectedFile={CreateObjectFile(message)}
                                        renderType="icon"
                                        lng={lng}
                                        handlePreview={() => handleOpenFile(CreateObjectFile(message))}
                                        file={CreateObjectFile(message)}
                                      />
                                    </div>
                                  )}
                                  {message.file && (
                                    <p className={classes.textFile}>{FormatNameAWS(CreateObjectFile(message).name)}</p>
                                  )}
                                </div>
                                {(message.censoredLow || message.censoredHight) ? (
                                  <div className={classes.containerError}>
                                    <ErrorIcon />
                                  </div>
                                ) : (
                                  <AvatarModule
                                    small
                                    name={message.emisorName || ""}
                                    image={message.avatar || ""}
                                    onClickAvatar={onClickAvatar}
                                  />
                                )}
                              </div>
                              {(message.censoredLow || message.censoredHight) && (
                                <div className={classes.textAlertCensoredRight}>
                                  <p>{CensoredMessage(message.censoredLow, message.censoredHight, lng)}</p>
                                </div>
                              )}
                            </React.Fragment>
                          )
                        }
                        {message.type === 'HISTORICAL' && (
                          <React.Fragment>
                            {ReturnHistoricalMessage && ReturnHistoricalMessage(message)}
                          </React.Fragment>
                        )}
                      </div>
                    )
                    : (<React.Fragment />)
                  }
                </React.Fragment>
              )}
          </div>
        ))}
        {listMessages && listMessages.length > viewMoreLimit && (
          <div className={classes.seeMoreContainer} onClick={onClickSeeMore}>
            <p>{lng === 'en' ? 'See more' : 'Ver mas'}</p>
          </div>
        )}
      </div>
    </React.Fragment>
  )
}