import React, { MouseEventHandler, useState } from 'react';
import { makeStyles, IconButton } from '@material-ui/core';
import { theme } from './Theme/theme';
import { ThemeTypes } from './Theme/theme.types';
import { CardWithImg } from './cardWithImg';
import { CardFooter } from './cardFooter';
import PositionFooter from './Types/positionFooter';
import ActionTypes from './Types/actionsTypes';

/* Icons */
import EditIcon from '@mui/icons-material/Edit';
import DeleteOutlineIcon from '@mui/icons-material/DeleteOutline';
import { UploadFileWithIcon } from './UploadFileWithIcon';

export const DefaultCard: React.FC<{
  src?: string | undefined
  type?: string | undefined
  selected?: boolean
  width?: string | number
  height?: string | number
  iconColorActions?: string
  actions?: ActionTypes
  activeInputFile?: boolean
  onChangeInputFile?: React.ChangeEventHandler<HTMLInputElement> | undefined
  onClickDelete?: () => void
  onClickEdit?: () => void
  onClick?: MouseEventHandler<HTMLDivElement> | undefined
  children?: React.ReactNode
  imageCard?: {
    width?: string | number
    height?: string | number
    image?: string
    iconFooter?: any
    actions?: string
    children?: React.ReactNode
    onClickEdit?: () => void
    onClickDelete?: () => void
  }
  footerCard?: {
    title?: string
    subTitle?: string,
    position?: PositionFooter
    divider?: boolean
    dividerColor?: string
    cursor?: boolean
  }
  [key: string]: any;
}> = ({
  src,
  type,
  selected,
  width,
  height,
  children,
  imageCard,
  footerCard,
  onClick,
  actions,
  iconColorActions,
  onClickDelete,
  onClickEdit,
  activeInputFile,
  onChangeInputFile,
  ...props
}) => {
    const [showEditales, setShotEditables] = useState(false);
    const defaultWidth = 210;
    const styles = makeStyles({
      selected: {
        border: selected ? `2px solid ${theme.bluePrimary}` : `2px solid ${theme.grayPrimary}`,
        borderRadius: 5,
        backgroundColor: theme.whitePrimary,
        textAlign: 'left',
        cursor: selected ? 'pointer' : undefined,
        width: (props: ThemeTypes) => props.width || defaultWidth,
        height: (props: ThemeTypes) => props.height,
        '&:hover': {
          border: `2px solid ${theme.bluePrimary}`,
          cursor: 'pointer',
        },
        '&>h1': {
          textTransform: 'uppercase',
          fontFamily: 'Poppins',
          fontSize: 15,
          color: theme.blackPrimary,
          margin: 0,
          fontWeight: 500
        },
        '&>h4': {
          textTransform: 'capitalize',
          fontFamily: 'Poppins',
          fontSize: 14,
          color: theme.textContentPrimary,
          fontWeight: 400
        }
      },
      containerIcons: {
        position: 'absolute',
        marginTop: 10,
        zIndex: 90,
        '&>button': {
          border: `1px solid ${theme.borderGreyPrimary}`,
          width: 40,
          height: 40,
          margin: 5
        }
      },
      child: {
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        textAlign: 'center',
        marginTop: 30,
        height: height && typeof height === 'number' ? height - 77 : 210 - 77,
      },
    });
    const classes = styles({ width, height });
    const renderActions = () => {
      const iconsMargin = width ? Number(width) - 115 : 115;
      const defaultIconColor = theme.whitePrimary;
      if (Array.isArray(actions) && actions.length > 0) {
        const editAction = actions.includes('edit');
        const deleteAction = actions.includes('delete');

        if (deleteAction && editAction) {
          return (
            <>
              {showEditales && (
                <div className={classes.containerIcons}
                  onMouseEnter={() => setShotEditables(true)}
                  style={{ marginLeft: iconsMargin }}
                >
                  <IconButton style={{ background: iconColorActions || defaultIconColor }} onClick={onClickEdit}>
                    <EditIcon />
                  </IconButton>
                  <IconButton style={{ background: iconColorActions || defaultIconColor }} onClick={onClickDelete}>
                    <DeleteOutlineIcon />
                  </IconButton>
                </div>
              )}</>
          );
        }
        if (editAction) return (
          <>
            {showEditales && (
              <div className={classes.containerIcons}
                onMouseEnter={() => setShotEditables(true)}
                onMouseLeave={() => setShotEditables(false)}
                style={{ marginLeft: iconsMargin + 45 }}
              >
                <IconButton style={{ background: iconColorActions || defaultIconColor }} onClick={onClickEdit}>
                  <EditIcon />
                </IconButton>
              </div>
            )}
          </>
        );

        if (deleteAction) return (
          <>
            {showEditales && (
              <div className={classes.containerIcons}
                onMouseEnter={() => setShotEditables(true)}
                onMouseLeave={() => setShotEditables(false)}
                style={{ marginLeft: iconsMargin + 45 }}
              >
                <IconButton style={{ background: iconColorActions || defaultIconColor }} onClick={onClickDelete}>
                  <DeleteOutlineIcon />
                </IconButton>
              </div>
            )}
          </>
        );
      }

      if (actions === 'edit') return (
        <>
          {showEditales && (
            <div className={classes.containerIcons}
              onMouseEnter={() => setShotEditables(true)}
              onMouseLeave={() => setShotEditables(false)}
              style={{ marginLeft: iconsMargin + 45 }}
            >
              <IconButton style={{ background: iconColorActions || defaultIconColor }} onClick={onClickEdit}>
                <EditIcon />
              </IconButton>
            </div>
          )}
        </>
      );

      if (actions === 'delete') return (
        <>
          {showEditales && (
            <div className={classes.containerIcons}
              onMouseEnter={() => setShotEditables(true)}
              onMouseLeave={() => setShotEditables(false)}
              style={{ marginLeft: iconsMargin + 45 }}
            >
              <IconButton style={{ background: iconColorActions || defaultIconColor }} onClick={onClickDelete}>
                <DeleteOutlineIcon />
              </IconButton>
            </div>
          )
          }
        </>
      );

      return null;
    };

    return (
      <>
        {activeInputFile ? (
          <UploadFileWithIcon
            src={src}
            type={type}
            footerCard={footerCard}
            width={width}
            height={height}
            actions={actions}
            onClickEdit={onClickEdit}
            onClickDelete={onClickDelete}
            onChange={onChangeInputFile}>
            <div
              onMouseEnter={() => setShotEditables(true)}
              onMouseLeave={() => setShotEditables(false)}
              className={classes.child}>
              {children}
            </div>
          </UploadFileWithIcon>
        ) : (
          <div onClick={onClick} {...props} className={classes.selected}>
            {imageCard && (
              <CardWithImg
                width={imageCard?.width || width}
                height={imageCard?.height || height}
                actions={imageCard?.actions}
                onClickEdit={imageCard?.onClickEdit}
                onClickDelete={imageCard?.onClickDelete}
                image={imageCard?.image}
                iconFooter={imageCard?.iconFooter} >
                {imageCard?.children}
              </CardWithImg>
            )}
            {children && (
              <>
                {renderActions()}
                <div
                  onMouseEnter={() => setShotEditables(true)}
                  onMouseLeave={() => setShotEditables(false)}
                  className={classes.child}>
                  {children}
                </div>
              </>
            )}
            {footerCard && (
              <CardFooter
                position={footerCard?.position}
                title={footerCard?.title}
                cursor={footerCard?.cursor || showEditales}
                divider={footerCard?.divider}
                dividerColor={footerCard?.dividerColor}
                subTitle={footerCard?.subTitle} />
            )}
          </div>
        )}
      </>
    );
  };
