import React from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';
import { ThemeTypes } from './Theme/theme.types';
import Dialog from "@material-ui/core/Dialog";

interface DefaultModalTypes {
  open: boolean;
  setOpen: (v:boolean) => void;
  width?: string | number;
  height?: string | number;
  content?: JSX.Element | any;
  handleClose?: () => void;
  [key: string]: any;
  classContent?: any;
}

export const DefaultModal = ({ open, setOpen, width, height, content, handleClose, classContent,...props }: DefaultModalTypes) => {
  const styles = makeStyles({
    root: {
      '& > .MuiDialog-container .MuiPaper-root': {
        boxShadow: theme.modalShadowDefault,
        borderRadius: 4
      },
      '& > .MuiDialog-container': {
        backgroundColor: theme.modalBackgroundDefault,
      }
    },
    containerModal: {
      width:  (props: ThemeTypes) => props.width || 500,
      height: (props: ThemeTypes) => props.height || 500,
  },
  });
  const classes = styles({ width, height });
  return (
    <div className={classes.root} { ...props }>
      <Dialog
        className={classes.root}
        open={open}
        aria-labelledby="responsive-dialog-title"
        onClose={() => handleClose && handleClose()}
      >
        <div className={classContent || classes.containerModal}>
          {content}
        </div>
      </Dialog>
    </div>
  )
}