import React from 'react';
import { makeStyles } from '@material-ui/core/styles'
import { theme as ThemeStyles } from './Theme/theme';
import PositionFooter from './Types/positionFooter';
import ErrorIcon from '@mui/icons-material/Error';

interface ErrorTypes {
  title?: string;
  width?: number
  [key: string]: any;
  image?: any;
  position?: PositionFooter
};


export const Error = ({ title, image, width, position, ...props }: ErrorTypes) => {

  const styles = makeStyles({
    container: {
      display: 'flex',
      flexDirection: 'row',
      alignItems: 'flex-start',
      justifyContent: (props: any) => props.position || undefined,
      width: (props: any) => props.width || 'calc(100%)',
      paddingTop: 8,
    },
    error: {
      fontFamily: 'Poppins',
      fontWeight: 400,
      fontSize: 12,
      color: ThemeStyles.bluePrimary
    },
    icon: {
      width: 14,
      height: 14,
      marginRight: 9
    },
    defaultIcon:{
      width: 18,
      height: 18,
      marginRight: 9,
      marginTop: -3,
      color: ThemeStyles.bluePrimary
    }
  })
  const classes = styles({ width, position });

  return (
    <div className={classes.container} {...props}>
      {image ? <img src={image} className={classes.icon} />: (
        <ErrorIcon className={classes.defaultIcon}/>
      )}
      <small className={classes.error}>{title}</small>
    </div>
  );
};
