import React from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';

import InstagramIcon from '@mui/icons-material/Instagram';
import LinkedInIcon from '@mui/icons-material/LinkedIn';
import FacebookIcon from '@mui/icons-material/Facebook';
import TwitterIcon from '@mui/icons-material/Twitter';

interface FooterTypes {
  [key: string]: any;
  text?: string;
  type: string;
}

export const Footer = ({ text, type, ...props }: FooterTypes) => {
  const styles = makeStyles({
    root: {
      width: '100%',
      textAlign: 'center',
      color: theme.textContentPrimary,
      borderTop: `2px solid ${theme.grayPrimary}`,
      paddingTop: 10,
      paddingBottom: 10,
      backgroundColor: theme.whitePrimary,
      '&>ul': {
        display: 'flex',
        flexFlow: 'wrap',
        listStyle: 'none',
        justifyContent: 'center',
        '&>li': {
          textAlign: 'center',
          '&>a': {
            margin: 15,
            '&>svg': {
              color: theme.textContentPrimary,
              width: 20,
              height: 20,
            }
          }
        }
      },
      '&>p': {
        padding: 0,
        margin: 0
      }
    },

  });
  const classes = styles();
  return (
    <React.Fragment>
      {type === 'simple' && (
        <footer {...props} className={classes.root}>
          <ul>
            <li>
              <a href="https://www.instagram.com/" target="_blank" title="Instagram"><InstagramIcon /></a>
            </li>
            <li>
              <a href="https://www.linkedin.com/" target="_blank" title="Linkedin"><LinkedInIcon /></a>
            </li>
            <li>
              <a href="https://www.facebook.com/" target="_blank" title="Facebook"><FacebookIcon /></a>
            </li>
            <li>
              <a href="https://www.twitter.com/" target="_blank" title="Twitter"><TwitterIcon /></a>
            </li>
          </ul>
          <p>
            {text || ""}
          </p>
        </footer>
      )}
    </React.Fragment>
  )
}