import React, { useEffect, useState } from 'react';

import Picker from 'emoji-picker-react';

import TextField from '@material-ui/core/TextField';
import IconButton from '@material-ui/core/IconButton';
import InputAdornment from '@material-ui/core/InputAdornment';
import { makeStyles } from '@material-ui/core';
import { theme } from './Theme/theme';

import {
  FormatName,
  FileSize,
  DescriptionSize,
} from '../src/helpers/fileTypes';
import { FormatDate } from './helpers/FormatDate';

/* Components */
import { AttachFilesChat } from './AttachFilesChat';
import { RenderFile } from './RenderFile';
import { DefaultModal } from './DefaultModal';

/* Icons */
import AttachFileIcon from '@mui/icons-material/AttachFile'; // Attach file
import SendIcon from '@mui/icons-material/Send'; // Send Message
import DeleteOutlineIcon from '@mui/icons-material/DeleteOutline';
import SentimentSatisfiedAltIcon from '@mui/icons-material/SentimentSatisfiedAlt'; // Add emoji
import ErrorIcon from '@mui/icons-material/Error';
import { ThemeTypes } from './Theme/theme.types';

type RecentFilesListType = {
  id: string;
  name: string;
  url: string;
  type: string;
  size?: string;
  created?: Date | string;
};

interface InputChatTypes {
  [key: string]: any;
  iconSend?: boolean;
  iconAttach?: boolean;
  disabled?: boolean;
  id: string;
  value?: string;
  setValue?: (v?: string) => void;
  placeholder?: string;
  returnAction?: () => void;
  width?: string | number;
  handleSubmit?: () => void;
  emojiStyles?: { [key: string]: string | number };
  storiesStyle?: boolean;
  handleUploadFile?: () => void;
  lng?: string;
  recentFilesList?: RecentFilesListType[];
  setFileName?: (v?: string) => void;
  setFileType?: (v?: string) => void;
  setFileSize?: (v?: string) => void;
  setFilePath?: (v?: string) => void;
  file?: any;
  setFile?: any;
  limitSizeInMB: number;
  maxHeightInput?: number | string;
}

export const InputChat = ({
  iconSend,
  iconAttach,
  disabled,
  id,
  value,
  setValue,
  placeholder,
  returnAction,
  handleSubmit,
  width,
  emojiStyles,
  storiesStyle,
  handleUploadFile,
  lng,
  recentFilesList,
  setFileName,
  setFileSize,
  setFileType,
  setFilePath,
  file,
  setFile,
  limitSizeInMB,
  maxHeightInput,
  ...props
}: InputChatTypes) => {
  const styles = makeStyles({
    root: {
      width: (props: ThemeTypes) => props.width || '100%',
      position: 'relative',
      minWidth: 500,
      height: 'max-content',
    },
    field: {
      width: (props: ThemeTypes) => props.width || '100%',
      height: 'max-content',
      minWidth: 500,
      position: 'relative',
      '& > .MuiInputBase-root': {
        width: (props: ThemeTypes) => props.width || '100%',
        minWidth: 500,
        border: 'none',
        borderRadius: 40,
        outline: 'none',
        '& > .MuiInputBase-input': {
          paddingLeft: 20,
          paddingRight: 20,
          paddingTop: 24,
          paddingBottom: 15,
          borderRadius: 4,
          backgroundColor: 'transparent',
          zIndex: 1,
        },
        '&> .MuiInputBase-inputMultiline': {
          maxHeight: (props: ThemeTypes) => props.maxHeight || 120,
          overflow: 'auto !important',
          '&::-webkit-scrollbar': {
            width: '5px',
            height: '5px',
            backgroundColor: theme.grayPrimary,
          },
          '&::-webkit-scrollbar-thumb': {
            backgroundColor: theme.opacityGrayDefault,
            borderRadius: '20px',
          },
          '&::-webkit-scrollbar-track': {
            marginBottom: '1px',
          },
        },
      },

      '& > .MuiInput-underline:before': {
        borderBottom: 'none',
        content: 'none',
      },
      '& > .MuiInput-underline:after': {
        borderBottom: `0px solid transparent`,
        height: 'max-content',
        minHeight: '100% !important',
        transition: 'none',
        borderRadius: 40,
      },
      '& > .MuiInput-underline:hover': {
        backgroundColor: 'white',
      },
      '& > .MuiInputLabel-root:before': {
        color: 'blue',
      },
    },
    containerIcons: {
      display: 'flex',
      flexFlow: 'wrap',
      width: 'max-content',
      '&>button': {
        width: 35,
        height: 35,
        margin: 5,
      },
    },
    sendIcon: {
      color: theme.bluePrimary,
    },
    containerEmojis: {
      position: 'absolute',
      zIndex: 10,
      marginTop: -460,
      right: 0,
      ...emojiStyles,
    },
    backWall: {
      position: 'fixed',
      width: '100%',
      height: '100%',
      top: 0,
      left: 0,
      right: 0,
      zIndex: 9,
      backgroundColor: 'transparent',
    },
    containerAddFile: {
      margin: 15,
      border: `2px solid ${theme.borderGreyPrimary}`,
      borderRadius: '5px 5px 40px 40px',
      padding: 10,
      display: 'flex',
      flexFlow: 'wrap',
      alignItems: 'center',
    },
    contentModal: {
      width: 'fit-content',
      height: 'fit-content',
      maxWidth: 530,
      maxHeight: 760,
      overflow: 'auto',
      '&>div>div': {
        maxHeight: `520px !important`,
        maxWidth: 450,
        overflow: 'auto',
        '&::-webkit-scrollbar': {
          width: '5px',
          height: '5px',
          backgroundColor: theme.grayPrimary,
        },
        '&::-webkit-scrollbar-thumb': {
          backgroundColor: theme.opacityGrayDefault,
          borderRadius: '20px',
        },
        '&::-webkit-scrollbar-track': {
          marginBottom: '1px',
        },
      },
    },
    addFilePreview: {
      position: 'relative',
      zIndex: 5,
      borderBottom: `1px solid ${theme.grayPrimary}`,
      display: 'flex',
      flexFlow: 'wrap',
      alignItems: 'center',
      width: '100%',
      padding: 15,
      borderRadius: '5px 5px 40px 40px',
      '&:hover': {
        cursor: 'pointer',
        backgroundColor: theme.hoverBlue,
        '&>div>p': {
          color: theme.bluePrimary,
        },
      },
      '&>:nth-child(1)': {
        width: 60,
        height: 60,
        border: `1px solid ${theme.grayPrimary}`,
        borderRadius: 4,
        '&>div>img': {
          width: 60,
          height: 60,
          borderRadius: 4,
        },
      },
    },
    containerInfo: {
      marginLeft: 25,
      position: 'relative',
      zIndex: 4,
      '&>:nth-child(1)': {
        fontWeight: 700,
        color: theme.blackPrimary,
      },
      '&>p': {
        color: theme.opacityGrayDefault,
        fontWeight: 700,
      },
    },
    containerDelete: {
      position: 'absolute',
      zIndex: 6,
      width: 40,
      height: 40,
      display: 'flex',
      justifyContent: 'flex-end',
      alignItems: 'center',
      marginLeft: '80%',
      '&>button': {
        width: 60,
        height: 60,
        '&>span>svg': {
          padding: 5,
          border: `1px solid ${theme.grayPrimary}`,
          width: 40,
          height: 40,
          color: theme.opacityGrayDefault,
          borderRadius: '50%',
        },
      },
    },
    errorIcon: {
      width: 15,
      height: 15,
      color: theme.bluePrimary,
      marginTop: -8,
    },
    alertSize: {
      marginLeft: 15,
      color: theme.bluePrimary,
    },
    containerTextfield: {
      border: (props: ThemeTypes) =>
        props.active
          ? `1px solid ${theme.bluePrimary}`
          : `1px solid ${theme.borderGreyPrimary}`,
      borderRadius: 40,
      '&:hover': {
        border: (props: ThemeTypes) =>
          !props.disabled ? `1px solid ${theme.bluePrimary}` : '',
      },
    },
  });
  const [inputActive, setInputActive] = useState(false);
  const [localValue, setLocalvalue] = useState<string>('');
  const [showEmojis, setShowEmojis] = useState(false);
  const [selectedEmojis, setSelectedEmojis] = useState<string[]>([]);
  const [openAttach, setOpenAttach] = useState(false);
  const selectedFileInitialValues = {
    id: '',
    name: '',
    url: '',
    type: '',
    size: '',
    created: undefined,
  };
  const [addFile, setAddFile] = useState<RecentFilesListType>(
    selectedFileInitialValues
  );
  const [openModal, setOpenModal] = useState(false);
  const [alertSize, setAlertSize] = useState(false);

  const classes = styles({
    width,
    active: inputActive,
    disabled,
    maxHeight: maxHeightInput,
  });

  const handleChange = (e: string) => {
    if (setValue) {
      setValue(e);
      setLocalvalue(e);
    } else {
      setLocalvalue(e);
    }
    setSelectedEmojis([]);
    setShowEmojis(false);
  };
  useEffect(() => {
    if (localValue !== '') {
      setInputActive(true);
    } else {
      setInputActive(false);
    }
  }, [localValue]);

  const handleEmoji = (event: any) => {
    if (selectedEmojis.length > 0) {
      setSelectedEmojis([...selectedEmojis, event.emoji]);
      setValue &&
        setValue(
          value && value !== '' ? `${value}${event.emoji}` : `${event.emoji}`
        );
      setLocalvalue(
        localValue && localValue !== ''
          ? `${value}${event.emoji}`
          : `${event.emoji}`
      );
    } else {
      setValue && setValue(`${value}${event.emoji}`);
      setLocalvalue(`${localValue}${event.emoji}`);
    }
  };

  const handleSend = () => {
    handleSubmit && handleSubmit();
    setValue && setValue('');
    setLocalvalue('');
    setShowEmojis(false);
    setSelectedEmojis([]);
    setAddFile(selectedFileInitialValues);
  };
  const handleKeyPress = (key: string) => {
    if (key === 'Enter') {
      handleSend();
    }
  };

  const backWallActions = () => {
    setShowEmojis(false);
    setOpenAttach(false);
  };
  const handlePreview = () => {
    addFile.type !== 'application/zip' && setOpenModal(!openModal);
  };

  const handleDeleteAddFile = () => {
    setAddFile(selectedFileInitialValues);
    setFile && setFile(null);
    setFileName && setFileName(undefined);
    setFileType && setFileType(undefined);
    setFileSize && setFileSize(undefined);
    setFilePath && setFilePath(undefined);
  };

  const ContentModal = () => {
    return (
      <div>
        <RenderFile
          selectedFile={addFile}
          renderType="preview"
          lng={lng}
          handlePreview={handlePreview}
          file={addFile}
        />
      </div>
    );
  };
  return (
    <React.Fragment>
      {openModal && (
        <DefaultModal
          open={openModal}
          setOpen={setOpenModal}
          handleClose={() => setOpenModal(false)}
          content={ContentModal()}
          width={'fit-content'}
          height={'fit-content'}
          classContent={classes.contentModal}
        />
      )}
      {(showEmojis || openAttach) && (
        <div className={classes.backWall} onClick={() => backWallActions()} />
      )}
      <div
        className={classes.root}
        {...props}
        style={{ marginTop: storiesStyle ? 500 : '' }}
      >
        {showEmojis && (
          <div className={classes.containerEmojis}>
            <Picker onEmojiClick={handleEmoji} />
          </div>
        )}
        {openAttach && (
          <AttachFilesChat
            lng={lng}
            recentFilesList={recentFilesList}
            addFile={addFile}
            setAddFile={setAddFile}
            file={file}
            setFile={setFile}
            limitSizeInMB={limitSizeInMB}
            setAlertSize={setAlertSize}
            setFileName={setFileName}
            setFilePath={setFilePath}
            setFileSize={setFileSize}
            setFileType={setFileType}
          />
        )}

        <div className={classes.containerTextfield}>
          <TextField
            multiline
            id={id}
            className={classes.field}
            value={localValue}
            placeholder={placeholder || ''}
            type="text"
            onChange={e => !disabled && handleChange(e.target.value)}
            onKeyDown={e => !disabled && handleKeyPress(e.key)}
            autoComplete="off"
            disabled={disabled}
            InputProps={{
              endAdornment: (
                <InputAdornment position="start">
                  <div className={classes.containerIcons}>
                    {!disabled && iconAttach && (
                      <IconButton onClick={() => setOpenAttach(!openAttach)}>
                        <AttachFileIcon />
                      </IconButton>
                    )}
                    <IconButton
                      onClick={() => !disabled && setShowEmojis(!showEmojis)}
                    >
                      <SentimentSatisfiedAltIcon />
                    </IconButton>
                    {!disabled &&
                      iconSend &&
                      (localValue !== '' || addFile.id !== '') && (
                        <IconButton>
                          <SendIcon
                            className={classes.sendIcon}
                            onClick={() => handleSend()}
                          />
                        </IconButton>
                      )}
                  </div>
                </InputAdornment>
              ),
            }}
            {...props}
          />
          {addFile && addFile.id !== '' && (
            <div className={classes.containerAddFile}>
              <div className={classes.containerDelete}>
                <IconButton onClick={() => handleDeleteAddFile()}>
                  <DeleteOutlineIcon />
                </IconButton>
              </div>
              <div
                className={classes.addFilePreview}
                onClick={() => handlePreview()}
              >
                <RenderFile
                  lng={lng}
                  selectedFile={addFile}
                  file={addFile}
                  renderType="icon"
                  handlePreview={() => null}
                />
                <div className={classes.containerInfo}>
                  <p>{FormatName(addFile.name)}</p>
                  <p>{DescriptionSize(FileSize(addFile.size), lng || '')}</p>
                  <p>{FormatDate(addFile.created?.toString(), lng || '')}</p>
                </div>
              </div>
            </div>
          )}
          {alertSize && limitSizeInMB && (
            <div className={classes.containerAddFile}>
              <div className={classes.errorIcon}>
                <ErrorIcon />
              </div>
              <p className={classes.alertSize}>
                {lng === 'en'
                  ? `The size limit allowed should not exceed ${limitSizeInMB} MB`
                  : `El limite de tamaño permitido no debe superar los ${limitSizeInMB} MB`}
              </p>
            </div>
          )}
        </div>
      </div>
    </React.Fragment>
  );
};
