import React, { useState } from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';

interface ListContractTypes {
  title?: string;
  labelContract?: string;
  labelWorkspace?: string;
  labelDispute?: string;
  sections?: {
    contract?: boolean;
    workspace?: boolean;
    dispute?: boolean;
  };
  routeActive?: string;
  onClickContract?: () => void;
  onClickWorkspace?: () => void;
  onClickDispute?: () => void;
  active?: boolean;
  [key: string]: any;
}

export const ListContract = ({ 
  title, 
  sections, 
  routeActive, 
  onClickContract,
  onClickWorkspace,
  onClickDispute,
  labelContract,
  labelWorkspace, 
  labelDispute, 
  active,
  ...props }: ListContractTypes) => {

  const styles = makeStyles({
    root: {},
    container: {},
    sectionOne: {
      display: 'flex',
      padding: 0,
      margin: 0,
      alignItems: 'center'
    },
    dotActive: {
      width: 10,
      height: 10,
      borderRadius: '50%',
      backgroundColor: theme.greenPrimary,
      border: `2.5px solid ${theme.greenPrimary}`,
      padding: 0,
      margin: '0px 16px 0px 0px'
    },
    dotInactive: {
      width: 10,
      height: 10,
      borderRadius: '50%',
      backgroundColor: theme.whitePrimary,
      border: `2.5px solid ${theme.opacityGrayDefault}`,
      padding: 0,
      margin: '0px 16px 0px 0px'
    },
    titleActive: {
      textTransform: 'uppercase',
      fontWeight: 400,
      fontSize: 16,
      margin: 0,
      color: theme.blackPrimary,
      '&:hover': {
        cursor: 'pointer',
        color: theme.bluePrimary
      }
    },
    titleInactive: {
      textTransform: 'uppercase',
      fontWeight: 400,
      color: theme.opacityGrayDefault,
      fontSize: 16,
      margin: 0,
      '&:hover': {
        cursor: 'pointer',
        color: theme.bluePrimary
      }
    },
    sectionTwo: {
      padding: '10px 0px 0px 30px',
      width: 'max-content'
    },
    itemActive: {
      padding: '0px 0px 10px 0px',
      margin: 0,
      fontSize: 15,
      color: theme.blackPrimary,
      '&:hover': {
        color: theme.bluePrimary,
        cursor: 'pointer'
      }
    },
    itemInactive: {
      padding: '0px 0px 10px 0px',
      margin: 0,
      fontSize: 15,
      color: theme.opacityGrayDefault,
      '&:hover': {
        color: theme.bluePrimary,
        cursor: 'pointer'
      }
    },
  });

  const classes = styles();
  const [open, setOpen] = useState(active);
  return (
    <div className={classes.root} {...props}>
      <div className={classes.container}>
        <div className={classes.sectionOne}>
          <div className={open ? classes.dotActive : classes.dotInactive} />
          <p className={open ? classes.titleActive : classes.titleInactive} onClick={() => setOpen(!open)}>{title}</p>
        </div>
        {open && (
          <div className={classes.sectionTwo}>
            {sections?.contract && <p className={routeActive === 'Contract' ? classes.itemActive : classes.itemInactive} onClick={onClickContract} >{labelContract}</p>}
            {sections?.workspace && <p className={routeActive === 'Workspace' ? classes.itemActive : classes.itemInactive} onClick={onClickWorkspace} >{labelWorkspace}</p>}
            {sections?.dispute && <p className={routeActive === 'Dispute' ? classes.itemActive : classes.itemInactive} onClick={onClickDispute} >{labelDispute}</p>}
          </div>
        )}
      </div>
    </div>
  )
}