import React from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';
import { ThemeTypes } from './Theme/theme.types';

import ContentPasteIcon from '@mui/icons-material/ContentPaste';
import Avatar from '@material-ui/core/Avatar';

import { ButtonForm } from './Button';

interface ListingProjectCardTypes {
  [key: string]: any;
  width?: string | number;
  height?: string | number;
  avatar?: boolean;
  avatarSrc?: string;
  projectTitle?: string;
  projectStatus?: string;
  publicatedDate?: string;
  btnQuantity?: number;
  onClickCard?: () => void;
  onClickBtnRight?: () => void;
  onClickBtnLeft?: () => void;
  onClickBtnCenter?: () => void;
  projectId?: string;
  btnHeight?: number,
  btnCenterText?: string;
  btnRightText?: string;
  btnLeftText?: string;
  onClickAvatar?: () => void;
  userName?: string;
  lng?: string;
  noBtn?: boolean;
}

export const ListingProjectCard = ({
  width,
  height,
  avatar,
  avatarSrc,
  projectTitle,
  projectStatus,
  publicatedDate,
  onClickCard,
  onClickBtnRight,
  onClickBtnLeft,
  onClickBtnCenter,
  projectId,
  btnHeight,
  btnCenterText,
  btnLeftText,
  btnRightText,
  onClickAvatar,
  userName,
  lng,
  btnQuantity,
  noBtn,
  ...props }: ListingProjectCardTypes) => {
  const styles = makeStyles({
    root: {
      width: (props: ThemeTypes) => props.width || 340,
      height: (props: ThemeTypes) => props.height || 340,
      border: `1px solid ${theme.grayPrimary}`,
      borderRadius: 4,
      backgroundColor: theme.whitePrimary,
      padding: 20,
      '&:hover': {
        border: `2px solid ${theme.bluePrimary}`,
        boxShadow: theme.shadowBlackDefault,
        cursor: 'pointer'
      }
    },
    content: {
      width: '99.9%',
      height: (props: ThemeTypes) => props.childHeight ? `calc(100% - ${props.childHeight}px)` : `calc(100% - 80px)`,
    },
    containerBtn: {
      height: (props: ThemeTypes) => props.childHeight || 80,
      width: '99.9%',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
    },
    containerIcons: {
      display: 'flex',
      alignItems: 'center',
      '&>svg': {
        color: theme.yellowPrimary,
        backgroundColor: theme.yellowBackground,
        width: 30,
        height: 30,
        padding: 7,
        borderRadius: '50%',
        position: 'relative',
        zIndex: 20,
      }
    },
    avatar: {
      width: 40,
      height: 40,
      marginLeft: -10,
      position: 'relative',
      zIndex: 19
    },
    containerMiddle: {
      display: 'flex',
      flexFlow: 'column',
      alignItems: 'center',
      justifyContent: 'center',
      width: '100%',
      height: '100%',
      textAlign: 'center'
    },
    title: {
      fontSize: 22,
      width: '99.9%',
      color: theme.blackPrimary,
      textTransform: 'capitalize',
      margin: '5px 0px 5px 0px !important',
      padding: 0
    },
    status: {
      fontSize: 18,
      width: '99.9%',
      color: theme.bluePrimary,
      textTransform: 'capitalize',
      margin: '5px 0px 5px 0px !important',
      padding: 0
    },
    date: {
      fontSize: 14,
      width: '99.9%',
      color: theme.opacityGrayDefault,
      margin: '20px 0px 30px 0px !important',
      padding: 0
    }
  });
  const classes = styles({ width, height, childHeight: btnHeight });

  const formatDate = (date: string | undefined) => {
    let en = lng === 'en';
    let day, month, year;
    if (date) {
      let dateMonths = {
        "0": en ? "January" : "Enero",
        "1": en ? "February" : "Febrero",
        "2": en ? "March" : "Marzo",
        "3": en ? "April" : "Abril",
        "4": en ? "May" : "Mayo",
        "5": en ? "June" : "Junio",
        "6": en ? "July" : "Julio",
        "7": en ? "August" : "Agosto",
        "8": en ? "September" : "Setiembre",
        "9": en ? "October" : "Octubre",
        "10": en ? "November" : "Noviembre",
        "11": en ? "December" : "Diciembre"
      }
      day = date.split('-')[2].slice(0, 2)
      month = date.split('-')[1].slice(0, 2)
      year = date.split('-')[0]
      
      return en ?
        `Published on ${Object.values(dateMonths)[parseInt(month) - 1]} ${day}, ${year}`
        :
        `Publicado el ${day}  ${Object.values(dateMonths)[parseInt(month) - 1]}, ${year}`
    }
    return ""
  }

  return (
    <div className={classes.root} {...props} onClick={onClickCard}>
      <div className={classes.content}>
        <div className={classes.containerIcons}>
          <ContentPasteIcon />
          {avatar && (
            <Avatar
              onClick={onClickAvatar}
              className={classes.avatar}
              src={avatarSrc}
              title={userName || ""}
            >
              {userName ? userName.slice(0, 1) : 'D'}
            </Avatar>
          )}
        </div>
        <div className={classes.containerMiddle}>
          <h1 className={classes.title}>{projectTitle || ""}</h1>
          <h4 className={classes.status}>{projectStatus}</h4>
          <p className={classes.date}>{formatDate(publicatedDate)}</p>
        </div>
      </div>
      <div className={classes.containerBtn} style={{ justifyContent: btnQuantity && btnQuantity === 2 ? 'space-between' : 'center' }}>
        {!noBtn && btnQuantity && btnQuantity === 1 && btnCenterText && (
          <ButtonForm
            style={{ width: '100%' }}
            label={btnCenterText}
            onClick={onClickBtnCenter}
          />
        )}
        {!noBtn && btnQuantity && btnQuantity === 2 && btnLeftText && btnRightText && (
          <React.Fragment>
            <ButtonForm
              style={{ width: '100%', margin: 15 }}
              label={btnLeftText}
              onClick={onClickBtnLeft}
            />
            <ButtonForm
              style={{ width: '100%', margin: 15 }}
              label={btnRightText}
              onClick={onClickBtnRight}
            />
          </React.Fragment>
        )}
      </div>
    </div>
  )
}