import React from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';
import Timeago from 'react-timeago';
import buildFormatter from 'react-timeago/lib/formatters/buildFormatter'
import spanishStrings from 'react-timeago/lib/language-strings/es'
import englishStrings from 'react-timeago/lib/language-strings/en'


import { AvatarModule } from './Avatar';

interface MenuMessagesTypes {
  id?: string;
  userEmisor?: string;
  emisorName?: string;
  availability?: string;
  created?: Date;
  message?: string;
  emisorId?: string;
  avatar?: string;
  avatarCounterPart?: string;
  recibedName?: string;
  lng?: string;
  [key: string]: any;
  redirection?: () => void;
  userId?: string;
  width?: string| number;
}

export const MenuMessages = ({
  id,
  userEmisor,
  emisorName,
  availability,
  created,
  message,
  emisorId,
  avatar,
  avatarCounterPart,
  recibedName,
  lng,
  redirection,
  userId,
  width,
  ...props }: MenuMessagesTypes) => {
  const styles = makeStyles({
    root: {
      display: "flex",
      paddingTop: 15,
      paddingBottom: 15,
      alignItems: "center",
      marginLeft: 15,
      borderBottom: `1px solid ${theme.grayPrimary}`,
      "&:hover": {
        opacity: ".75",
        cursor: "pointer"
      }
    },
    containerText: {
      marginLeft: 12,
      width: "100%"
    },
    name: {
      color: theme.blackPrimary,
      lineHeight: "21px",
      fontSize: 14,
      fontFamily: "Poppins",
      fontStyle: 'normal',
      fontWeight: 500
    },
    message: {
      color: theme.opacityGrayDefault,
      lineHeight: "21px",
      fontSize: 14,
      fontFamily: "Poppins",
      fontStyle: 'normal',
    },
    created: {
      color: theme.opacityGrayDefault,
      lineHeight: "21px",
      fontSize: 12,
      fontFamily: "Poppins",
      fontStyle: 'normal',
      textAlignLast: "right",
      marginRight: 25
    }
  });
  const classes = styles();

  const handleUserNameMessage = (userId?: string, userEmisor?: string, emisorName?: string, recibedName?: string) => {
    if (userId === userEmisor) return recibedName
    return emisorName
  }
  const handleUserAvatarMessage = (userId?: string, userEmisor?: string, avatar?: string, avatarCounterPart?: string) => {
    if (userId !== userEmisor) return avatar
    return avatarCounterPart
  }


  const Timer = (created?: Date) => {
    const esFormat = buildFormatter(spanishStrings)
    const enFormat = buildFormatter(englishStrings)
    return (
      <div>
        {created && (
          <Timeago date={created} formatter={lng === 'en' ? enFormat : esFormat} />
        )}
      </div>
    )
  }

  const widthValue = (width?: string|number) => {
    if(width){
      if(typeof width === 'number'){
        return `${width}px`
      } 
      if(typeof width === 'string'){
        return width
      }
    }
    return ""
  }

  return (
    <div
      className={classes.root}
      key={id}
      onClick={redirection}
      {...props}
      style={{ width: widthValue(width) }}
    >
      <AvatarModule
        name={handleUserNameMessage(userId, userEmisor, emisorName, recibedName) || ""}
        image={handleUserAvatarMessage(userId, userEmisor, avatar, avatarCounterPart) || ""}
        small
        status
        online={availability === 'off' ? false : true}
      />
      <div className={classes.containerText}>
        <div className={classes.created}>
          {Timer(created)}
        </div>
        <p className={classes.name}>
          {handleUserNameMessage(userId, userEmisor, emisorName, recibedName) || ""}
        </p>
        <p className={classes.message}>
          {message && message.length > 30
            ? `${message}`.slice(0, 30).concat(' ...')
            : `${message}`}
        </p>
      </div>
    </div>
  )
}