import React from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';

interface ItemsTypes {
  label?: string;
  icon?: JSX.Element | any;
  onClick?: () => void;
}

interface MenuProfileTypes {
  labelOnline?: string;
  labelOffline?: string;
  list: ItemsTypes[];
  online?: boolean;
  onClickOnline?: () => void;
  onClickOffline?: () => void;
  [key: string]: any;
}

export const MenuProfile = ({
  labelOnline,
  labelOffline,
  list,
  online,
  onClickOnline,
  onClickOffline,
  ...props }: MenuProfileTypes) => {
  const styles = makeStyles({
    root: {
      width: 323,
      minHeight: 328,
      maxHeight: 'max-content',
      boxShadow: theme.shadowBlackDefault,
      backgroundColor: theme.whitePrimary
    },
    switchContainer: {
      borderBottom:`2px solid ${theme.grayPrimary}`,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      margin: '0px 0px 0px 0px',
      height: 110,
      padding: 0,
      '&>div':{
        width: 110,
        height: 45,
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        fontSize: 14,
        fontFamily: 'Poppins',
        textTransform: 'capitalize',
        '&:hover':{
          cursor: 'pointer'
        }
      },
      '&>:nth-child(1)':{
        borderRadius: '5px 0px 0px 5px'
      },
      '&>:nth-child(2)':{
        borderRadius: '0px 5px 5px 0px'
      }
    },
    switchOnline:{
      backgroundColor: theme.greenPrimary,
      color: theme.whitePrimary
    },
    switchOffline:{
      backgroundColor: theme.grayPrimary,
      color: theme.blackPrimary
    },
    containerItems:{
      padding: 40
    },
    itemContainer:{
      color: theme.opacityGrayDefault,
      textTransform: 'capitalize',
      padding: 0,
      marign: 0,
      display: 'flex',
      alignItems: 'center',
      '&>p':{
        '&>svg':{
          marginRight: 10,
          padding: 0,
          marginTop: -3,
        },
        padding: 0,
        marign: 0,
      },
      '&:hover':{
        color: theme.blackPrimary,
        cursor: 'pointer'
      }
    }
  });


  const classes = styles();
  return (
    <div className={classes.root} {...props}>
      <section className={classes.switchContainer}>
        <div className={online ? classes.switchOnline : classes.switchOffline} onClick={onClickOnline} ><p>{labelOnline}</p></div>
        <div className={!online ? classes.switchOnline : classes.switchOffline} onClick={onClickOffline}><p>{labelOffline}</p></div>
      </section>
      <div className={classes.containerItems}>
      {list && list.length > 0 && list.map((v: ItemsTypes, index: number) => (
        <div className={classes.itemContainer} key={index}>
          <p onClick={v.onClick}>
            {v.icon}
            {v.label}
          </p>
        </div>
      ))}
      </div>
    </div>
  )
}