import React from 'react';
import { makeStyles } from '@material-ui/core';
import { theme } from './Theme/theme';
import { ThemeTypes } from './Theme/theme.types';
import { ResizableModal } from './ResizableModal';
import { Title } from './Title';
import { Subtitle } from './Subtitle';
import { ButtonForm } from './Button';
import ErrorOutlineIcon from '@mui/icons-material/ErrorOutline';
import CheckIcon from '@mui/icons-material/Check';

interface ModalListInfoStruct {
  [key: string]: any;
  open: boolean;
  setOpen: (v: boolean) => void;
  handleClose?: () => void;
  width?: string | number;
  items?: string[];
  title: string;
  subtitle?: string;
  footer: boolean;
  footerText?: string;
  btnText: string;
  onClick?: () => void;
  type: string;
}

export const ModalListInfo = ({
  open,
  setOpen,
  handleClose,
  width,
  title,
  subtitle,
  items,
  footer,
  footerText,
  btnText,
  onClick,
  type,
  ...props
}: ModalListInfoStruct) => {
  const styles = makeStyles({
    root: {
      padding: 30,
      width: (props: ThemeTypes) => props.width || 370,
    },
    list: {
      listStyleType: 'none',
      width: 310,
      margin: 'auto',
      padding: 0,
      maxHeight: 240,
      overflowX: 'hidden',
      overflowY: 'auto',
      marginTop: 10,
      '&::-webkit-scrollbar': {
        width: '5px',
        backgroundColor: '#F2F4F6',
      },
      '&::-webkit-scrollbar-thumb': {
        backgroundColor: '#93A0AD',
        borderRadius: '238px',
      },
      '&::-webkit-scrollbar-track': {
        marginBottom: '10px',
      },
      '&>li': {
        margin: '15px 0px 15px 0px',
        width: 300,
        color: theme.textContentPrimary,
        fontSize: 14,
        display: 'flex',
      },
    },
    containerBtn: {
      width: '100%',
      marginTop: 20,
      display: 'flex',
      justifyContent: 'flex-end',
    },
    iconSuccess: {
      backgroundColor: theme.backgroundGreen,
      borderRadius: '50%',
      width: 20,
      height: 20,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      padding: 4,
      marginRight: 15,
      '&>svg': {
        color: theme.greenPrimary,
        width: 20,
        height: 20,
        borderRadius: '50%',
      },
    },
    iconError: {
      backgroundColor: theme.lightBlue,
      borderRadius: '50%',
      width: 20,
      height: 20,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      padding: 4,
      marginRight: 15,

      '&>svg': {
        color: theme.darkBlue,
        width: 20,
        height: 20,
        borderRadius: '50%',
      },
    },
    containerFooter: {
      color: theme.darkBlue,
      backgroundColor: theme.lightBlue,
      borderRadius: 4,
      marginTop: 15,
      padding: 20,
      width: 340,
      fontSize: 14,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      '&>svg': {
        width: 30,
        height: 30,
        color: theme.darkBlue,
        marginRight: 15,
      },
    },
  });
  const classes = styles({ width });
  return (
    <ResizableModal
      width="max-content"
      height="max-content"
      open={open}
      setOpen={setOpen}
      handleClose={handleClose}
      style={{ padding: 20 }}
      content={
        <div className={classes.root} {...props}>
          <Title
            title={title}
            style={{ textAlign: 'center', width: '100%', fontWeight: 500 }}
          />
          <Subtitle
            subtitle={subtitle || ''}
            style={{
              marginTop: 10,
              fontSize: 16,
              color: theme.textContentPrimary,
              margin: 'auto',
              padding: 15,
              width: '100%',
            }}
          />
          <ul className={classes.list}>
            {items &&
              items.length > 0 &&
              items.map((i: string) => (
                <li>
                  {type === 'success' && (
                    <div className={classes.iconSuccess}>
                      <CheckIcon />
                    </div>
                  )}
                  {type === 'error' && (
                    <div className={classes.iconError}>
                      <ErrorOutlineIcon />
                    </div>
                  )}
                  &nbsp;{i}
                </li>
              ))}
          </ul>
          {footer && (
            <React.Fragment>
              {footerText && (
                <div className={classes.containerFooter}>
                  <ErrorOutlineIcon />
                  <p>{footerText}</p>
                </div>
              )}
            </React.Fragment>
          )}
          <div className={classes.containerBtn}>
            <ButtonForm label={btnText} onClick={onClick} />
          </div>
        </div>
      }
    />
  );
};
