import React from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';
import { ResizableModal } from './ResizableModal';
import { ButtonForm } from './Button';
import { ThemeTypes } from './Theme/theme.types';

import CheckIcon from '@mui/icons-material/Check';
import PriorityHighIcon from '@mui/icons-material/PriorityHigh';

interface NotificationAddPaidMethodTypes {
  title: string;
  [key: string]: any;
  message: string;
  type: string;
  labelBtn: string;
  width?: string | number;
  height?: string | number;
  open: boolean;
  setOpen: (v: boolean) => void;
  handleClose?: () => void;
  onClickBtn?: () => void;
}

export const ModalNotificationAddPaidMethod = ({
  title,
  message,
  type,
  labelBtn,
  width,
  height,
  open,
  setOpen,
  handleClose,
  onClickBtn,
  ...props }: NotificationAddPaidMethodTypes) => {
  const styles = makeStyles({
    root: {
      padding: 35,
      width: (props: ThemeTypes) => props.width || 'max-content',
      height: (props: ThemeTypes) => props.height || 'max-content'
    },
    title: {
      fontSize: 18,
      textTransform: 'uppercase',
      textAlign: 'center',
      color: theme.blackPrimary
    },
    text: {
      color: theme.textContentPrimary,
      fontSize: 16,
      marginTop: 10,
      textAlign: 'center'
    },
    containerBtn: {
      marginTop: 25,
      display: 'flex',
      justifyContent: 'center',
    },
    errorContainer: {
      width: 25,
      height: 25,
      borderRadius: '50%',
      backgroundColor: theme.backgroundRed,
      border: `1px solid ${theme.redPrimary}`,
      marginLeft: 20,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      '&>svg': {
        color: theme.redPrimary,
      }
    },
    successContainer: {
      width: 25,
      height: 25,
      borderRadius: '50%',
      backgroundColor: theme.backgroundGreen,
      marginLeft: 20,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      '&>svg': {
        color: theme.greenPrimary,
        width: 20,
        height: 20,
      }
    }
  });

  const defaultTitle = "Default Title"
  const defaultBtnLabel = "text"
  const defaultMessage = "El símbolo del euro es un símbolo monetario usado para el euro, la actual moneda oficial de la eurozona, en la Unión Europea. El diseño fue presentado al público por la Comisión Europea el 12 de diciembre de 1996."

  const classes = styles({
    width,
    height
  });
  return (
    <ResizableModal
      open={open}
      setOpen={setOpen}
      handleClose={handleClose}
      content={(
        <div className={classes.root} {...props}>
          <h1 className={classes.title}>{title || defaultTitle}</h1>
          <div style={{ display: 'flex' }}>
            <p style={{ marginTop: 5 }}>
              {type === 'Error' && (
                <div className={classes.errorContainer}>
                  <PriorityHighIcon />
                </div>
              )}
              {type === 'Success' && (
                <div className={classes.successContainer}>
                  <CheckIcon />
                </div>
              )}
            </p>
            <p className={classes.text}>
              {message || defaultMessage}</p>
          </div>

          <div className={classes.containerBtn}>
            <ButtonForm
              active
              label={labelBtn || defaultBtnLabel}
              onClick={onClickBtn}
            />
          </div>
        </div>
      )}
    />
  )
}