import React from 'react';
import { makeStyles } from '@material-ui/core';
import { theme } from './Theme/theme';
import { ResizableModal } from './ResizableModal';
import { ButtonForm } from './Button';
import { ThemeTypes } from './Theme/theme.types';


interface ValidationPaymentTypes {
  [key: string]: any;
  open: boolean;
  setOpen: (v: boolean) => void;
  handleClose: () => void;
  width: number | string;
  height: number | string;
  labelBtn?: string;
  textOne?: string;
  textTwo?: string;
  amount?: string;
  linkText?: string;
  onClickLink?: () => void;
  title?: string;
  onClickBtn?: () => void;
}

export const ModalValidationPayment = ({
  title,
  open,
  setOpen,
  width,
  height,
  handleClose,
  labelBtn,
  textOne,
  textTwo,
  amount,
  linkText,
  onClickLink,
  onClickBtn,
  ...props
}: ValidationPaymentTypes) => {
  const styles = makeStyles({
    root: {
      padding: 35,
      width: (props: ThemeTypes) => props.width || 'max-content',
      height: (props: ThemeTypes) => props.height || 'max-content'
    },
    title:{
      fontSize: 18,
      textTransform: 'uppercase',
      textAlign: 'center',
      color: theme.blackPrimary
    },
    text:{
      color: theme.textContentPrimary,
      fontSize: 16,
      marginTop: 10,
      textAlign: 'center'
    },
    containerBtn:{
      marginTop: 25,
      display: 'flex',
      justifyContent: 'center',
    },
    link:{
      color: theme.bluePrimary,
      "&:hover":{
        cursor: 'pointer',
        fontWeight: 600
      }
    },
    amount: {
      color: theme.blackPrimary,
      fontWeight: 600
    }

  });
  const classes = styles({
    width,
    height
  });

  const defaultLabelBtn = "text"
  const defaultTitle = "Default title"

  return (
    <ResizableModal
      open={open}
      setOpen={setOpen}
      handleClose={() => handleClose()}
      content={(
        <div className={classes.root} {...props}>
          <h1 className={classes.title}>{title || defaultTitle}</h1>
          {textOne && (
            <p className={classes.text}>
              {textOne}
              {amount && (
                <span className={classes.amount}>&nbsp;{amount}</span>
              )}
              {textTwo && '.' + ' ' + textTwo}
              {linkText && (
                <span className={classes.link} onClick={onClickLink}>&nbsp;{linkText}</span>
              )}
            </p>
          )}
          <div className={classes.containerBtn}>
          <ButtonForm
            active
            label={labelBtn || defaultLabelBtn}
            onClick={onClickBtn}
          />
          </div>
        </div>
      )}
    />
  )
};
