import React, { useState, useEffect } from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';

import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import IconButton from '@material-ui/core/IconButton';
import fileSaver from 'file-saver';

import {
  faMagnifyingGlassPlus,
  faMagnifyingGlassMinus,
  faArrowRight,
  faArrowLeft,
  faDownload
} from '@fortawesome/free-solid-svg-icons';
import { ThemeTypes } from './Theme/theme.types';
import { Page, Document, pdfjs } from 'react-pdf';
pdfjs.GlobalWorkerOptions.workerSrc = `//cdnjs.cloudflare.com/ajax/libs/pdf.js/${pdfjs.version}/pdf.worker.js`

interface PreviewPDFTypes {
  [key: string]: any;
  id: string;
  name: string;
  url: string;
  type: string;
  size?: string;
  created?: Date | string;
  lng?: string;

}

export const PreviewPDF = ({
  id,
  name,
  url,
  type,
  size,
  created,
  lng,
  ...props }: PreviewPDFTypes) => {
  const styles = makeStyles({
    root: {
      width: '100%',
      height: '100%'
    },
    menu: {
      borderTop: `2px solid ${theme.grayPrimary}`,
      backgroundColor: 'rgba(0,0,0,0.1)',
      display: 'flex',
      flexFlow: 'wrap',
      justifyContent: 'space-between',
    },
    iconsZoom: {
      display: 'flex',
      flexFolow: 'wrap',
      justifyContent: 'flex-end',
      alignItems: 'center',
      '&>button': {
        width: 40,
        height: 40,
        margin: 10,
        display: 'flex',
        flexFolow: 'wrap',
        justifyContent: 'center',
        alignItems: 'center',
        '&>span': {
          color: theme.defaultSubtitle,
          padding: 5,
          margin: 5,
          width: 20,
          height: 20,
          '&:hover': {
            color: theme.bluePrimary,
            cursor: 'pointer'
          }
        }
      }
    },
    infoModalFile: {
      marginLeft: 10,
      textAlign: 'left',
      fontSize: 14,
      color: theme.blackPrimary,
      display: 'flex',
      flexFlow: 'column',
      alignItems: 'center',
      marginTop: 4,
      '&>:nth-child(1)': {
        fontSize: 16,
        fontWeight: 700
      }
    },
    previewFile: {
    },
    containerRootPdf: {
      position: 'relative',
      width: 'fit-content',
      maxHeight: 500,
      overflow: 'auto',
      '&::-webkit-scrollbar': {
        width: "5px",
        height: "5px",
        backgroundColor: theme.grayPrimary,
      },
      '&::-webkit-scrollbar-thumb': {
        backgroundColor: theme.opacityGrayDefault,
        borderRadius: "20px",
      },
      "&::-webkit-scrollbar-track": {
        marginBottom: "1px",
      },
      '&>div': {
      },
    },
    containerFiles: {
      zoom: '75%',
      position: 'relative',
      "&>div":{
        "&>div":{          
          "&>div":{
            "&>canvas":{
              width: 'fit-content !important',
              height: 'fit-content !important',
              margin: 'auto',
              transform: (props: ThemeTypes) => `scale(${(props.scale ? props.scale : 100) / 100})`,
            }
          }
        }
      }
    },
    changePages: {
      height: 53,
      width: '100%',
      position: 'absolute',
      top: '90%',
      zIndex: 999,
      backgroundColor: 'rgba(0,0,0,0.7)',
      display: 'flex',
      alignItems: 'center',
    },
    changer: {
      color: 'gainsboro',
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      marginLeft: 40,
      '&>p': {
        margin: 15,
        fontSize: 24,
        fontWeight: 900,
        '&:hover': {
          color: '#3d43ff',
          cursor: 'pointer',
        },
      },
    },
    totalPages: {
      marginInlineStart: 'auto',
      marginRight: 15,
      color: 'gainsboro',
      fontWeight: 900,
    },
    currentPage: {
      marginLeft: '32%',
      fontSize: 18,
      fontWeight: 900,
      color: 'gainsboro',
    },
  });
  const [zoom, setZoom] = useState(100);
  const classes = styles({ scale: zoom });
  const [pageNumber, setPageNumber] = useState(1);
  const [numPages, setNumPages] = useState(0);
  const [disableNextPage, setDisableNextPage] = useState(false);

  const handleZoom = (action: string) => {
    if (action === 'in') {
      setZoom(zoom + 10)
    }
    if (action === 'out' && zoom > 100) {
      setZoom(zoom - 10)
    }
  }

  function onDocumentLoadSuccess({ numPages }: any) {
    setNumPages(numPages)
  }

  useEffect(() => {
    if (pageNumber === numPages) setDisableNextPage(true)
    if (numPages && pageNumber < numPages) setDisableNextPage(false)
  }, [pageNumber])

  useEffect(() => {
    if (numPages === 1) setDisableNextPage(true)
  }, [numPages])

  const handlePage = (page: number, type: string) => {
    if (numPages && page < numPages && !disableNextPage && type === 'NEXT') {
      setPageNumber(page + 1)
    } else if (page > 1 && type === 'BACK') {
      setPageNumber(page - 1)
    }
  }

  const handleDownload = () => {
    fileSaver.saveAs(url, name)
  }

  const Menu = () => {
    return (
      <div className={classes.menu}>
        <div className={classes.infoModalFile}>
          <p>{name}</p>
          <p>{size}</p>
        </div>
        <div className={classes.iconsZoom}>
          <IconButton onClick={() => handleDownload()}>
            <FontAwesomeIcon icon={faDownload} />
          </IconButton>
          {numPages && numPages > 1 && (
            <React.Fragment>
              <p style={{ color: theme.defaultSubtitle, fontSize: 14, fontWeight: 700 }}>
                {`${lng === 'en' ? 'Pages:' : 'Paginas:'} ${numPages}`}
              </p>
              <IconButton onClick={() => handlePage(pageNumber, 'BACK')}>
                <FontAwesomeIcon icon={faArrowLeft} style={{ color: pageNumber === 1 ? theme.opacityGrayDefault : '' }} />
              </IconButton>
              <p style={{ color: theme.defaultSubtitle, fontSize: 14, fontWeight: 700 }}>{pageNumber}</p>
              <IconButton onClick={() => handlePage(pageNumber, 'NEXT')}>
                <FontAwesomeIcon icon={faArrowRight} style={{ color: pageNumber === numPages ? theme.opacityGrayDefault : '' }} />
              </IconButton>
            </React.Fragment>
          )}
          <IconButton onClick={() => handleZoom('in')}>
            <FontAwesomeIcon icon={faMagnifyingGlassPlus} />
          </IconButton>
          <IconButton onClick={() => handleZoom('out')}>
            <FontAwesomeIcon icon={faMagnifyingGlassMinus} />
          </IconButton>
        </div>
      </div>
    )
  }

  return (
    <React.Fragment>

    <div className={classes.root} {...props}>
      <div className={classes.previewFile}>
        <div className={classes.containerRootPdf}>
          <div
            className={classes.containerFiles}
          >
            <div>
              <Document
                file={url}
                onLoadError={console.error}
                onLoadSuccess={onDocumentLoadSuccess}
                >
                <Page size="A4" pageNumber={pageNumber} />
              </Document>
            </div>
          </div>
        </div>
      </div>
    </div>
      {Menu()}
    </React.Fragment>
  )
}