import React, { useState } from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';

/* Icons */

import KeyboardArrowDownIcon from '@mui/icons-material/KeyboardArrowDown';
import KeyboardArrowUpIcon from '@mui/icons-material/KeyboardArrowUp';
import KeyboardBackspaceIcon from '@mui/icons-material/KeyboardBackspace';


type ItemsType = {
  title?: string;
  onClickItem?: () => void;
  referenceBold?: string;
}
type SectionTypes = {
  title?: string;
  icon?: JSX.Element | JSX.Element[] | any;
  onClick?: () => void;
  referenceBold?: string;
  items: ItemsType[]
}
interface PrincipalMenuTypes {
  routeLocation?: string;
  sections?: SectionTypes[];
  submenu?: JSX.Element | JSX.Element[];
  backArrow?: boolean;
  onClickBack?: () => void;
  [key: string]: any;
}

export const PrincipalMenu = ({ sections, routeLocation, submenu, backArrow, onClickBack, ...props }: PrincipalMenuTypes|any) => {
  const styles = makeStyles({
    root: {
      borderRight: `2px solid ${theme.grayPrimary}`,
      height: '100vh',
      width: 257,
      backgroundColor: theme.whitePrimary
    },
    containerItem: {
      color: theme.opacityGrayDefault,
      textTransform: 'uppercase',
      fontSize: 16,
      fontWeight: 400,
      margin: '20px 0px 0px 40px',
      '&>span': {
        '&>svg': {
          marginRight: 15,
        }
      },
      '&:hover': {
        color: theme.bluePrimary,
        cursor: 'pointer'
      }
    },
    containerItemSelected: {
      color: theme.blackPrimary,
      textTransform: 'uppercase',
      fontSize: 16,
      fontWeight: 400,
      margin: '20px 0px 0px 40px',
      '&>span': {
        '&>svg': {
          marginRight: 15,
        }
      },
      '&:hover': {
        color: theme.bluePrimary,
        cursor: 'pointer'
      }
    },
    arrow: {
      marginLeft: 10
    },
    item: {
      color: theme.opacityGrayDefault,
      fontSize: 16,
      textTransform: 'capitalize',
      width: 'max-content',
      marginInlineStart: 'auto',
      marginRight: 40,
    },
    textItem: {
      '&:hover': {
        color: theme.bluePrimary,
        cursor: 'pointer'
      }
    },
    textItemSelected: {
      color: theme.blackPrimary,
      '&:hover': {
        color: theme.bluePrimary,
        cursor: 'pointer'
      }
    },
    containerSubmenu:{
      marginTop: 70,
      borderTop: `2px solid ${theme.grayPrimary}`,
      margin: 'auto',
      width: '100%',
      '&>div':{
        marginTop: 70,
        padding: '0px 0px 0px 40px'
      }
    },
    backArrow:{    
      textTransform: 'uppercase',
      color: theme.opacityGrayDefault,
      fontSize: 14,
      display:'flex',
      alignItems: 'center',
      marginLeft: 40,
      '&>svg':{
        marginRight: 10
      },
      '&:hover':{
        color: theme.bluePrimary,
        cursor: 'pointer'
      }
    }
  });
  const classes = styles();
  const [open, setOpen] = useState<{[key:string]: string|undefined|number|boolean}>({ title: '', index: 0, opened: false })

  const openSection = (title: string|undefined, index: number|undefined, onClick: any) => {
    console.log({
      title: title,
      index: index,
    })
    setOpen({
      title: title,
      index: index,
      opened: !open.opened
    })
    onClick && onClick()
  }

  return (
    sections && (
      <div className={classes.root} {...props}>
        {backArrow && <p className={classes.backArrow} onClick={onClickBack}><KeyboardBackspaceIcon/>Dashboard</p>}
        {sections.map((v: SectionTypes, index: number) => (
          <>
            <p className={routeLocation === v.referenceBold ? classes.containerItemSelected : classes.containerItem} onClick={() => openSection(v.title, index, v.onClick)} key={index}>
              <span><v.icon /></span>
              {v.title}
              {v.items && v.items.length > 0 && (
                <span className={classes.arrow}>
                  {open && open.opened && open.title === v.title ? <KeyboardArrowUpIcon/> : <KeyboardArrowDownIcon />}
                </span>
              )}
            </p>
            {open && open.opened && open.title === v.title && (
              <div className={classes.item}>
                {v.items && v.items.length > 0 && v.items.map((item: ItemsType , index: number) => (
                  <p key={index} onClick={item?.onClickItem} className={routeLocation === item?.referenceBold ? classes.textItemSelected : classes.textItem} >{item?.title}</p>
                ))}
              </div>
            )}
          </>
        ))}
        {submenu && <div className={classes.containerSubmenu}>{submenu}</div>}
      </div>
    )
  )
}