import React from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';
import { ThemeTypes } from "./Theme/theme.types";


interface SelectableCardTypes {
  width?: string | number;
  height?: string | number;
  title: string;
  description: string;
  active?: boolean;
  onClick?: () => void;
  [key: string]: any;
}


export const SelectableCard = ({ width, height, title, description, active, ...props }: SelectableCardTypes) => {

  const defaultWidth = 210;

  const styles = makeStyles({
    selected: {
      border: `2px solid ${theme.bluePrimary}`,
      borderRadius: 5,
      padding: 37,
      backgroundColor: theme.whitePrimary,
      textAlign: 'left',
      width: (props: ThemeTypes) => props.width || defaultWidth,
      '&:hover':{
        border: `2px solid ${theme.bluePrimary}`,
        cursor: 'pointer',
      },
      '&>h1': {
        textTransform: 'uppercase',
        fontFamily: 'Poppins',
        fontSize: 15,
        color: theme.blackPrimary,
        margin: 0,
        fontWeight: 500
      },
      '&>h4': {
        textTransform: 'capitalize',
        fontFamily: 'Poppins',
        fontSize: 14,
        color: theme.textContentPrimary,
        fontWeight: 400
      }
    },
    notSelected: {
      border: `2px solid ${theme.grayPrimary}`,
      borderRadius: 5,
      padding: 37,
      backgroundColor: theme.whitePrimary,
      textAlign: 'left',
      width: (props: ThemeTypes) => props.width || defaultWidth,
      '&:hover':{
        border: `2px solid ${theme.bluePrimary}`,
        cursor: 'pointer',
      },
      '&>h1': {
        textTransform: 'uppercase',
        fontFamily: 'Poppins',
        fontSize: 15,
        color: theme.blackPrimary,
        margin: 0,
        fontWeight: 500
      },
      '&>h4': {
        textTransform: 'capitalize',
        fontFamily: 'Poppins',
        fontSize: 14,
        color: theme.textContentPrimary,
        fontWeight: 400,
      }

    }
  });
  const classes = styles({ width, height });
  return (
    <div {...props} className={active ? classes.selected : classes.notSelected}>
      <h1>{title}</h1>
      <h4>{description}</h4>
    </div>
  )
}
