import React, { useState, useEffect } from 'react';
/* Components */
import TextField from '@material-ui/core/TextField';
import IconButton from '@material-ui/core/IconButton';

/* Styles */
import InputAdornment from '@material-ui/core/InputAdornment';
import { makeStyles } from "@material-ui/core";
import { theme as StoryTheme } from './Theme/theme';
import KeyboardArrowUpIcon from '@mui/icons-material/KeyboardArrowUp';
import KeyboardArrowDownIcon from '@mui/icons-material/KeyboardArrowDown';
import SearchIcon from '@mui/icons-material/Search';

/* Configs */

interface PropTypes {
	id?: string
	onMouseEnter?: (value: any) => void
	onMouseLeave?: (value: any) => void
	onKeyDown?: (value: any) => void
	onClick?: (value: any) => void
	onChange?: (value: any) => void
	listData?: any
	value?: any
	hideSearch?: boolean,
	label?: string
	name?: string | null | undefined
	type?: string
	section?: string
	disabled?: boolean
	setValue?: any
	selectOption?: any
	width?: number
	setTitle?: any;
	[key: string]: any;
}

export const Selector = ({
	id,
	onMouseEnter,
	onMouseLeave,
	onKeyDown,
	onClick,
	onChange,
	listData,
	value,
	setValue,
	hideSearch = false,
	label,
	name,
	type,
	section,
	disabled,
	selectOption,
	width,
	setTitle,
	...props
}: PropTypes) => {
	const [upArrow, setUpArrow] = useState(false)
	const [listDataToFilter, setListDataToFilter] = useState([])

	useEffect(() => {
		setUpArrow(false)
		setListDataToFilter(listData)
	}, [listData])

	const classes: any = styles({
		border: upArrow ? 'none' : `1px solid ${StoryTheme.borderGreyPrimary}`,
		borderBottom: upArrow ? `1px solid ${StoryTheme.bluePrimary}` : `1px solid ${StoryTheme.borderGreyPrimary}`
	})

	const handleChangeIcon = () => {
		setUpArrow(!upArrow)
	}
	/* Retorno de resultados filtrados */
	const handleFilterResults = (event: any, section: any) => {
		switch (section) {
			case 'COUNTRY':
				if (listDataToFilter) {
					return setListDataToFilter(listData.filter((data: any) => data.country.toLowerCase().includes(event.toLowerCase())))
				}
				break
			case 'LANGUAGE':
			case 'DEFAULT':
				if (listDataToFilter) {
					return setListDataToFilter(listData.filter((data: any) => data.toLowerCase().includes(event.toLowerCase())))
				}
				break
			case 'CHECKOUT':
				if (listDataToFilter) {
					return setListDataToFilter(listData.filter((data: any) => data.name_es.toLowerCase().includes(event.toLowerCase())))
				}
				break
			case 'COUNTRY_CODE':
				if (listDataToFilter) {
					return setListDataToFilter(listData.filter((data: any) => data.name_es.toLowerCase().includes(event.toLowerCase())))
				}
				break
			default:
		}
	}
	/* seleccion de valores */
	const handleClick = (section: any, data: any) => {
		switch (section) {
			case 'COUNTRY':
				(data && typeof selectOption === 'function') && selectOption(data)
				setUpArrow(!upArrow)
				break
			case 'LANGUAGE':
			case 'DEFAULT':
				setValue(data)
				setUpArrow(!upArrow)
				break
			case 'CHECKOUT':
				setValue(`${data.name_es}, ${data.code}`)
				setUpArrow(!upArrow)
				break
			case 'COUNTRY_CODE':
				setValue(`${data.name_es}, ${data.code}`)
				setUpArrow(!upArrow)
				break
			case 'PROPOSAL_MODAL':
				console.log('data project:', data)
				setValue(data.id)
				setTitle(data.title)
				break
			default:
				setUpArrow(!upArrow)
		}
	}

	/* Retorno de valores para inputs Search */
	const handleValues = (value: any) => {
		if (value && value !== '') return value
	}
	/* Retorno de valores seleccionados */
	const returnResults = (listDataToFilter: any, section: any) => {
		if (listDataToFilter && listDataToFilter.length > 0) {
			switch (section) {
				case 'COUNTRY':
					return (
						listDataToFilter && listDataToFilter.map((data: any) => (
							<div className={classes.results}>
								<p onClick={() => handleClick(section, data)} >{data.country}</p>
							</div>
						))
					)
				case 'LANGUAGE':
					return (
						listDataToFilter && listDataToFilter.map((data: any) => (
							<div className={classes.results}>
								<p onClick={() => handleClick(section, data)} >{data}</p>
							</div>
						))
					)
				case 'DEFAULT':
					return (
						listDataToFilter && listDataToFilter.map((data: string) => (
							<div className={classes.results}>
								<p onClick={() => handleClick(section, data)} >{data}</p>
							</div>
						))
					)
				case 'COUNTRY_CODE':
					return (
						listDataToFilter && listDataToFilter.map((data: any) => (
							<div className={classes.results}>
								<p onClick={() => handleClick(section, data)} >{data.name_es}</p>
							</div>
						))
					)
				case 'PROPOSAL_MODAL':
					return (
						listDataToFilter && listDataToFilter.map((data: any) => (
							<div className={classes.results}>
								<p onClick={() => handleClick(section, data)} >{data.title}</p>
							</div>
						))
					)
				case 'CHECKOUT':
					return (
						listDataToFilter && listDataToFilter.map((data: any) => (
							<div className={classes.results}>
								<p onClick={() => handleClick(section, data)}>{`${data.name_es}, ${data.code}`}</p>
							</div>
						))
					)
				default:
			}
		} else {
			return (<p className={classes.noResults}>No hay resultados</p>)
		}
	}

	return (
		<div {...props} style={{ position: upArrow ? 'absolute' : 'relative', zIndex: upArrow ? 9999 : 100 }}>
			{upArrow && (<div className={classes.backWall} onClick={() => setUpArrow(false)} />)}
			<div className={classes.root} style={{ border: upArrow ? `2px solid ${StoryTheme.bluePrimary}` : '', width: width || '', zIndex: upArrow ? 9999 : 100 }} >
				<TextField
					className={classes.field}
					id={id}
					type={type}
					value={value || ''}
					onChange={onChange}
					label={label}
					onMouseEnter={onMouseEnter}
					onMouseLeave={onMouseLeave}
					fullWidth
					autoComplete="off"
					disabled
					name={name ? name : undefined}
					InputProps={{
						endAdornment:
							(
								<InputAdornment position="start">
									<div style={{ paddingRight: '12px' }} onClick={() => handleChangeIcon()}>
										{
											!upArrow ?
												<IconButton style={{ width: 36, height: 36 }}>
													<KeyboardArrowDownIcon className={classes.arrow} style={{ border: `2px solid ${StoryTheme.borderGreyPrimary}` }} />
												</IconButton>
												:
												<IconButton style={{ width: 36, height: 36 }}>
													<KeyboardArrowUpIcon className={classes.arrow} style={{ border: `1px solid ${StoryTheme.bluePrimary}` }} />
												</IconButton>
										}
									</div>
								</InputAdornment>
							)
					}}
				/>
				{upArrow && (
					<div className={classes.selector}>
						<div className={classes.inputSearch}>
							{!hideSearch && (
								<TextField
									className={classes.fieldSearch}
									id={id}
									type={type}
									value={value ? handleValues(value) : null}
									onChange={(event) => handleFilterResults(event.target.value, section)}
									onKeyDown={onKeyDown}
									label={label}
									onMouseEnter={onMouseEnter}
									onMouseLeave={onMouseLeave}
									fullWidth
									autoComplete="off"
									disabled={disabled}
									name={name ? name : undefined}
									autoFocus
									InputProps={{
										endAdornment:
											(
												<InputAdornment position="start">
													<div style={{ paddingRight: '12px' }}>
														<SearchIcon className={classes.arrow} />
													</div>
												</InputAdornment>
											)
									}}
								/>
							)}
							{upArrow && listDataToFilter && (
								<div className={classes.containerResults}>
									{returnResults(listDataToFilter, section)}
								</div>
							)
							}
						</div>
					</div>
				)}
			</div>
		</div>
	)
}
const styles: any = makeStyles({
	backWall: {
		backgroundColor: 'transparent',
		position: 'fixed',
		width: '100%',
		height: '100%',
		top: 0,
		left: 0,
		zIndex: 998
	},
	root: {
		display: 'flex',
		flexDirection: 'column',
		alignSelf: 'center',
		width: '100%',
		borderRadius: 6,
		position: 'relative',
		zIndex: 998,
		'& > .MuiPaper-elevation3': {
			boxShadow: 'none',
			backgroundColor: 'white',
		},
		'&:focus-visible': {
			outline: `1px solid ${StoryTheme.bluePrimary}`
		}
	},
	field: {
		border: (props: { border: string }) => props.border,
		borderBottom: (props: any) => props.borderBottom,
		width: '100%',
		outline: "none",
		borderRadius: 4,
		'& > .MuiInputBase-root': {
			marginTop: 1,
			borderRadius: 4,
			'& > .MuiInputBase-input': {
				paddingLeft: 20,
				paddingRight: 20,
				paddingTop: 24,
				paddingBottom: 15,
				color: StoryTheme.blackPrimary,
				padding: 0,
				borderRadius: 4,
				backgroundColor: "transparent",
				zIndex: 100,
				'&:focus': {
					border: 'none'
				}
			},
		},
		'& > .MuiInput-root': {
			backgroundColor: StoryTheme.whitePrimary,
		},
		'& > .MuiInput-underline:before': {
			borderBottom: 'none',
			content: 'none'
		},
		'& > .MuiInput-underline:after': {
			backgroundColor: 'white',
			borderBottom: 'none',
		},
		'& > .MuiInput-underline:hover': {
			backgroundColor: 'white',
		},
		'& > .MuiInputLabel-animated': {
			color: 'grey',
			zIndex: 99,
			marginTop: 0,
			paddingTop: 8,
			paddingLeft: 15,
			fontSize: 16,
			transition: 'color 200ms cubic-bezier(0.0, 0, 0.2, 1) 0ms,transform 200ms cubic-bezier(0.0, 0, 0.2, 1) 0ms',
		},
		'& > .MuiInputLabel-root:before': {
			color: StoryTheme.bluePrimary,
		},
		'&:focus-visible': {
			outline: `1px solid ${StoryTheme.bluePrimary}`
		}
	},
	fieldSearch: {
		border: `1px solid ${StoryTheme.bluePrimary}`,
		width: '100%',
		outline: "none",
		borderRadius: 4,
		'& > .MuiInputBase-root': {
			marginTop: 1,
			borderRadius: 4,
			'& > .MuiInputBase-input': {
				paddingLeft: 20,
				paddingRight: 20,
				paddingTop: 24,
				paddingBottom: 15,
				color: StoryTheme.blackPrimary,
				padding: 0,
				borderRadius: 4,
				backgroundColor: "transparent",
				zIndex: 100,
				'&:focus': {
					border: 'none'
				}
			}
		},
		'& > .MuiInput-root': {
			backgroundColor: StoryTheme.whitePrimary,
		},
		'& > .MuiInput-underline:before': {
			borderBottom: 'none',
			content: 'none'
		},
		'& > .MuiInput-underline:after': {
			backgroundColor: 'white',
			borderBottom: 'none',
		},
		'& > .MuiInput-underline:hover': {
			backgroundColor: StoryTheme.whitePrimary,
		},
		'& > .MuiInputLabel-animated': {
			color: 'grey',
			zIndex: 99,
			marginTop: 0,
			paddingTop: 8,
			paddingLeft: 15,
			fontSize: 16,
			transition: 'color 200ms cubic-bezier(0.0, 0, 0.2, 1) 0ms,transform 200ms cubic-bezier(0.0, 0, 0.2, 1) 0ms',
		},
		'& > .MuiInputLabel-root:before': {
			color: StoryTheme.bluePrimary,
		},
		'&:focus-visible': {
			outline: `1px solid ${StoryTheme.bluePrimary}`
		}
	},
	arrow: {
		color: 'grey',
		width: '35px !important',
		height: '35px !important',
		borderRadius: '50%',
		cursor: 'pointer',
		position: 'relative',
		zIndex: 990
	},
	selector: {
		border: `1px solid ${StoryTheme.borderGreyPrimary}`,
		minHeight: 190,
		backgroundColor: StoryTheme.whitePrimary,
		'&:focus-visible': {
			outline: `1px solid ${StoryTheme.bluePrimary}`
		}
	},
	inputSearch: {
		padding: 25,
		'&:focus-visible': {
			outline: `1px solid ${StoryTheme.bluePrimary}`
		}
	},
	containerResults: {
		maxHeight: 150,
		height: 'min-content',
		overflowX: 'auto',
		marginTop: 15,
		'&::-webkit-scrollbar': {
			width: "5px",
			backgroundColor: "#F2F4F6",
		},
		'&::-webkit-scrollbar-thumb': {
			backgroundColor: "#93A0AD",
			borderRadius: "238px",

		},
		"&::-webkit-scrollbar-track": {
			marginBottom: "70px",

		},
	},
	results: {
		fontSize: 15,
		'&>p': {
			padding: '6px 6px 6px 4px',
			margin: 0,
			textAlign: 'left',
			'&:hover': {
				backgroundColor: StoryTheme.hoverBlue,
				cursor: 'pointer'
			}
		}
	},
	noResults: {
		textAlign: 'center',
		marginTop: 15
	},
	errorMaxTags: {
		display: 'flex',
		justifyContent: 'center',
		'&>div': {
			width: 300,
			textAlign: 'center',
		}
	},
	containerTags: {
		border: `1px solid ${StoryTheme.borderGreyPrimary}`,
		marginTop: 10,
		padding: 15,
		display: 'flex',
		flexFlow: 'wrap'
	},
	tag: {
		backgroundColor: '#f2f4f6',
		borderRadius: 4,
		margin: 5,
		width: 'max-content',
		padding: 8,
		display: 'flex'
	},
	tagTitle: {
		fontSize: 14
	},
	crossTag: {
		marginLeft: 20,
		'&:hover': {
			fontWeight: 700,
			cursor: 'pointer'
		}
	}
})
