import React, { useState, useEffect } from 'react';
import { makeStyles } from "@material-ui/core";

import KeyboardArrowDownIcon from '@mui/icons-material/KeyboardArrowDown';
import KeyboardArrowUpIcon from '@mui/icons-material/KeyboardArrowUp';

import IconButton from '@material-ui/core/IconButton';

import { theme } from './Theme/theme';

interface SimpleSelectorTypes {
  label?: string;
  [key: string]: any;
  list?: string[];
  onClick?: () => void;
  setValue?: (v: string | number) => void;
  value?: string | number;
}

export const SimpleSelector = ({
  label,
  list,
  onClick,
  setValue,
  value,
  ...props }: SimpleSelectorTypes) => {
  const styles = makeStyles({
    root: {
      width: 'max-content',
      display: 'flex',
      fontSize: 14,
      alignItems: 'center',
    },
    containerValue: {
      position: 'relative',
      display: 'flex',
      alignItems: 'center',
      marginLeft: 10,
      '&>span': {
        marginLeft: 6,
        '&>button': {
          width: 15,
          height: 15
        }
      }
    },
    containerValues: {
      position: 'absolute',
      zIndex: 999,
      backgroundColor: theme.whitePrimary,
      width: 'max-content',
      height: 'max-content',
      maxHeight: 260,
      top: 30,
      right: 0,
      border: `1px solid ${theme.borderGreyPrimary}`,
      borderRadius: 5,
      padding: 15,
      boxShadow: theme.shadowSimple,
      overflowX: 'auto',
      '&::-webkit-scrollbar': {
        width: "5px",
        backgroundColor: theme.grayPrimary,
      },
      '&::-webkit-scrollbar-thumb': {
        backgroundColor: theme.opacityGrayDefault,
        borderRadius: "20px",
      },
      "&::-webkit-scrollbar-track": {
        marginBottom: "1px",
      },
    },
    itemSelected: {
      margin: 10,
      color: theme.blackPrimary,
      fontWeight: 600,
      '&:hover': {
        cursor: 'pointer',
        fontWeight: 600
      }
    },
    item: {
      margin: 10,
      color: theme.opacityGrayDefault,
      '&:hover': {
        color: theme.blackPrimary,
        cursor: 'pointer',
        fontWeight: 600
      }
    },
    backWall: {
      position: 'fixed',
      backgroundColor: 'transparent !important',
      top: 0,
      left: 0,
      right: 0,
      width: '100%',
      height: '100%'
    }
  });
  const classes = styles();
  const [valueLocal, setValueLocal] = useState<string | number>("");
  const [open, setOpen] = useState(false);

  useEffect(() => {
    if (list && list.length > 0) {
      setValueLocal(list[0]);
    }
  }, [list])

  const handleSetValue = (v: string | number) => {
    setValue && setValue(v)
    setValueLocal(v)
  }

  return (
    <>
      {open && (<div className={classes.backWall} onClick={() => setOpen(!open)} />)}
      <div className={classes.root} {...props} >
        <div>
          <p>{label}:&nbsp;</p>
        </div>
        <div className={classes.containerValue}>
          <p>{valueLocal}</p>
          <span>
            <IconButton onClick={() => setOpen(!open)}>
              {!open ? (<KeyboardArrowDownIcon />) : (<KeyboardArrowUpIcon />)}
            </IconButton>
          </span>
          {open &&
            (
              <div className={classes.containerValues}>
                {list && list.length > 0 && list.map((v, i) => (
                  <p
                    key={i}
                    onClick={() => handleSetValue(v)}
                    className={v === valueLocal ? classes.itemSelected : classes.item}
                  >
                    {v}
                  </p>
                ))}
              </div>
            )}
        </div>
      </div>
    </>
  )
}