import React from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';
import { ThemeTypes } from './Theme/theme.types';

/* Icons */
import IconButton from '@material-ui/core/IconButton';
import WorkOutlineOutlinedIcon from '@mui/icons-material/WorkOutlineOutlined';
import EditIcon from '@mui/icons-material/Edit';
import DeleteOutlineIcon from '@mui/icons-material/DeleteOutline';
import ChromeReaderModeOutlinedIcon from '@mui/icons-material/ChromeReaderModeOutlined'



interface AbilityTypes {
  abilityId: string;
  abilityTitle: string;
}

interface ListAbilityTypes {
  id: string;
  categoryId: string;
  categoryTitle: string;
  specialityId: string;
  specialityTitle: string;
  experience: string
  description: string;
  userId: string;
  abilities: AbilityTypes[]
}

interface ListExperienceTypes {
  id: string,
  title: string,
  enterprise: string;
  description: string;
  initialDate: string;
  endDate?: string;
  userId: string;
  created: Date;
}

type ListFormationTypes = Omit<ListExperienceTypes, 'enterprise'> & { center?: string }

interface SkillCardTypes {
  type: string;
  listAbility?: ListAbilityTypes;
  width?: string | number;
  height?: string | number;
  onClickEdit?: () => void;
  onClickDelete?: () => void;
  [key: string]: any;
  listExperience?: ListExperienceTypes;
  lng?: string;
  listFormation?: ListFormationTypes;
  noIcons?: boolean;
  description?: string;
  Icon?: JSX.Element | any;
}

export const SkillCard = ({
  type,
  listAbility,
  width,
  height,
  onClickEdit,
  onClickDelete,
  listExperience,
  lng,
  listFormation,
  noIcons,
  description,
  Icon,
  ...props }: SkillCardTypes) => {
  const styles = makeStyles({
    root: {
      width: (props: ThemeTypes) => props.width || '100%',
      height: (props: ThemeTypes) => props.height || '100%',
      border: `2px solid ${theme.grayPrimary}`,
      borderRadius: 5,
      backgroundColor: theme.whitePrimary,
      padding: 30,
      '&>.iconsEditable': {
        display: 'none'
      },
      '&:hover': {
        border: `2px solid ${theme.bluePrimary}`,
        backgroundColor: theme.whiteOpacity,
        position: 'relative',
        '&>div': {
          opacity: .50
        },
        '&>.iconsEditable': {
          display: 'inline',
          right: 0,
          position: 'absolute',
          zIndex: 99,
          margin: '0px 40px 0px 0px',
          padding: 0,
          '&>button': {
            color: theme.defaultSubtitle,
            padding: 5,
            margin: '0px 0px 0px 20px',
            backgroundColor: theme.whitePrimary,
            border: `1px solid ${theme.borderGreyPrimary}`
          }
        }
      }
    },
    rowHeader: {
      display: 'flex',
      alignItems: 'center',
    },
    workIcon: {
      margin: '0px 20px 0px 0px',
      '&>svg': {
        width: 24,
        height: 24,
        color: theme.opacityGrayDefault
      }
    },
    titleCard: {
      color: theme.blackPrimary,
      fontSize: 18,
      margin: 0,
    },
    experience: {
      color: theme.blackPrimary,
      fontSize: 16,
      marginInlineStart: 'auto'
    },
    rowContent: {
      margin: '0px 40px 0px 40px',
    },
    content: {
      color: theme.textContentPrimary,
      fontSize: 16
    },
    tagsContainer: {
      display: 'flex',
      flexFlow: 'wrap',
      rowGap: 15,
      marginTop: 20
    },
    tag: {
      color: theme.defaultSubtitle,
      fontSize: 16,
      borderRadius: 5,
      backgroundColor: theme.grayPrimary,
      width: 'max-content',
      height: 'max-content',
      padding: '10px 15px 10px 15px',
      margin: '0px 15px 0px 0px'
    }
  });
  const classes = styles({
    width,
    height
  });
  const returnDatesExperience = (date: string | undefined, lng: string | undefined) => {
    try {
      if (date) {
        let month, year;
        month = date.split("/")[1].slice(0, 2)
        year = date.split("/")[2]
        switch (month) {
          case "01":
            month = lng === "en" ?  "January" :"Enero"
            break
          case "02":
            month = lng === "en" ?  "February" : "Febrero"
            break
          case "03":
            month = lng === "en" ?  "March" : "Marzo"
            break
          case "04":
            month = lng === "en" ?  "April" : "Abril"
            break
          case "05":
            month = lng === "en" ?  "May" : "Mayo"
            break
          case "06":
            month = lng === "en" ?  "June" : "Junio"
            break
          case "07":
            month = lng === "en" ?  "July" : "Julio"
            break
          case "08":
            month = lng === "en" ?  "August" : "Agosto"
            break
          case "09":
            month = lng === "en" ?  "September" : "Setiembre"
            break
          case "10":
            month = lng === "en" ?  "October" : "Octubre"
            break
          case "11":
            month = lng === "en" ?  "November" : "Noviembre"
            break
          case "12":
            month = lng === "en" ?  "December" : "Diciembre"
            break

          default:
            month = month
        }
        return `${month} ${year}`
      } else {
        return lng === 'en' ? "Present" : "Actualidad"
      }
    } catch (err) {
      console.log("ERROR_RETURN_DATE_EXPERIENCE")
    }
  }

  const CardAbility = () => {
    return (
      <div className={classes.root} {...props}>
        {!noIcons && <section className='iconsEditable'>
          <IconButton onClick={onClickEdit}>
            <EditIcon />
          </IconButton>
          <IconButton onClick={onClickDelete}>
            <DeleteOutlineIcon />
          </IconButton>
        </section>}
        <div className={classes.rowHeader}>
          <span className={classes.workIcon}>
            <WorkOutlineOutlinedIcon />
          </span>
          <p className={classes.titleCard}>
            {listAbility?.specialityTitle}
          </p>
          <p className={classes.experience}>
            {listAbility?.experience}
          </p>
        </div>
        <div className={classes.rowContent}>
          <p className={classes.content}>{listAbility?.categoryTitle}</p>
          <p className={classes.content}>“{listAbility?.description}“</p>
          <div className={classes.tagsContainer}>
            {listAbility?.abilities && listAbility?.abilities.length > 0 && listAbility?.abilities?.map(ab => (
              <div className={classes.tag} key={ab.abilityId}>
                {ab.abilityTitle}
              </div>
            ))}
          </div>
        </div>
      </div>
    )
  }
  const CardCurriculum = () => {
    return (
      <div className={classes.root} {...props}>
      {!noIcons && <section className='iconsEditable'>
        <IconButton onClick={onClickEdit}>
          <EditIcon />
        </IconButton>
        <IconButton onClick={onClickDelete}>
          <DeleteOutlineIcon />
        </IconButton>
      </section>}
      <div className={classes.rowHeader}>
        <span className={classes.workIcon}>
          <ChromeReaderModeOutlinedIcon />
        </span>
        <p className={classes.titleCard}>
          {listFormation?.title}
        </p>
        <p className={classes.experience}>
          {returnDatesExperience(listFormation?.initialDate, lng)}&nbsp;-&nbsp;{returnDatesExperience(listFormation?.endDate, lng)}
        </p>
      </div>
      <div className={classes.rowContent}>
        <p className={classes.content}>{listFormation?.center}</p>
        <p className={classes.content}>“{listFormation?.description}“</p>
      </div>
    </div>
    )
  }
  const CardExperience = () => {
    return (
      <div className={classes.root} {...props}>
        {!noIcons && <section className='iconsEditable'>
          <IconButton onClick={onClickEdit}>
            <EditIcon />
          </IconButton>
          <IconButton onClick={onClickDelete}>
            <DeleteOutlineIcon />
          </IconButton>
        </section>}
        <div className={classes.rowHeader}>
          <span className={classes.workIcon}>
            <WorkOutlineOutlinedIcon />
          </span>
          <p className={classes.titleCard}>
            {listExperience?.title}
          </p>
          <p className={classes.experience}>
            {returnDatesExperience(listExperience?.initialDate, lng)}&nbsp;-&nbsp;{returnDatesExperience(listExperience?.endDate, lng)}
          </p>
        </div>
        <div className={classes.rowContent}>
          <p className={classes.content}>{listExperience?.enterprise}</p>
          <p className={classes.content}>“{listExperience?.description}“</p>
        </div>
      </div>
    )
  }

  const CardSimple = () => {
    return (
      <div className={classes.root} {...props}>
      <div style={{ display: 'flex'}}>
        <span className={classes.workIcon}>
          {Icon ? Icon : <WorkOutlineOutlinedIcon />}
        </span>
        <div className={classes.rowContent} style={{ padding: 0 }}>
        <p className={classes.content} style={{ padding: 0, margin: 0 }}>{description}</p>
      </div>
      </div>
    </div>
    )
  }

  return (
    <>
      {type === 'ABILITY' && CardAbility()}
      {type === 'EXPERIENCE' && CardExperience()}
      {type === 'CURRICULUM' && CardCurriculum()}
      {type === 'SIMPLE' && CardSimple()}
    </>
  )
}