import React from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';
import { ThemeTypes } from "./Theme/theme.types";

interface TitleTypes {
    step: number
    list: { title: string, subtitle: string }[];
    setStep?: (v: number) => void;
    marginTop?: number|string;
    [key: string]: any;
}

export const Stepper = ({ step, list,setStep, marginTop, ...props }: TitleTypes) => {
    const styles = makeStyles({
        container:{
            borderRight: `2px solid ${theme.dividerGray}`,
            width: 'max-content',
            paddingRight: 50,
            marginTop: (props: ThemeTypes) => props.marginTop ? props.marginTop : 0
        },
        root: {
            display: 'flex',
            '&:hover':{
                cursor: 'pointer'
            }
        },
        selectedNumber: {
            color: theme.blackPrimary,
            fontSize: 30,
            margin: '10px 0px 0px 0px',
            padding: 0,
            fontFamily: 'Poppins'
        },
        stepNumber: {
            color: theme.opacityGrayDefault,
            fontSize: 30,
            margin: '10px 0px 0px 0px',
            padding: 0,
            fontFamily: 'Poppins'
        },
        selectedText: {
            '&>p': {
                color: theme.blackPrimary,
                margin: '10px 0px 0px 18px',
                padding: 0,
                fontSize: 20,
                fontFamily: 'Poppins',
            },
            '&>:nth-child(2)':{
                textTransform: 'uppercase',
                marginTop: 3,
                fontSize: 16
            }
        },
        stepText: {
            '&>p': {
                color: theme.opacityGrayDefault,
                margin: '10px 0px 0px 18px',
                padding: 0,
                fontSize: 20,
                fontFamily: 'Poppins'
            },
            '&>:nth-child(2)':{
                textTransform: 'uppercase',
                marginTop: 3,
                fontSize: 16
            }
        }
    });
    const classes = styles({marginTop});

   
    return (
        <div {...props} className={classes.container}>
            {list && list.map((i, index) => (
                <div className={classes.root} onClick={() => setStep && setStep(index)}>
                    <p className={index <= step ? classes.selectedNumber : classes.stepNumber}>{index + 1}.</p>
                    <div className={index <= step ? classes.selectedText : classes.stepText}>
                        <p>{i.title}</p>
                        <p>{i.subtitle}</p>
                    </div>
                </div>
            ))}
        </div>
    )
}