import React from 'react';
import { makeStyles } from '@material-ui/core';
import { theme } from './Theme/theme';
import { ThemeTypes } from './Theme/theme.types';
import Checkbox from '@mui/material/Checkbox';

interface TermsAndConditionsStruct {
  [key: string]: any;
  content?: JSX.Element;
  width?: string | number;
  label?: string;
  checked: boolean;
  setChecked?: (v: boolean) => void;
}

export const TermsAndConditions = ({
  content,
  width,
  label,
  checked,
  setChecked,
  ...props
}: TermsAndConditionsStruct) => {
  const styles = makeStyles({
    root: {
      border: `1px solid ${theme.borderGreyPrimary}`,
      borderRadius: 4,
      padding: 24,
      width: (props: ThemeTypes) => props.width || 320,
      height: 'max-content',
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
    },
    content: {
      '&>p': {
        fontSize: 14,
        fontWeight: 400,
        color: theme.blackPrimary,
        '&>span': {
          color: theme.bluePrimary,
          fontWeight: 400,
          '&:hover': {
            cursor: 'pointer',
          },
        },
      },
    },
    containerCheck: {
      marginRight: 25,
    },
  });
  const classes = styles({ width });
  const labelValue = {
    inputProps: { 'aria-label': label || 'Checkbox default' },
  };
  return (
    <div className={classes.root} {...props}>
      <div className={classes.containerCheck}>
        <Checkbox
          {...labelValue}
          checked={checked}
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setChecked && setChecked(e.target.checked)
          }
        />
      </div>
      <div className={classes.content}>{content}</div>
    </div>
  );
};
