import React, { useState } from 'react';

import Textfield from '@material-ui/core/TextField';
import { makeStyles } from '@material-ui/core';
import { theme } from './Theme/theme';
import { ThemeTypes } from './Theme/theme.types';
import { Error } from './Error';

import IconButton from '@material-ui/core/IconButton';

/* Icons */
import EditIcon from '@mui/icons-material/Edit';
import DeleteOutlineIcon from '@mui/icons-material/DeleteOutline';
import LockOutlinedIcon from '@mui/icons-material/LockOutlined';
import EuroIcon from '@mui/icons-material/Euro';
import DoneAllIcon from '@mui/icons-material/DoneAll';
import LoopSharpIcon from '@mui/icons-material/LoopSharp';
import CloseIcon from '@mui/icons-material/Close';
import KeyboardArrowUpIcon from '@mui/icons-material/KeyboardArrowUp';
import KeyboardArrowDownIcon from '@mui/icons-material/KeyboardArrowDown';

import InputAdornment from '@material-ui/core/InputAdornment';

type cardsObjectType = {
  Active?: boolean;
  Alias: string;
  BankCode: string;
  CardProvider: string;
  CardType: string;
  CreationDate: number;
  Currency: string;
  Country: string;
  EnabledPayments?: string;
  EnabledUser?: string;
  ExpirationDate: string;
  Fingerprint: string;
  Id: string;
  Product?: string;
  Tag?: string | null;
  UserId: string;
  Validity: string;
};

interface TextFieldTypes {
  label?: string;
  type?: string;
  key?: string;
  id?: string;
  width?: string | number;
  height?: string | number;
  onClick?: () => void;
  onChange?: (e: any) => void;
  onKeyDown?: (e: any) => void;
  value?: string | number;
  error?: boolean;
  errorTitle?: string;
  actions?: string;
  onClickEdit?: () => void;
  onClickDelete?: () => void;
  multiline?: boolean;
  autoFocus?: boolean;
  [key: string]: any;
  cardDetected?: string;
  paymentsUtility?: string;
  cardRegistredStatus?: string;
  disabled?: boolean;
  textAddNewCard?: string;
  addNewCardRedirection?: () => void;
  cardsList?: cardsObjectType[];
  setSelectedCard?: (v: any) => void;
  selectedCard?: any;
}

export const TextField = ({
  label,
  type,
  key,
  id,
  onClick,
  onChange,
  onKeyDown,
  width,
  height,
  value,
  error,
  errorTitle,
  actions,
  onClickDelete,
  onClickEdit,
  multiline,
  autoFocus,
  cardDetected,
  paymentsUtility,
  cardRegistedStatus,
  disabled,
  textAddNewCard,
  addNewCardRedirection,
  cardsList,
  selectedCard,
  setSelectedCard,
  ...props
}: TextFieldTypes) => {
  const iconsMargin = width ? Number(width) - 100 : 100;

  const creditCardsEnabled = [
    {
      provider: 'MASTERCARD',
      icon:
        'https://gubick.s3.eu-west-3.amazonaws.com/gubickstatics/mastercard.jpg',
    },
    {
      provider: 'DINNERS',
      icon:
        'https://gubick.s3.eu-west-3.amazonaws.com/gubickstatics/dinners.png',
    },
    {
      provider: 'MAESTRO',
      icon:
        'https://gubick.s3.eu-west-3.amazonaws.com/gubickstatics/maestro.png',
    },
    {
      provider: 'VISA',
      icon: 'https://gubick.s3.eu-west-3.amazonaws.com/gubickstatics/visa.png',
    },
    {
      provider: 'AMEX',
      icon:
        'https://gubick.s3.eu-west-3.amazonaws.com/gubickstatics/american-express.png',
    },
  ];

  const styles = makeStyles({
    rootMaster: {
      position: 'relative',
      width: 'max-content',
      '&>.containerIcons': {
        position: 'absolute',
        marginTop: 10,
        zIndex: 90,
        display: 'none',
        backgroundColor: theme.whitePrimary,
        '&>button': {
          border: `1px solid ${theme.borderGreyPrimary}`,
          width: 33,
          height: 33,
          margin: 5,
        },
      },
      '&>.containerIconsFixed': {
        position: 'absolute',
        marginTop: 10,
        zIndex: 90,
        backgroundColor: theme.whitePrimary,
        '&>button': {
          border: `1px solid ${theme.borderGreyPrimary}`,
          width: 33,
          height: 33,
          margin: 5,
        },
      },
      '&:hover': {
        '&>.containerIcons': {
          display: 'flex',
        },
      },
    },
    root: {
      display: 'flex',
      flexDirection: 'column',
      alignSelf: 'center',
      width: (props: ThemeTypes) => (props.width ? props.width : 378),
      height: 'max-content',
      '& > .MuiPaper-elevation3': {
        boxShadow: 'none',
        backgroundColor: 'white',
      },
    },
    field: {
      border: `1px solid ${theme.borderGreyPrimary}`,
      width: (props: ThemeTypes) => (props.width ? props.width : 378),
      height: 'max-content',
      outline: 'none',
      borderRadius: '4px',
      position: 'relative',
      '& > .MuiInputBase-root': {
        marginTop: '1px',
        height: 'max-content',
        fontWeight: 300,
        fontSize: 16,
        borderRadius: '4px',
        minHeight: (props: ThemeTypes) =>
          props.multiline ? '130px !important' : '',
        '& > .MuiInputBase-input': {
          width: (props: ThemeTypes) => (props.width ? props.width : 378),
          minHeight: (props: ThemeTypes) =>
            props.multiline ? '130px !important' : '',
          height: 'max-content',
          paddingLeft: '20px',
          paddingRight: '20px',
          paddingTop: '24px',
          paddingBottom: '15px',
          color: '#000c24',
          padding: '0px',
          borderRadius: '4px',
          backgroundColor: 'transparent !important',
          zIndex: 100,
        },
        '& > .MuiInputBase-input:focus': {
          width: (props: ThemeTypes) =>
            props.width ? `${props.width} !important` : `377px !important`,
          height: 'max-content',
          backgroundColor: 'transparent !important',
          marginLeft: 1.5,
        },
        '& > .MuiInput-input': {
          marginLeft: 1.5,
          zIndex: 1,
          width: (props: ThemeTypes) =>
            props.width ? `${props.width} !important` : `377px !important`,
          height: 'max-content',
          minHeight: (props: ThemeTypes) =>
            props.multiline ? '130px !important' : '',
          backgroundColor: 'transparent !important',
        },
      },
      '& > .MuiInput-root': {
        backgroundColor: theme.whitePrimary,
        height: 'max-content',
      },
      '& > .MuiInput-underline:before': {
        borderBottom: 'none',
        height: 'max-content',
        content: 'none',
      },
      '& > .MuiInput-underline:after': {
        border: `1px solid ${theme.bluePrimary}`,
        width: (props: ThemeTypes) => (props.width ? props.width : 378),
        height: 'max-content',
        minHeight: '100% !important',
        backgroundColor: 'white',
        transition: 'none',
        borderRadius: 4,
      },
      '& > .MuiInput-underline:hover': {
        backgroundColor: 'white',
      },
      '& > .MuiInputLabel-animated': {
        color: 'grey',
        zIndex: 99,
        marginTop: '0px',
        paddingTop: '8px',
        paddingLeft: '15px',
        fontSize: '16px',
        transition:
          'color 200ms cubic-bezier(0.0, 0, 0.2, 1) 0ms,transform 100ms cubic-bezier(0.0, 0, 0.2, 1) 0ms',
      },
      '& > .MuiInputLabel-root:before': {
        color: 'blue',
      },
      '& >div>div> .cardRegisteredDelete': {
        display: 'none',
      },
      '&:hover': {
        '& >div>div> .cardRegisteredDelete': {
          display: 'inline',
        },
      },
    },
    icon: {
      width: '24px',
      height: '24px',
    },
    iconBig: {
      width: '30,37px',
      height: '24px',
    },
    containerChat: {
      borderRadius: 35,
    },
    containerTextField: {
      position: 'relative',
    },
    onEdit: {
      color: 'grey',
      width: 'min-content',
      position: 'absolute',
      zIndex: 101,
      marginTop: 7,
      backgroundColor: '#ffffff',
      '&>svg': {
        width: 40,
        height: 40,
        padding: 8,
        borderRadius: '50%',
        '&:hover': {
          width: 42,
          height: 42,
          border: '1px solid #3d43ff',
          cursor: 'pointer',
        },
      },
    },

    cardIcons: {
      width: 23,
      height: 23,
    },
    closeIcon: {
      color: theme.redPrimary,
    },
    doneIcon: {
      color: theme.greenPrimary,
    },
    verifyIcon: {
      color: theme.bluePrimary,
      animation: '$spin 2s linear infinite',
    },
    '@keyframes spin': {
      '0%': {
        transform: 'rotate(360deg)',
      },
      '100%': {
        transform: 'rotate(0deg)',
      },
    },
    containerTextFieldAndSelectorPayment: {
      position: 'relative',
      display: 'flex',
      alignItems: 'center',
    },
    containerSelectorPayment: {
      position: 'absolute',
      right: 0,
      marginRight: 6,
      zIndex: 999,
    },
    buttonIconSelectorPayment: {
      width: 30,
      height: 30,
      border: `1px solid ${theme.borderGreyPrimary}`,
    },
    conatinerIconsCardSelector: {
      width: 'max-content',
      height: 25,
      display: 'flex',
      marginRight: 30,
      '&>.onlyIcon': {
        width: 35,
        height: 30,
        marginTop: -4,
        marginRight: 15,
        '&>span': {
          opacity: '0.99 !important',
          '&>img': {
            width: 35,
            height: 30,
          },
        },
      },
      '&>button': {
        width: 20,
        height: 20,
        margin: 2,
        '&>span': {
          opacity: 0.55,
          '&>img': {
            width: 20,
            height: 20,
          },
        },
      },
    },
    listPaymentCard: {
      '&>ul': {
        listStyleType: 'none',
        padding: 0,
        margin: 0,
        border: `1px solid ${theme.borderGreyPrimary}`,
        borderRadius: '0px 0px 4px 4px',
        '&>li': {
          padding: 10,
          color: theme.lightGrayPrimary,
          '&:hover': {
            backgroundColor: theme.hoverBlue,
            cursor: 'pointer',
            color: theme.bluePrimary,
          },
        },
      },
    },
  });
  const classes = styles({ width, height, multiline });
  const [unfoldedSelectorPayment, setUnfoldedSelectorPayment] = useState(false);
  const [internSelectedCard, setInternSelectedCard] = useState<cardsObjectType>(
    {
      ExpirationDate: '',
      Alias: '',
      CardType: '',
      CardProvider: '',
      Country: '',
      Product: '',
      BankCode: '',
      Active: false,
      Currency: '',
      Validity: '',
      UserId: '',
      Id: '',
      Tag: null,
      CreationDate: 0,
      Fingerprint: '',
      EnabledUser: '',
    }
  );

  const getSpacedString = (result: string): string => {
    const spacedString = result.split('').reduce((acc, curr, index) => {
      return acc + curr + (index % 4 === 3 ? ' ' : '');
    }, '');
    return spacedString;
  };

  const formatCardAlias = (alias: string) => {
    if (alias) {
      let lengthCharacters = alias.length;
      let expReg = /[^\s]/g;
      let hiddenValues = alias
        .slice(0, lengthCharacters - 4)
        ?.replace(expReg, '*');
      let visibleCharacters = alias.slice(
        lengthCharacters - 4,
        lengthCharacters
      );

      let result = `${hiddenValues}${visibleCharacters}`;
      return getSpacedString(result);
    }
  };

  return (
    <div className={classes.rootMaster}>
      {actions !== 'Blocked' && actions === 'Edit, Delete' && (
        <div className="containerIcons" style={{ marginLeft: iconsMargin }}>
          <IconButton onClick={onClickEdit}>
            <EditIcon />
          </IconButton>
          <IconButton onClick={onClickDelete}>
            <DeleteOutlineIcon />
          </IconButton>
        </div>
      )}
      {actions !== 'Blocked' && actions === 'Edit' && (
        <div
          className="containerIcons"
          style={{ marginLeft: iconsMargin + 45 }}
        >
          <IconButton onClick={onClickEdit}>
            <EditIcon />
          </IconButton>
        </div>
      )}
      {actions !== 'Blocked' && actions === 'Delete' && (
        <div
          className="containerIcons"
          style={{ marginLeft: iconsMargin + 45 }}
        >
          <IconButton onClick={onClickDelete}>
            <DeleteOutlineIcon />
          </IconButton>
        </div>
      )}
      {actions !== 'Blocked' && actions === 'Currency' && (
        <div
          className="containerIconsFixed"
          style={{ marginLeft: iconsMargin + 45 }}
        >
          <IconButton style={{ marginTop: -1 }}>
            <EuroIcon />
          </IconButton>
        </div>
      )}
      {actions !== 'Blocked' && actions === 'Porcent' && (
        <div
          className="containerIconsFixed"
          style={{ marginLeft: iconsMargin + 45 }}
        >
          <IconButton style={{ marginTop: -1 }}>
            <span style={{ fontWeight: 700 }}>%</span>
          </IconButton>
        </div>
      )}
      {actions === 'Blocked' && (
        <div
          className="containerIconsFixed"
          style={{ marginLeft: iconsMargin + 45 }}
        >
          <IconButton onClick={onClickDelete} style={{ border: 'none' }}>
            <LockOutlinedIcon style={{ color: theme.bluePrimary }} />
          </IconButton>
        </div>
      )}
      {actions === 'Payments' && (
        <React.Fragment>
          {!paymentsUtility && (
            <React.Fragment>
              <Textfield
                id={id}
                className={classes.field}
                value={value}
                label={label}
                type={type}
                onChange={onChange}
                onKeyDown={onKeyDown}
                autoComplete="off"
                autoFocus={autoFocus}
                InputProps={{
                  endAdornment: creditCardsEnabled.map(card => (
                    <InputAdornment
                      position="start"
                      style={{ position: 'relative', zIndex: 20 }}
                    >
                      <div>
                        <IconButton
                          style={{
                            width: cardDetected === card.provider ? 37 : 27,
                            height: cardDetected === card.provider ? 35 : 25,
                            backgroundColor:
                              cardDetected === card.provider ? '#e5e9ff' : '',
                            padding: 2,
                          }}
                        >
                          <img
                            className={classes.cardIcons}
                            width={cardDetected === card.provider ? 33 : 24}
                            height={cardDetected === card.provider ? 31 : 22}
                            src={card.icon}
                            title={card.provider}
                            style={{
                              opacity:
                                cardDetected === card.provider ? 0.9 : 0.3,
                            }}
                          />
                        </IconButton>
                      </div>
                    </InputAdornment>
                  )),
                }}
                {...props}
              />
              {error && <Error title={errorTitle} />}
            </React.Fragment>
          )}
          {paymentsUtility === 'cvc' && (
            <React.Fragment>
              <Textfield
                id={id}
                className={classes.field}
                value={value}
                label={label}
                type={type}
                onChange={onChange}
                onKeyDown={onKeyDown}
                autoComplete="off"
                autoFocus={autoFocus}
                InputProps={{
                  endAdornment: (
                    <InputAdornment
                      position="start"
                      style={{ position: 'relative', zIndex: 20 }}
                    >
                      <div>
                        <IconButton>
                          <img
                            className={classes.cardIcons}
                            width={40}
                            height={40}
                            src="https://gubick.s3.eu-west-3.amazonaws.com/gubickstatics/cvc.png"
                            title={'CVC'}
                          />
                        </IconButton>
                      </div>
                    </InputAdornment>
                  ),
                }}
                {...props}
              />
              {error && <Error title={errorTitle} />}
            </React.Fragment>
          )}
          {paymentsUtility === 'card_registered' && (
            <React.Fragment>
              <Textfield
                id={id}
                className={classes.field}
                value={value}
                label={label}
                type={type}
                autoComplete="off"
                disabled
                InputProps={{
                  endAdornment: (
                    <InputAdornment
                      position="start"
                      style={{ position: 'relative', zIndex: 20 }}
                    >
                      <div>
                        <IconButton>
                          {cardRegistedStatus === 'INVALID' && (
                            <CloseIcon className={classes.closeIcon} />
                          )}
                          {cardRegistedStatus === 'VALID' && (
                            <DoneAllIcon className={classes.doneIcon} />
                          )}
                          {cardRegistedStatus === 'UNKNOWN' && (
                            <LoopSharpIcon className={classes.verifyIcon} />
                          )}
                        </IconButton>
                      </div>

                      <div className="cardRegisteredDelete">
                        <IconButton>
                          <DeleteOutlineIcon onClick={onClickDelete} />
                        </IconButton>
                      </div>
                    </InputAdornment>
                  ),
                }}
                {...props}
              />
              {error && <Error title={errorTitle} />}
            </React.Fragment>
          )}
        </React.Fragment>
      )}
      {actions !== 'Payments' && actions !== 'PaymentSelector' && (
        <React.Fragment>
          <Textfield
            id={id}
            multiline={multiline}
            className={classes.field}
            value={value}
            label={label}
            type={type}
            onChange={onChange}
            onKeyDown={onKeyDown}
            autoComplete="off"
            disabled={actions === 'Blocked' ? true : disabled}
            autoFocus={autoFocus}
            {...props}
          />
          {error && <Error title={errorTitle} />}
        </React.Fragment>
      )}
      {actions === 'PaymentSelector' && (
        <React.Fragment>
          <div className={classes.containerTextFieldAndSelectorPayment}>
            <Textfield
              id={id}
              multiline={multiline}
              className={classes.field}
              value={formatCardAlias(internSelectedCard.Alias) || ''}
              label={label}
              type={type}
              onChange={onChange}
              onKeyDown={onKeyDown}
              autoComplete="off"
              disabled={disabled}
              autoFocus={autoFocus}
              InputProps={{
                endAdornment: (
                  <InputAdornment
                    position="start"
                    style={{ position: 'relative', zIndex: 20 }}
                  >
                    {internSelectedCard?.CardType === '' && (
                      <div className={classes.conatinerIconsCardSelector}>
                        {creditCardsEnabled &&
                          creditCardsEnabled?.length > 0 &&
                          creditCardsEnabled?.map(
                            (cardIcon: { provider: string; icon: string }) => (
                              <IconButton>
                                <img
                                  src={cardIcon.icon}
                                  alt={cardIcon.provider}
                                />
                              </IconButton>
                            )
                          )}
                      </div>
                    )}
                    {internSelectedCard?.CardType !== '' && (
                      <div className={classes.conatinerIconsCardSelector}>
                        {internSelectedCard?.CardType === 'DINERS' &&
                          creditCardsEnabled &&
                          creditCardsEnabled?.length > 0 &&
                          creditCardsEnabled
                            ?.filter(c => c.provider === 'DINNERS')
                            .map(
                              (cardIcon: {
                                provider: string;
                                icon: string;
                              }) => (
                                <IconButton className="onlyIcon">
                                  <img
                                    src={cardIcon.icon}
                                    alt={cardIcon.provider}
                                  />
                                </IconButton>
                              )
                            )}
                        {internSelectedCard?.CardType ===
                          'CB_VISA_MASTERCARD' &&
                          creditCardsEnabled &&
                          creditCardsEnabled?.length > 0 &&
                          creditCardsEnabled
                            ?.filter(
                              c =>
                                c.provider === internSelectedCard?.CardProvider
                            )
                            .map(
                              (cardIcon: {
                                provider: string;
                                icon: string;
                              }) => (
                                <IconButton className="onlyIcon">
                                  <img
                                    src={cardIcon.icon}
                                    alt={cardIcon.provider}
                                  />
                                </IconButton>
                              )
                            )}

                        {internSelectedCard?.CardType !== 'DINERS' &&
                          internSelectedCard?.CardType !==
                            'CB_VISA_MASTERCARD' &&
                          creditCardsEnabled &&
                          creditCardsEnabled?.length > 0 &&
                          creditCardsEnabled
                            ?.filter(
                              c => c.provider === internSelectedCard?.CardType
                            )
                            .map(
                              (cardIcon: {
                                provider: string;
                                icon: string;
                              }) => (
                                <IconButton className="onlyIcon">
                                  <img
                                    src={cardIcon.icon}
                                    alt={cardIcon.provider}
                                  />
                                </IconButton>
                              )
                            )}
                      </div>
                    )}
                  </InputAdornment>
                ),
              }}
              {...props}
            />
            <div
              className={classes.containerSelectorPayment}
              onClick={() =>
                setUnfoldedSelectorPayment(!unfoldedSelectorPayment)
              }
            >
              <IconButton className={classes.buttonIconSelectorPayment}>
                <React.Fragment>
                  {unfoldedSelectorPayment ? (
                    <KeyboardArrowUpIcon />
                  ) : (
                    <KeyboardArrowDownIcon />
                  )}
                </React.Fragment>
              </IconButton>
            </div>
          </div>
          {unfoldedSelectorPayment && (
            <div className={classes.listPaymentCard}>
              <ul>
                {cardsList &&
                  cardsList?.length > 0 &&
                  cardsList.map((card: cardsObjectType) => (
                    <li
                      onClick={() => {
                        setInternSelectedCard(card);
                        setSelectedCard && setSelectedCard(card);
                        setUnfoldedSelectorPayment(!unfoldedSelectorPayment);
                      }}
                    >
                      {formatCardAlias(card?.Alias)}
                    </li>
                  ))}
                <li
                  onClick={() =>
                    addNewCardRedirection ? addNewCardRedirection() : null
                  }
                >
                  {textAddNewCard || 'Default Text'}
                </li>
              </ul>
            </div>
          )}

          {error && <Error title={errorTitle} />}
        </React.Fragment>
      )}
    </div>
  );
};
