import React, { useEffect, useState } from 'react';

import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';
import { ThemeTypes } from './Theme/theme.types';
import dayjs, { Dayjs } from 'dayjs';
import { AdapterDayjs } from '@mui/x-date-pickers/AdapterDayjs';
import Stack from '@mui/material/Stack';
import { LocalizationProvider } from '@mui/x-date-pickers/LocalizationProvider';
import { DesktopDatePicker } from '@mui/x-date-pickers/DesktopDatePicker';


// import { theme } from './Theme/theme';

import TextField from '@material-ui/core/TextField';

interface TextFieldDateTypes {
  [key: string]: any;
  width?: string | number;
  height?: string | number;
  label?: string;
  initialDate?: string;
  setValueDate?: (e: string | undefined) => void;
  format?: string;
  maxDate?: boolean;
}

export const TextFieldDate = ({width, height, label, initialDate, setValueDate, format, maxDate, ...props }: TextFieldDateTypes) => {
  const styles = makeStyles({
    root: {},
    field: {
      border: `1px solid ${theme.borderGreyPrimary}`,
      width: (props: ThemeTypes) => props.width ? props.width : 378,
      outline: "none",
      borderRadius: '4px',
      position: 'relative',
      '& > .MuiInputBase-root': {
        marginTop: '1px',
        fontWeight: 300,
        fontSize: 16,
        borderRadius: '4px',
        minHeight: (props: ThemeTypes) => props.multiline ? '130px !important' : '',
        '&>:nth-child(2)':{
          '&>button': {
            marginRight: 10,
            position: 'relative',
            zIndex: 99,
            margin: 0,
            padding: 5,
            border: `1px solid ${theme.borderGreyPrimary}`,
            marginTop: -8,
            '&>svg':{
              width: 20,
              height: 20,
            },
            '&:hover':{
              border: `1px solid ${theme.bluePrimary}`,
            }
          }
        },
        '& > .MuiInputBase-input': {
          width: (props: ThemeTypes) => props.width ? props.width : 378,
          minHeight: (props: ThemeTypes) => props.multiline ? '130px !important' : '',
          marginTop: (props: ThemeTypes) => props.multiline ? 32 : '',
          paddingLeft: '20px',
          paddingRight: '0px',
          paddingTop: '24px',
          paddingBottom: '15px',
          color: '#00c24',
          padding: '0px',
          borderRadius: '4px',
          backgroundColor: "transparent !important",
          zIndex: 100,
        },
        '& > .MuiInputBase-input:focus':{
          width: (props: ThemeTypes) => props.width ? `${props.width} !important` : `377px !important`,
          backgroundColor: 'transparent !important',
          marginLeft: 1.5,
        },
        '& > .MuiInput-input':{
          marginLeft: 1.5,
          zIndex:1,
          width: (props: ThemeTypes) => props.width ? `${props.width} !important` : `377px !important`,
          minHeight: (props: ThemeTypes) => props.multiline ? '130px !important' : '',
          backgroundColor: 'transparent !important',
        }
      },
      '& > .MuiInput-root': {
        backgroundColor: theme.whitePrimary,
        height: 55
      },
      '& > .MuiInput-underline:before': {
        borderBottom: 'none',
        content: 'none'
      },
      '& > .MuiInput-underline:after': {
        border: `1px solid ${theme.bluePrimary}`,
        width: (props: ThemeTypes) => props.width ? props.width : 378,
        height: (props: ThemeTypes) => props.height ? props.height : 60,
        backgroundColor: 'white',
        transition: 'none',
        borderRadius: 4
      },
      '& > .MuiInput-underline:hover': {
        backgroundColor: 'white',
      },
      '& > .MuiInputLabel-animated': {
        color: 'grey',
        zIndex: 99,
        marginTop: "0px",
        paddingTop: '8px',
        paddingLeft: "15px",
        fontSize: "16px",
        transition: 'color 200ms cubic-bezier(0.0, 0, 0.2, 1) 0ms,transform 100ms cubic-bezier(0.0, 0, 0.2, 1) 0ms',
      },
      '& > .MuiInputLabel-root:before': {
        color: 'blue',
      },
    },
  });
  const classes = styles({ width, height });

  const formatDate = format || 'DD/MM/YYYY'
  const [str, setStr] = useState( initialDate || dayjs().format(formatDate));
  const [dateValues] = str.split(' ');
  const [day, month, year] = dateValues.split('/');

  const date =  new Date(+year, +month -1, +day);

  const [value, setValue] = useState<Dayjs | null>(
    dayjs(date)
  );

  const handleChange = (newValue: Dayjs | null) => {
    setValue(newValue);
  };


  useEffect(() => {
    if(initialDate) setStr(initialDate)
  },[initialDate])

  useEffect(() => {
    if(setValueDate){
      setValueDate(value?.format(formatDate))
    }
  },[value])


  return (
    <div className={classes.root} {...props}>
      <LocalizationProvider dateAdapter={AdapterDayjs}>
        <Stack spacing={3}>
        {maxDate ? (<DesktopDatePicker
          maxDate={dayjs().subtract(18, 'year')}
          className={classes.field}
          label={label}
          inputFormat={formatDate}
          value={value}
          onChange={handleChange}
          renderInput={(params: any) => <TextField className={classes.field} { ...params } />}
        />) : (
          <DesktopDatePicker
          className={classes.field}
          label={label}
          inputFormat={formatDate}
          value={value}
          onChange={handleChange}
          renderInput={(params: any) => <TextField className={classes.field} { ...params } />}
        />
        )}
        </Stack>
      </LocalizationProvider>
    </div>
  )
}