import React, { useEffect, useRef, useState } from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';

import IconButton from '@material-ui/core/IconButton';
import { Error } from './Error';
/* Icons */
import NorthIcon from '@mui/icons-material/North';
import DeleteOutlineIcon from '@mui/icons-material/DeleteOutline';
import AttachFileIcon from '@mui/icons-material/AttachFile';
import { ThemeTypes } from './Theme/theme.types';

import { temporalId } from './helpers/temporalId';

type filesTypes = {
  temp_id: string;
  name: string;
  size: number;
  type: string;
  base: string;
}

interface TextFieldUploadFileTypes {
  [key: string]: any;
  accept: string;
  onChange?: React.ChangeEventHandler<HTMLInputElement>;
  width?: string | number;
  label?: string;
  tag?: string;
  addText?: string;
  maxFiles: number;
  maxFilesMessage: string;
  initialFiles?: filesTypes[];
  setDataFiles?: (data: filesTypes[]) => void;
}

export const TextFieldUploadFile = ({
  accept,
  onChange,
  width,
  label,
  tag,
  addText,
  maxFiles,
  maxFilesMessage,
  setDataFiles,
  initialFiles,
  ...props }: TextFieldUploadFileTypes) => {
  const styles = makeStyles({
    root: {
    },
    containerFile: {
      border: `2px dashed ${theme.borderGreyPrimary}`,
      width: (props: ThemeTypes) => props.width || 356,
      borderRadius: 4,
      display: 'flex',
      alignItems: 'center',
      '&:hover': {
        border: `2px dashed ${theme.bluePrimary}`,
      }
    },
    containerFileTag: {
      border: `1px solid ${theme.borderGreyPrimary}`,
      borderRadius: 4,
      height: 'max-content',
      minHeight: 55,
      marginTop: 20,
      width: (props: ThemeTypes) => props.width || 356,
      '&:hover': {
        border: `1px solid ${theme.bluePrimary}`,
      }
    },
    containerIcon: {
      border: `1px solid ${theme.borderGreyPrimary}`,
      width: 30,
      height: 30,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      borderRadius: '50%',
      marginInlineStart: 'auto',
      marginRight: 15,
      '&:hover': {
        cursor: 'pointer',
        border: `1px solid ${theme.bluePrimary}`
      }
    },
    containerIconTag: {
      width: 15,
      height: 15,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      margin: 0,
      padding: 0,
      marginLeft: 15
    },
    label: {
      marginLeft: 15,
      padding: 5,
      margin: 8,
      color: theme.defaultSubtitle
    },
    labelTag: {
      marginLeft: 15,
      marginTop: 5,
      fontSize: 14,
      color: theme.defaultSubtitle,
      margin: 0,
      padding: 0
    },
    fileName: {
      marginLeft: 10,
      padding: 4,
      margin: 4
    },
    addText: {
      color: theme.bluePrimary,
      width: (props: ThemeTypes) => props.width || 356,
      textAlign: 'right',
      fontWeight: 500,
      marginTop: 10,
      '&:hover': {
        cursor: 'pointer'
      }
    },
    contentTag: {
      display: 'flex',
      alignItems: 'center',
      marginTop: -10,
      padding: 0,
      height: '100%',
      '&:hover': {
        '&>:nth-child(3)': {
          display: 'flex'
        }
      }
    },
    containerTrash: {
      width: 30,
      height: 30,
      border: `1px solid ${theme.borderGreyPrimary}`,
      justifyContent: 'center',
      alignItems: 'center',
      borderRadius: '50%',
      marginInlineStart: 'auto',
      marginRight: 15,
      marginTop: -25,
      display: 'none',
      '&:hover': {
        cursor: 'pointer',
        border: `1px solid ${theme.bluePrimary}`
      }
    }
  });
  const classes = styles({ width });

  const inputFile: any = useRef();

  const [files, setFiles] = useState<filesTypes[]>([])
  const [showError, setShowError] = useState(false)
  
  const hanldeRemove = (id: string) => {
    setFiles(files.filter(f => f.temp_id !== id))
  }

  useEffect(() =>{
    if(initialFiles && initialFiles.length > 0) setFiles(initialFiles)
  },[initialFiles])

  useEffect(() => {
    if(setDataFiles) setDataFiles(files)
  },[files])

  const handleSetFiles = (file: any, url: string) => {
    if (files.length === maxFiles) {
      setShowError(!showError)
      setTimeout(() => {
        setShowError(showError)
      }, 5500)
    } else {
      if (files.length === 0) {
        setFiles([
          {
            temp_id: temporalId(),
            name: file[0].name,
            size: file[0].size,
            type: file[0].type,
            base: url
          }
        ])
      }
      if (files.length > 0) {
        setFiles([
          ...files,
          {
            temp_id: temporalId(),
            name: file[0].name,
            size: file[0].size,
            type: file[0].type,
            base: url
          }
        ])
      }
    }
  }

  const handleChange = () => {
    if (inputFile) inputFile?.current?.click();
  };
  const fileChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const _file = e?.target?.files;
    const fileReader = new FileReader();
    fileReader.onload = (fileLoad: ProgressEvent<FileReader>) => {
      const target: any = fileLoad?.target;
      if (onChange) onChange(e);
      if (_file) handleSetFiles(_file, target?.result)
    };
    if (_file) fileReader?.readAsDataURL(_file[0]);
  };


  const errorWidth = () => {
    if(typeof width === 'string') {
      return parseFloat(width.replace(/\D/g, ""))
    }
    if(typeof width === 'number'){
      return width
    }
    return 365
  }

  return (
    <div {...props}>
      {files.length > 0 &&
        <>
          {files.map(file => (

            <div className={classes.containerFileTag} key={file.temp_id}>
              <p className={classes.labelTag}>{tag}</p>
              <div className={classes.contentTag}>
                <div className={classes.containerIconTag}>
                  <IconButton onClick={handleChange}>
                    <AttachFileIcon />
                  </IconButton>
                </div>
                <p className={classes.fileName}>{file.name}</p>
                <div className={classes.containerTrash}>
                  <IconButton onClick={() => hanldeRemove(file.temp_id)}>
                    <DeleteOutlineIcon />
                  </IconButton>
                </div>
              </div>
            </div>
          ))}
          {showError && <Error width={errorWidth()} title={maxFilesMessage}/>}
          <p className={classes.addText} onClick={handleChange}>{addText}</p>
        </>
      }
      {files.length === 0 &&
        (
          <div className={classes.containerFile}>
            <p className={classes.label}>{label}</p>
            <div className={classes.containerIcon}>
              <IconButton onClick={handleChange}>
                <NorthIcon />
              </IconButton>
            </div>
          </div>
        )
      }

      <input
        ref={inputFile}
        accept={accept}
        type='file'
        onChange={fileChange}
        style={{ display: 'none' }}
      />

    </div>
  )
}
