import React, { useState, useEffect } from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';

import KeyboardArrowUpIcon from '@mui/icons-material/KeyboardArrowUp';
import KeyboardArrowDownIcon from '@mui/icons-material/KeyboardArrowDown';
import { IconButton } from '@material-ui/core';
import { ThemeTypes } from './Theme/theme.types';


interface TextfieldSelectorStruct {
  label?: string;
  items?: string[];
  width?: number | string;
  [key: string]: any;
  height?: number | string;
  value?: string;
  setValue?: (v: string) => void;
}

export const TextfieldSelector = ({
  label,
  items,
  width,
  height,
  value,
  setValue,
  ...props }: TextfieldSelectorStruct) => {

  const rootDefaultStyle = {
    height: 'max-content',
    borderRadius: 4,
  }

  const styles = makeStyles({
    root: {
      width: (props: ThemeTypes) => props.width || 370,
      minHeight: (props: ThemeTypes) => props.height || 60,
      ...rootDefaultStyle
    },
    rootOpen: {
      width: (props: ThemeTypes) => props.width || 370,
      minHeight: (props: ThemeTypes) => props.height || 60,      ...rootDefaultStyle,
      border: `1px solid ${theme.bluePrimary}`,
      "&>:nth-child(1)": {
        borderBottom: `1px solid ${theme.bluePrimary}`
      }

    },
    containerItems: {
      backgroundColor: theme.whitePrimary,
      border: `1px solid ${theme.borderGreyPrimary}`,
      borderRadius: 4,
      overflow: 'auto',
      maxHeight: 150,
      '&::-webkit-scrollbar': {
        width: '5px',
        height: '5px',
        backgroundColor: theme.grayPrimary,
      },
      '&::-webkit-scrollbar-thumb': {
        backgroundColor: theme.opacityGrayDefault,
        borderRadius: '20px',
      },
      '&::-webkit-scrollbar-track': {
        marginBottom: '1px',
      },
      '&>ul': {
        padding: 0,
        margin: 0,
        "&>li": {
          listStyleType: 'none',
          padding: '10px 5px 5px 20px',
          color: theme.opacityGrayDefault,
          "&:hover": {
            backgroundColor: theme.hoverBlue,
            cursor: 'pointer',
            color: theme.blackPrimary
          },
        }
      }
    },
    selector: {
      width: 'auto',
      height: 'max-content',
      border: `1px solid ${theme.borderGreyPrimary}`,
      backgroundColor: theme.whitePrimary,
      borderRadius: 4,
      display: 'flex'
    },
    labelValue: {
      color: theme.defaultSubtitle,
      fontSize: 14,
      padding: '5px 0px 0px 10px'
    },
    labelDefault: {
      color: theme.defaultSubtitle,
      padding: '5px 5px 5px 20px',
      fontSize: 15,
      marginTop: 16
    },
    strValue: {
      color: theme.blackPrimary,
      fontSize: 16,
      padding: '5px 5px 5px 20px',
    },
    contentBtn: {
      marginInlineStart: 'auto',
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      backgroundColor: theme.whitePrimary,
      marginRight: 5,
      "&>button": {
        border: `1px solid ${theme.borderGreyPrimary}`,
        width: 35,
        height: 35
      }
    },
    contentSelector: {}
  });
  const classes = styles({ width, height });
  const defaultItems = Array.from({ length: 5 }, (_, i) => `String ${i + 1}`);
  const listItems = items || defaultItems

  const [localValue, setLocalValue] = useState<string>("");
  const [open, setOpen] = useState(false)

  const handleValue = (v: string) => {
    setValue && setValue(v)
    setLocalValue(v)
    setOpen(false)
  }

  useEffect(() => {
    value && setLocalValue(value)
  }, [])


  return (
    <section className={open ? classes.rootOpen : classes.root} {...props}>
      <div className={classes.selector}>
        <div className={classes.contentSelector}>
          <p className={localValue ? classes.labelValue : classes.labelDefault}>
            {label || "Default label"}
          </p>
          <p className={classes.strValue}>{localValue}</p>
        </div>
        <div className={classes.contentBtn}>
          <IconButton onClick={() => setOpen(!open)}>
            {open ? (
              <KeyboardArrowUpIcon />
            ) : (
              <KeyboardArrowDownIcon />
            )}
          </IconButton>
        </div>
      </div>
      {open && (<div className={classes.containerItems}>
        <ul>
          {listItems.map((item: string, index: number) => (
            <li key={index} onClick={() => handleValue(item)}>{item}</li>
          ))}
        </ul>
      </div>)}
    </section>
  )
}
