import React, { useRef, useState } from 'react';
import { DefaultCard } from './DefaultCard';
import { returnTypeFile } from './helpers';
import ActionTypes from './Types/actionsTypes';
import PositionFooter from './Types/positionFooter';

export const UploadFileWithIcon: React.FC<{
  src?: string | undefined
  type?: string | undefined
  accept?: string | undefined
  children?: React.ReactNode | undefined
  [key: string]: any
  width?: string | number
  height?: string | number
  actions?: ActionTypes
  onClickDelete?: () => void
  onClickEdit?: () => void
  footerCard?: {
    title?: string
    subTitle?: string,
    position?: PositionFooter
    divider?: boolean
    dividerColor?: string
    cursor?: boolean
  }
  onChange?: React.ChangeEventHandler<HTMLInputElement> | undefined
}> = ({
  src,
  type,
  width,
  height,
  actions,
  children,
  accept,
  onChange,
  onClickDelete,
  onClickEdit,
  footerCard,
  ...props
}) => {

    const inputFile: any = useRef();
    const [file, setFile]: any = useState(null);
    const [previewFile, setPreviewFile] = useState({ url: undefined });

    const handleChange = () => {
      if (inputFile) inputFile?.current.click();
    };

    const handleCleanFile = () => {
      if (onClickDelete) onClickDelete();
      setPreviewFile({ url: undefined });
      setFile(null);
    };

    const fileChange = (e: React.ChangeEvent<HTMLInputElement>) => {
      const _file = e?.target?.files;
      const fileReader = new FileReader();
      setFile(null);
      fileReader.onload = (fileLoad: ProgressEvent<FileReader>) => {
        const target: any = fileLoad.target;
        setPreviewFile({ url: target?.result });
        if (onChange) onChange(e);
        if (_file) setFile(_file[0]);
      };
      if (_file) fileReader.readAsDataURL(_file[0]);
    };

    if ((type && src) || file) {
      switch (returnTypeFile(type || file?.type)) {
        case 'jpg':
        case 'jpeg':
        case 'bmp':
        case 'gif':
        case 'png':
          return (
            <DefaultCard
              width={width}
              actions={actions}
              imageCard={{
                actions: 'Delete',
                image: src || previewFile?.url,
                onClickDelete: handleCleanFile
              }}
              footerCard={footerCard}
              height={height}>
            </DefaultCard>
          );
        default:
          return (
            <DefaultCard
              width={width}
              actions='delete'
              footerCard={footerCard}
              onClickDelete={handleCleanFile}
              height={height}>
              No se reconoce el tipo de archivo
            </DefaultCard>
          );
      }
    }

    return (
      <DefaultCard actions={actions} width={width} height={height}>
        <div  {...props} style={{ cursor: 'pointer', ...props?.style }} onClick={handleChange}>
          {children}
          <input
            ref={inputFile}
            style={{ display: 'none' }}
            accept={accept}
            type='file'
            onChange={fileChange} />
        </div>
      </DefaultCard>
    );
  };