import React from 'react';
import { makeStyles } from '@material-ui/core';
import { theme } from './Theme/theme';
import { ThemeTypes } from './Theme/theme.types';
import ErrorOutlineIcon from '@mui/icons-material/ErrorOutline';

interface ValidationInfoStruct {
  [key: string]: any;
  text?: string;
  width?: string | number;
}

export const ValidationInfo = ({
  text,
  width,
  ...props
}: ValidationInfoStruct) => {
  const styles = makeStyles({
    root: {
      width: (props: ThemeTypes) => props.width || 320,
      height: 'max-content',
      padding: 15,
      backgroundColor: theme.lightBlue,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      borderRadius: 4,
      '&>svg': {
        color: theme.bluePrimary,
        width: 40,
        height: 40,
        marginRight: 10,
      },
      '&>p': {
        color: theme.blackPrimary,
        fontSize: 14,
        fontWeight: 400,
      },
    },
  });
  const classes = styles({ width });
  const defaultText = 'This is a default text for validation info';
  return (
    <div className={classes.root} {...props}>
      <ErrorOutlineIcon />
      <p>{text || defaultText}</p>
    </div>
  );
};
