import React, { useState } from 'react';
import { makeStyles } from "@material-ui/core";
import { theme } from './Theme/theme';
import { ThemeTypes } from './Theme/theme.types';

import IconButton from '@material-ui/core/IconButton';

/* Icons */
import EditIcon from '@mui/icons-material/Edit';
import DeleteOutlineIcon from '@mui/icons-material/DeleteOutline';

interface ValueContainerTypes {
  label?: string;
  value?: string;
  indicator?: string;
  onClickEdit?: () => void;
  onClickDelete?: () => void;
  width?: string | number;
  height?: string | number;
  [key: string]: any;
}

export const ValueContainer = ({ width, height, label, indicator, onClickEdit, onClickDelete, value, ...props }: ValueContainerTypes) => {

  const iconsMargin = width ? Number(width) - 100 : 100

  const styles = makeStyles({
    root: {
      width: (props: ThemeTypes) => props.width || 356,
      height: (props: ThemeTypes) => props.height || 60,
      border: `1px  solid ${theme.borderGreyPrimary}`,
      borderRadius: 4,
      position: 'relative',
      '&:hover': {
        border: `1px solid ${theme.bluePrimary}`
      }
    },
    label: {
      color: theme.defaultSubtitle,
      fontSize: 14,
      textTransform: 'capitalize',
      margin: '5px 0px 0px 10px',
      padding: 0
    },
    container: {
      display: 'flex'
    },
    value: {
      color: theme.blackPrimary,
      fontSize: 16,
      margin: '0px 0px 0px 10px',
    },
    indicator: {
      textTransform: 'capitalize',
      color: theme.bluePrimary,
      fontWeight: 600,
      marginInlineStart: 'auto',
      margin: '0px 10px 0px 0px'
    },
    containerIcons:{
      position: 'absolute',
      marginTop: -44 ,
      zIndex: 998,
      backgroundColor: theme.whitePrimary,
      display: 'flex',
      '&>button':{
        border: `1px solid ${theme.borderGreyPrimary}`,
        width: 40,
        height: 40,
        margin: 5
      }
    }
  });
  const classes = styles({ width, height });
  const [showEdited, setShowEdited] = useState(false);
  return (
    <>
      <div className={classes.root}
       onMouseEnter={() => setShowEdited(true)}
       onMouseLeave={() => setShowEdited(false)}
       {...props}
      >
        <p className={classes.label}>{label}</p>
        <div className={classes.container}>
          <p className={classes.value}>{value}</p>
          {!showEdited && <p className={classes.indicator}>{indicator}</p>}
        </div>
        {showEdited && (
        <div className={classes.containerIcons}
        onMouseEnter={() => setShowEdited(true)}
        onMouseLeave={() => setShowEdited(false)}
        style={{ marginLeft: iconsMargin }}
        {...props}
      >
        <IconButton onClick={onClickEdit}>
          <EditIcon />
        </IconButton>
        <IconButton onClick={onClickDelete}>
          <DeleteOutlineIcon />
        </IconButton>
      </div>
      )}
      </div>
    </>
  )
}