import React, { useState } from 'react';
import { IconButton, makeStyles } from '@material-ui/core';
import { theme } from './Theme/theme';
import { ThemeTypes } from './Theme/theme.types';

/* Icons */
import EditIcon from '@mui/icons-material/Edit';
import DeleteOutlineIcon from '@mui/icons-material/DeleteOutline';

export const CardWithImg: React.FC<{
  width?: string | number
  height?: string | number
  image?: string
  actions?: string
  onClickDelete?: () => void
  onClickEdit?: () => void
  iconColor?: string
  children?: React.ReactNode,
  iconFooter?: any;
  [key: string]: any;
}> = ({ image, width, height, actions, onClickDelete, onClickEdit, iconColor, children, iconFooter, ...props }) => {
  const iconsMargin = width ? Number(width) - 115 : 115;
  const iconFooterMarginLeft = width ? Number(width) - 65 : 65;
  const iconFooterMarginTop = height ? Number(height) - 65 : 65;
  const defaultIconColor = theme.whitePrimary;
  const [showEditales, setShotEditables] = useState(false);
  const styles = makeStyles({
    background: {
      background: image ? `${showEditales ? 'linear-gradient( #cececece,#cececece),' : ''} url(${image}) no-repeat` : 'linear-gradient( #cececece,#cececece)',
      width: (props: ThemeTypes) => props.width || 200,
      height: (props: ThemeTypes) => props.height || 200,
      backgroundSize: (props: ThemeTypes) => `${props.width || 200}px ${props.height || 200}px`,
    },
    containerIcons: {
      position: 'absolute',
      marginTop: 10,
      zIndex: 90,
      '&>button': {
        border: `1px solid ${theme.borderGreyPrimary}`,
        width: 40,
        height: 40,
        margin: 5
      }
    },
    iconFooter: {
      position: 'absolute',
      marginTop: iconFooterMarginTop,
      marginLeft: iconFooterMarginLeft,
      zIndex: 90,
      opacity: showEditales ? 0.6 : undefined,
      '&>button': {
        border: `1px solid ${theme.borderGreyPrimary}`,
        width: 40,
        height: 40,
        margin: 5
      }
    }
  });
  const classes = styles({ width, height });
  return (
    <div
      onMouseEnter={() => setShotEditables(true)}
      onMouseLeave={() => setShotEditables(false)}
      {...props}
      className={classes.background}>
      {showEditales && actions !== 'Blocked' && actions === 'Edit, Delete' && (
        <div className={classes.containerIcons}
          onMouseEnter={() => setShotEditables(true)}
          style={{ marginLeft: iconsMargin }}
        >
          <IconButton style={{ background: iconColor || defaultIconColor }} onClick={onClickEdit}>
            <EditIcon />
          </IconButton>
          <IconButton style={{ background: iconColor || defaultIconColor }} onClick={onClickDelete}>
            <DeleteOutlineIcon />
          </IconButton>
        </div>
      )}
      {showEditales && actions !== 'Blocked' && actions === 'Delete' && (
        <div className={classes.containerIcons}
          onMouseEnter={() => setShotEditables(true)}
          style={{ marginLeft: iconsMargin + 45 }}
        >
          <IconButton style={{ background: iconColor || defaultIconColor }} onClick={onClickDelete}>
            <DeleteOutlineIcon />
          </IconButton>
        </div>
      )}
      {showEditales && actions !== 'Blocked' && actions === 'Edit' && (
        <div className={classes.containerIcons}
          onMouseEnter={() => setShotEditables(true)}
          style={{ marginLeft: iconsMargin + 45 }}
        >
          <IconButton style={{ background: iconColor || defaultIconColor }} onClick={onClickDelete}>
            <EditIcon />
          </IconButton>
        </div>
      )}
      {children}
      {iconFooter && (
        <div className={classes.iconFooter}>
          <IconButton style={{ background: iconColor || defaultIconColor }}>
            {iconFooter}
          </IconButton>
        </div>
      )}
    </div>
  );
};