const types: { [key: string]: string } = {
  "image/bmp": "bmp",
  "image/png": "png",
  "image/jpeg": "jpeg",
  "image/jpg": "jpg",
  "image/gif": "gif",
  "application/pdf": "pdf",
  "application/vnd.openxmlformats-officedocument.wordprocessingml.document": "docx",
  "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet": "xlsx",
  "application/zip": "zip",
  "application/x-zip-compressed": "zip",
  "video/mp4": "mp4",
  "audio/mpeg": "mpeg",
  "audio/wav": "wav",
  "audio/ogg": "ogg",
  "image/svg+xml": "svg"
}

export const DetectFileType = (fileType: string) => {
  if (fileType) {
    const type = Object.keys(types).filter(t => t === fileType)
    const typeValue = type && type[0] ? types[type[0]] : ''
    return typeValue
  }
  return ""
}

export const FormatName = (fileName: string) => {
  const limit = 10;
  if(fileName){
    if(fileName.length > limit){
      return fileName.split(".")[0].slice(0, limit).concat("...").concat(fileName.split(".")[1])
    } else {
      return fileName
    }
  }
  return ""
}

export const FormatNameAWS = (fileName: string) => {
  const limit = 15;
  if(fileName){
    if(fileName.length > limit){
      const firstString = fileName.split('.')[0].slice(0,limit - 3).concat('...');
      const ext = fileName.split('.')[1].split('-')[0];
      return `${firstString}.${ext}`;
    } else {
      const firstString = fileName.split('.')[0];
      const ext = fileName.split('.')[1].split('-')[0];
      return `${firstString}.${ext}`;
    }
  }
  return ""
}

export const FileSize = (size?: string) => {
  const inMB = 1000000;
  const inKB = 1000;
  if(size){
    const primaryResultMb = parseFloat(size) / inMB;
    const primaryResultKb = parseFloat(size) / inKB;

    const resInMB = `${primaryResultMb}`.includes('.') ? `${primaryResultMb}`.split('.')[0]+"."+(`${primaryResultMb}`.split('.')[1].substring(0,2)) : primaryResultMb
    const resInKb = `${primaryResultKb}`.includes('.') ? `${primaryResultKb}`.split('.')[0]+"."+(`${primaryResultKb}`.split('.')[1].substring(0,2)) : primaryResultKb

    const result = primaryResultMb >= 1 ? `${resInMB} MB` : `${resInKb} kb`;
    return result;
  }
  return ""
}

export const DescriptionSize = (size: string, lng: string) => {
  const text = lng === 'en' ? 'Size:' : 'Tamaño';
  return `${text} ${size}`
}

export const HourChat = (hour: string) => {
  if (hour) {
    const hours = hour.split(':')[0]
    const minutes = hour.split(':')[1]
    return minutes && minutes.length > 1 ? hour : `${hours}:0${minutes}`
  }
}